All Classes and Interfaces
Class
Description
Abstract class for easily decorating a
HttpRegistrySidecar.The Class AbstractHttpRegistryContextBuilder.
Abstract class for easily decorating a
HttpRegistrySidecar.Abstract base implementation of the
RestfulClient interface being the
foundation for various RestfulClient implementations such as
HttpRestClient or LoopbackRestClient.Abstract class for easily decorating a
RestfulHttpClient.Abstract class for easily decorating a
RestfulHttpDiscoveryClient.Abstract class for easily decorating a
RestfulHttpRegistryServer.Abstract class for easily decorating a
RestfulHttpServer.Implementation of the base functionality of the
RestfulServer
interface omitting the HTTP handling part being the foundation for various
RestfulServer implementations such as HttpRestServer or
LoopbackRestServer.A
BasicAuthEndpoint subscribes to a RestfulServer (
RestfulHttpServer) and defines the target for a Basic-Auth request.A
BasicAuthEndpointBuilder extends an BasicAuthEndpoint with
builder functionality and adds lambda support for handling the
requests addressed to this BasicAuthEndpoint.The
CorrelationClientInterceptor manages (adds) correlation IDs for
request and session.The
CorrelationServerInterceptor manages (adds) correlation IDs for
request and session.Provides an accessor for a home path property.
Provides a mutator for an home path property.
Provides a mutator for a home path property.
Provides a home path property.
Mixin to register a
RestRequestConsumer upon "home" requests.Provides an accessor for a home
RestRequestConsumer property.Provides a builder method for a home
RestRequestConsumer property
returning the builder for applying multiple build operations.Provides a mutator for a home
RestRequestConsumer property.Provides a home
RestRequestConsumer property.Provides an accessor for a home
Url property.Provides a mutator for an home
Url property.Provides a mutator for a home
Url property.Provides a home
Url property.The
HttpDiscovery describes the functionality required in order to
discover a service at a service discovery and discovery service.This context describes all information required to register a server
("service") at a service discovery registry.
The
HttpDiscoveryContextBuilder implements the
HttpDiscoveryContext with builder functionality as of the builder
pattern.The
HttpDiscoverySidecar describes the functionality required in
order to discover a service at a service discovery and discovery service.Provides an accessor for a service discovery discovery
Url property.Provides a builder method for a service discovery discovery URL property
returning the builder for applying multiple build operations.
Provides a mutator for a service discovery discovery URL property.
Provides a service discovery discovery URL property.
A lambda "catch-all" for handling exceptions during HTTP-Request processing.
Provides access to a
HttpExceptionHandler property.Provides a builder method for a
HttpExceptionHandler property
returning the builder for applying multiple build operations.Extends the
HttpExceptionHandlerAccessor with a setter method.Extends the
HttpExceptionHandlerAccessor with a setter method.Defines how errors affect the HTTP-Body whilst processing a
HttpRequest or a HttpResponse along with the according
sub-classes.Provides access to a
HttpExceptionHandling property.Provides a builder method for a
HttpExceptionHandling property
returning the builder for applying multiple build operations.Extends the
HttpExceptionHandlingAccessor with a setter method.Extends the
HttpExceptionHandlingAccessor with a setter method.The
HttpRegistry describes the functionality required in order to
register a service at a service registry and discovery service.This context describes all information required to register a server
("service") at a service discovery registry.
The
HttpRegistryContext.HttpRegistryContextBuilder interface extends the
HttpRegistryContext with builder functionality as of the builder
pattern.The
HttpRegistrySidecar describes the functionality required in order
to register a service at a service registry and discovery service.Provides an accessor for a service registry registry
Url property.Provides a builder method for a service registry registry URL property
returning the builder for applying multiple build operations.
Provides a mutator for a service registry registry URL property.
Provides a service registry registry URL property.
The
HttpRestClient implements the RestfulHttpClient
interface.The singleton of the
HttpRestClient for easy
RestfulHttpClient access.Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions of REST client functionality:
import static org.refcodes.rest.HttpRestClientSugar.*; Implementation of the
RestfulHttpServer interface using the
RestfulHttpServer defined in the com.sun.net.httpserver
package.The singleton of the
HttpRestServer for easy
RestfulHttpServer access.Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions of RESTful server functionality:
import static org.refcodes.rest.HttpRestServerSugarThe
HttpServerDescriptor describes a server to be registered at a
discovery registry so clients can resolve the server's URL.The
HttpServerDescriptor.HttpServerDescriptorBuilder interface extends the
HttpServerDescriptor interface with builder functionality as of
the builder pattern.Provides an accessor for a
HttpServerDescriptor property.Provides a builder method for a
HttpServerDescriptor property
returning the builder for applying multiple build operations.Provides a mutator for a
HttpServerDescriptor property.Provides a
HttpServerDescriptor property.The
HttpServerDescriptorFactory provides factory functionality for
creating HttpServerDescriptor instances.Implements the
RestfulClient interface to be used as loopback device
e.g. for testing purposes such as testing your RestResponseConsumer
implementations.The singleton of the
LoopbackRestClient for easy
LoopbackRestClient access.Implements a
RestfulServer to be used as loopback device e.g. for
testing purposes such as testing your RestRequestConsumer
implementations.The singleton of the
LoopbackRestServer for easy
RestfulServer access.Self refreshing implementation of the
OauthToken.Provides an accessor for a ping path property.
Provides a mutator for an ping path property.
Provides a mutator for a ping path property.
Provides a ping path property.
Mixin to register a
RestRequestConsumer upon "ping" requests.Provides an accessor for a ping
RestRequestConsumer property.Provides a builder method for a ping
RestRequestConsumer property
returning the builder for applying multiple build operations.Provides a mutator for a ping
RestRequestConsumer property.Provides a ping
RestRequestConsumer property.Provides an accessor for a ping
Url property.Provides a mutator for an ping
Url property.Provides a mutator for a ping
Url property.Provides a ping
Url property.Helper interface to keep the huge amount of convenience methods under
control.
Helper class to get the syntactic sugar (from a maintenance point of view)
under control.
An
RestEndpoint subscribes to a RestfulServer (
RestfulHttpServer) and defines the target for a REST request.An
RestEndpointBuilder extends an RestEndpoint with builder
functionality and adds lambda support for handling the requests
addressed to this RestEndpoint.A client to send requests for communicating with a RESTful server such as the
RestfulHttpServer.Extends a
RestfulClient to be capable of providing a User-Agent with
UserAgentAccessor.UserAgentMutator.setUserAgent(String) (RestfulHttpClient.withUserAgent(String)) and to be
capable of using base URLs to be set with BaseUrlAccessor.BaseUrlMutator.setBaseUrl(String) (
RestfulHttpClient.withBaseUrl(String)).The
RestfulHttpDiscoveryClient provides additional functionality for
registering at and signing off from a service discovery service in order to
resolve URLs to or from other services.The
RestfulHttpRegistryServer provides additional functionality for
registering at and signing off from a service discovery service in order to
resolve URLs to or from other services.Extends a
RestfulServer to be capable of opening a server socket on
the local host with the provided port number via ConnectionOpenable.open(Object) or
with an additional maximum number of connections via open(int, int).The
RestfulServer acts as the target for clients issuing REST
requests.Helper interface to keep the huge amount of convenience methods under
control.
Helper class to get the syntactic sugar (from a maintenance point of view)
under control.
Helper interface to keep the huge amount of convenience methods under
control.
Helper class to get the syntactic sugar (from a maintenance point of view)
under control.
Helper interface to keep the huge amount of convenience methods under
control.
Helper class to get the syntactic sugar (from a maintenance point of view)
under control.
A
RestRequest describes a REST request and the RestResponse
providing the response.The implementation of the
RestResponseHandler interface as good old
POJO for use by different RestfulClient implementations.Helper interface to keep the huge amount of convenience methods under
control.
Helper class to get the syntactic sugar (from a maintenance point of view)
under control.
The
RestRequestConsumer can be coded using the lambda
syntax and processes a request for a given locator and for a given
HttpMethod.Defines a
RestRequestEvent being the request as consumed by a
RestEndpoint.A
RestRequestHandler handles a REST request on the
RestfulClient instance's side to do the actual technical
implementation of sending that request (or mocking the send-out of a
request).Defines a
RestResponse being the base definition of a response as
returned as of a request issued by a RestfulClient (
RestfulHttpClient).The
RestResponseConsumer can be coded using the lambda
syntax and processes a response from a server.Defines a
RestResponseEvent being the response as consumed by a
RestResponseHandler's RestResponseConsumer.A
RestResponseHandler describes a REST request and the
RestResponseConsumer in charge for handling a REST response.A
RestResponseResult handles a REST request asynchronously on the
RestfulClient instance's side to do the actual technical
implementation of sending that request (or mocking the send-out of a
request).Provides an accessor for a status path property.
Provides a mutator for an status path property.
Provides a mutator for a status path property.
Provides a status path property.
Mixin to register a
RestRequestConsumer upon "status" requests.Provides an accessor for a status
RestRequestConsumer property.Provides a builder method for a status
RestRequestConsumer
property returning the builder for applying multiple build operations.Provides a mutator for a status
RestRequestConsumer property.Provides a status
RestRequestConsumer property.Provides an accessor for a status
Url property.Provides a mutator for an status
Url property.Provides a mutator for a status
Url property.Provides a status
Url property.