Interface BasicAuthEndpoint

All Superinterfaces:
BasicAuthObserver, HttpMethodAccessor
All Known Implementing Classes:
BasicAuthEndpointBuilder

public interface BasicAuthEndpoint extends BasicAuthObserver, HttpMethodAccessor
A BasicAuthEndpoint subscribes to a RestServer ( HttpRestServer) and defines the target for a Basic-Auth request. Therefore the BasicAuthEndpoint describes the HttpMethod, the locator (pattern) to which to respond as well as a BasicAuthObserver responsible for processing the request. The BasicAuthObserver is invoked as soon as a request with the given HttpMethod for a locator matching the given Locator-Pattern is being processed by the RestServer ( HttpRestServer). The locator for which a BasicAuthEndpoint is responsible for is defined by the BasicAuthEndpoint's Locator-Pattern: A single asterisk ("*") matches zero or more characters within a locator name. A double asterisk ("**") matches zero or more characters across directory levels. A question mark ("?") matches exactly one character within a locator name. The single asterisk ("*"), the double asterisk ("**") and the question mark ("?") we refer to as wildcard: You get an array with the substitutes of the wildcards using the RestRequestEvent's method RestRequestEvent.getWildcardReplacements() inside the BasicAuthObserver.onBasicAuthRequest(java.net.InetSocketAddress, java.net.InetSocketAddress, HttpMethod, String, org.refcodes.web.BasicAuthCredentials, String) method. You may name a wildcard by prefixing it with "{someWildcardName}". For example a named wildcard may look as follows: "{arg1}*" or "{arg2}**" or "{arg3}?".