Class BasicAuthEndpointBuilder

java.lang.Object
org.refcodes.rest.BasicAuthEndpointBuilder
All Implemented Interfaces:
Closable, Closable.CloseBuilder<LinkComponent.LinkComponentBuilder<BasicAuthEndpointBuilder>>, ConnectionStatusAccessor, LinkComponent, LinkComponent.LinkComponentBuilder<BasicAuthEndpointBuilder>, Openable, Openable.OpenBuilder<LinkComponent.LinkComponentBuilder<BasicAuthEndpointBuilder>>, OpenedAccessor, BasicAuthEndpoint, BasicAuthObserver, HttpMethodAccessor, HttpMethodAccessor.HttpMethodBuilder<BasicAuthEndpointBuilder>, HttpMethodAccessor.HttpMethodMutator, HttpMethodAccessor.HttpMethodProperty

A BasicAuthEndpointBuilder extends an BasicAuthEndpoint with builder functionality and adds lambda support for handling the requests addressed to this BasicAuthEndpoint. The lambda defined as BasicAuthObserver acts as the single listener to this BasicAuthEndpoint responsible for handling the requests for which this BasicAuthEndpoint is responsible. The locator for which an BasicAuthEndpointBuilder is responsible for is defined by the BasicAuthEndpointBuilder's Locator-Pattern: A single asterisk ("*") matches zero or more characters within a locator name. A double asterisk ("**") matches zero or more characters across directory levels. A question mark ("?") matches exactly one character within a locator name. The single asterisk ("*"), the double asterisk ("**") and the question mark ("?") we refer to as wildcard: You get an array with the substitutes of the wildcards using the method RestRequestEvent.getWildcardReplacements() . You may name a wildcard by prefixing it with "${someWildcardName}". For example a named wildcard may look as follows: "${arg1}=*" or "${arg2}=**" or "${arg3}=?". You can get the text substituting a named wildcard using the method RestRequestEvent.getWildcardReplacement(String). For ease of use, a named wildcard with single asterisk ("*") such as "${arg1}=*" can be abbreviated as "${arg1}".