Class BasicAuthEvent
java.lang.Object
org.refcodes.web.BasicAuthRequest
org.refcodes.rest.BasicAuthEvent
- All Implemented Interfaces:
ActionAccessor<HttpMethod>, SourceAccessor<RestServer>, WildcardSubstitutes, ActionEvent<HttpMethod, RestServer>, Event<RestServer>, BasicAuthCredentialsAccessor, HttpMethodAccessor, LocalAddressAccessor, RealmAccessor, RemoteAddressAccessor, UrlAccessor
public class BasicAuthEvent
extends BasicAuthRequest
implements ActionEvent<HttpMethod, RestServer>, WildcardSubstitutes, RealmAccessor, LocalAddressAccessor, RemoteAddressAccessor
The
BasicAuthEvent describes a BasicAuthRequest being the
request as consumed by a RestEndpoint. Usually you will use
RestServer.onRequest(HttpMethod, String, RestRequestConsumer) for
registering a RestRequestConsumer to the RestServer (
HttpRestServer).-
Nested Class Summary
Nested classes/interfaces inherited from interface ActionAccessor
ActionAccessor.ActionBuilder<A,B>, ActionAccessor.ActionMutator<A>, ActionAccessor.ActionProperty<A> Nested classes/interfaces inherited from interface BasicAuthCredentialsAccessor
BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>, BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, BasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyNested classes/interfaces inherited from interface HttpMethodAccessor
HttpMethodAccessor.HttpMethodBuilder<B>, HttpMethodAccessor.HttpMethodMutator, HttpMethodAccessor.HttpMethodPropertyNested classes/interfaces inherited from interface LocalAddressAccessor
LocalAddressAccessor.LocalAddressBuilder<B>, LocalAddressAccessor.LocalAddressMutator, LocalAddressAccessor.LocalAddressPropertyNested classes/interfaces inherited from interface RealmAccessor
RealmAccessor.RealmBuilder<B>, RealmAccessor.RealmMutator, RealmAccessor.RealmPropertyNested classes/interfaces inherited from interface RemoteAddressAccessor
RemoteAddressAccessor.RemoteAddressBuilder<B>, RemoteAddressAccessor.RemoteAddressMutator, RemoteAddressAccessor.RemoteAddressPropertyNested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> Nested classes/interfaces inherited from interface UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Constructor Summary
ConstructorsConstructorDescriptionBasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, Url aUrl, WildcardSubstitutes aWildcardSubstitutes, BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer) Instantiates a new basic auth event. -
Method Summary
Modifier and TypeMethodDescriptiongetRealm()String[]getWildcardReplacement(String aWildcardName) getWildcardReplacementAt(int aIndex) String[]String[]getWildcardReplacements(String... aWildcardNames) String[]getWildcardReplacementsAt(int... aIndexes) Methods inherited from class BasicAuthRequest
getBasicAuthCredentials, getHttpMethod, getUrl
-
Constructor Details
-
BasicAuthEvent
public BasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, Url aUrl, WildcardSubstitutes aWildcardSubstitutes, BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer) Instantiates a new basic auth event.- Parameters:
aLocalAddress- The local address where the event is being received.aRemoteAddress- The remote address from which the request originates.aHttpMethod- TheHttpMethodwith which the request has been sent.aUrl- TheUrlfrom which to take the URL specific data.aWildcardSubstitutes- The text being substituted by the wildcard of theRestEndpoint's Locator-Pattern.aCredentials- The credentials retrieved from the request.aRealm- The realm to which this request is being addressed.aRestServer- The system firing the event.
-
-
Method Details
-
getAction
- Specified by:
getActionin interfaceActionAccessor<HttpMethod>
-
getWildcardReplacements
- Specified by:
getWildcardReplacementsin interfaceWildcardSubstitutes
-
getWildcardReplacementAt
- Specified by:
getWildcardReplacementAtin interfaceWildcardSubstitutes
-
getWildcardReplacement
- Specified by:
getWildcardReplacementin interfaceWildcardSubstitutes
-
getWildcardReplacements
- Specified by:
getWildcardReplacementsin interfaceWildcardSubstitutes
-
getWildcardReplacementsAt
- Specified by:
getWildcardReplacementsAtin interfaceWildcardSubstitutes
-
getRemoteAddress
- Specified by:
getRemoteAddressin interfaceRemoteAddressAccessor
-
getLocalAddress
- Specified by:
getLocalAddressin interfaceLocalAddressAccessor
-
getRealm
- Specified by:
getRealmin interfaceRealmAccessor
-
getSource
- Specified by:
getSourcein interfaceSourceAccessor<RestServer>
-
getWildcardNames
- Specified by:
getWildcardNamesin interfaceWildcardSubstitutes
-