Class BasicAuthEventImpl

java.lang.Object
org.refcodes.web.BasicAuthRequestImpl
org.refcodes.rest.BasicAuthEventImpl
All Implemented Interfaces:
org.refcodes.matcher.WildcardSubstitutes, org.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>, org.refcodes.mixin.Dumpable, org.refcodes.mixin.SourceAccessor<RestServer>, org.refcodes.observer.GenericActionEvent<org.refcodes.web.HttpMethod,​RestServer>, org.refcodes.observer.GenericEvent<RestServer>, BasicAuthEvent, org.refcodes.web.BasicAuthCredentialsAccessor, org.refcodes.web.BasicAuthRequest, org.refcodes.web.HttpMethodAccessor, org.refcodes.web.LocalAddressAccessor, org.refcodes.web.RealmAccessor, org.refcodes.web.RemoteAddressAccessor, org.refcodes.web.UrlAccessor

public class BasicAuthEventImpl
extends org.refcodes.web.BasicAuthRequestImpl
implements BasicAuthEvent
The BasicAuthEventImpl class implements the BasicAuthEvent type.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor

    org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,​B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,​B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor

    org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty

    Nested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor

    org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B extends org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B>>, org.refcodes.web.HttpMethodAccessor.HttpMethodMutator, org.refcodes.web.HttpMethodAccessor.HttpMethodProperty

    Nested classes/interfaces inherited from interface org.refcodes.web.LocalAddressAccessor

    org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B extends org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B>>, org.refcodes.web.LocalAddressAccessor.LocalAddressMutator, org.refcodes.web.LocalAddressAccessor.LocalAddressProperty

    Nested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor

    org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmProperty

    Nested classes/interfaces inherited from interface org.refcodes.web.RemoteAddressAccessor

    org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B extends org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B>>, org.refcodes.web.RemoteAddressAccessor.RemoteAddressMutator, org.refcodes.web.RemoteAddressAccessor.RemoteAddressProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor

    org.refcodes.mixin.SourceAccessor.SourceMutator<SRC extends Object>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor

    org.refcodes.web.UrlAccessor.UrlBuilder, org.refcodes.web.UrlAccessor.UrlMutator, org.refcodes.web.UrlAccessor.UrlProperty
  • Constructor Summary

    Constructors
    Constructor Description
    BasicAuthEventImpl​(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer)  
  • Method Summary

    Methods inherited from class org.refcodes.web.BasicAuthRequestImpl

    getBasicAuthCredentials, getHttpMethod, getUrl

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor

    getBasicAuthCredentials

    Methods inherited from interface org.refcodes.rest.BasicAuthEvent

    getAction

    Methods inherited from interface org.refcodes.mixin.Dumpable

    toDump, toDump, toPrintable

    Methods inherited from interface org.refcodes.web.HttpMethodAccessor

    getHttpMethod

    Methods inherited from interface org.refcodes.web.UrlAccessor

    getUrl
  • Constructor Details

    • BasicAuthEventImpl

      public BasicAuthEventImpl​(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer)
      Parameters:
      aLocalAddress - The local address where the event is being received.
      aRemoteAddress - The remote address from which the request originates.
      aHttpMethod - The HttpMethod with which the request has been sent.
      aUrl - The Url from which to take the URL specific data.
      aWildcardSubstitutes - The text being substituted by the wildcard of the RestEndpoint's Locator-Pattern.
      aCredentials - The credentials retrieved from the request.
      aRealm - The realm to which this request is being addressed.
      aRestServer - The system firing the event.
  • Method Details

    • getWildcardReplacements

      public String[] getWildcardReplacements()
      Specified by:
      getWildcardReplacements in interface org.refcodes.matcher.WildcardSubstitutes
    • getWildcardReplacementAt

      public String getWildcardReplacementAt​(int aIndex)
      Specified by:
      getWildcardReplacementAt in interface org.refcodes.matcher.WildcardSubstitutes
    • getWildcardReplacement

      public String getWildcardReplacement​(String aWildcardName)
      Specified by:
      getWildcardReplacement in interface org.refcodes.matcher.WildcardSubstitutes
    • getWildcardReplacements

      public String[] getWildcardReplacements​(String... aWildcardNames)
      Specified by:
      getWildcardReplacements in interface org.refcodes.matcher.WildcardSubstitutes
    • getWildcardReplacementsAt

      public String[] getWildcardReplacementsAt​(int... aIndexes)
      Specified by:
      getWildcardReplacementsAt in interface org.refcodes.matcher.WildcardSubstitutes
    • getRemoteAddress

      public InetSocketAddress getRemoteAddress()
      Specified by:
      getRemoteAddress in interface org.refcodes.web.RemoteAddressAccessor
    • getLocalAddress

      public InetSocketAddress getLocalAddress()
      Specified by:
      getLocalAddress in interface org.refcodes.web.LocalAddressAccessor
    • getRealm

      public String getRealm()
      Specified by:
      getRealm in interface org.refcodes.web.RealmAccessor
    • getSource

      public RestServer getSource()
      Specified by:
      getSource in interface org.refcodes.mixin.SourceAccessor<RestServer>
    • getWildcardNames

      public String[] getWildcardNames()
      Specified by:
      getWildcardNames in interface org.refcodes.matcher.WildcardSubstitutes