Interface HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
- All Superinterfaces:
HttpExceptionHandlerAccessor, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
- All Known Subinterfaces:
HttpRestRegistryServer<DESC,B>, HttpRestServer
- All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator, AbstractHttpRestServerDecorator, JdkHttpRestServer, JdkHttpRestServerSingleton
- Enclosing interface:
HttpExceptionHandlerAccessor
public static interface HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
extends HttpExceptionHandlerAccessor, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
Extends the
HttpExceptionHandlerAccessor with a setter method.-
Nested Class Summary
Nested classes/interfaces inherited from interface HttpExceptionHandlerAccessor
HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B>, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator, HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault HttpExceptionHandlerletHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).Methods inherited from interface HttpExceptionHandlerAccessor
getHttpExceptionHandlerMethods inherited from interface HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
onHttpException, setHttpExceptionHandler
-
Method Details
-
letHttpExceptionHandler
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).- Parameters:
aHttpExceptionHandler- TheHttpExceptionHandlerto set (viaHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-