Enum Class HttpExceptionHandling

java.lang.Object
java.lang.Enum<HttpExceptionHandling>
org.refcodes.rest.HttpExceptionHandling
All Implemented Interfaces:
Serializable, Comparable<HttpExceptionHandling>, Constable

public enum HttpExceptionHandling extends Enum<HttpExceptionHandling>
Defines how errors affect the HTTP-Body whilst processing a HttpRequest or a HttpResponse along with the according sub-classes. Usually the following fields are written into the HTTP-Body (if possible): "timestamp", "status", "error": "Bad Request", "exception" and "message". Usually the causing exception's message is used for the "message" attribute: Make sure you do not reveal any sensible information in the exception's message.