Interface HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
All Known Subinterfaces:
HttpRestRegistryServer<DESC,B>, HttpRestServer
All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator, AbstractHttpRestServerDecorator, JdkHttpRestServer, JdkHttpRestServerSingleton
Enclosing interface:
HttpExceptionHandlingAccessor

public static interface HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>
Provides a builder method for a HttpExceptionHandling property returning the builder for applying multiple build operations.