Interface HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty
- All Superinterfaces:
HttpExceptionHandlingAccessor, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator
- All Known Subinterfaces:
HttpRestRegistryServer<DESC,B>, HttpRestServer
- All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator, AbstractHttpRestServerDecorator, JdkHttpRestServer, JdkHttpRestServerSingleton
- Enclosing interface:
HttpExceptionHandlingAccessor
public static interface HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty
extends HttpExceptionHandlingAccessor, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator
Extends the
HttpExceptionHandlingAccessor with a setter method.-
Nested Class Summary
Nested classes/interfaces inherited from interface HttpExceptionHandlingAccessor
HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator, HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault HttpExceptionHandlingletHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).Methods inherited from interface HttpExceptionHandlingAccessor
getHttpExceptionHandlingMethods inherited from interface HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator
setHttpExceptionHandling
-
Method Details
-
letHttpExceptionHandling
default HttpExceptionHandling letHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).- Parameters:
aHttpExceptionHandling- TheHttpExceptionHandlingto set (viaHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-