Interface HttpRegistryContext<DESC extends HttpServerDescriptor>
- Type Parameters:
DESC- TheHttpServerDescriptorwhich describes a server to be registered at a discovery registry so clients can resolve the server's URL.
- All Superinterfaces:
HttpRegistryUrlAccessor, HttpServerDescriptorAccessor<DESC>, PingRequestObserverAccessor, TrustStoreDescriptorAccessor
public interface HttpRegistryContext<DESC extends HttpServerDescriptor>
extends HttpRegistryUrlAccessor, TrustStoreDescriptorAccessor, HttpServerDescriptorAccessor<DESC>, PingRequestObserverAccessor
This context describes all information required to register a server
("service") at a service discovery registry.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheHttpRegistryContext.HttpRegistryContextBuilderinterface extends theHttpRegistryContextwith builder functionality as of the builder pattern.Nested classes/interfaces inherited from interface HttpRegistryUrlAccessor
HttpRegistryUrlAccessor.HttpRegistryUrlBuilder<B>, HttpRegistryUrlAccessor.HttpRegistryUrlMutator, HttpRegistryUrlAccessor.HttpRegistryUrlPropertyNested classes/interfaces inherited from interface HttpServerDescriptorAccessor
HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC,B>, HttpServerDescriptorAccessor.HttpServerDescriptorMutator<DESC>, HttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC> Nested classes/interfaces inherited from interface PingRequestObserverAccessor
PingRequestObserverAccessor.PingRequestObserverBuilder<B>, PingRequestObserverAccessor.PingRequestObserverMutator, PingRequestObserverAccessor.PingRequestObserverPropertyNested classes/interfaces inherited from interface TrustStoreDescriptorAccessor
TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>, TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty -
Method Summary
Methods inherited from interface HttpRegistryUrlAccessor
getHttpRegistryUrlMethods inherited from interface HttpServerDescriptorAccessor
getHttpServerDescriptorMethods inherited from interface PingRequestObserverAccessor
getPingRequestObserverMethods inherited from interface TrustStoreDescriptorAccessor
getTrustStoreDescriptor