Interface HttpRestClient
- All Superinterfaces:
org.refcodes.web.BaseUrlAccessor,org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>,org.refcodes.web.BaseUrlAccessor.BaseUrlMutator,org.refcodes.web.BaseUrlAccessor.BaseUrlProperty,org.refcodes.web.BasicAuthCredentialsAccessor,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestClient>,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty,org.refcodes.component.Closable,org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpClientContext>,org.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpClientContext>,org.refcodes.component.ConnectionStatusAccessor,DeleteRestClient,GetRestClient,org.refcodes.web.HttpClientInterceptable,org.refcodes.component.LinkComponent,org.refcodes.web.MediaTypeFactoryLookup,org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup,org.refcodes.web.OauthTokenAccessor,org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<RestClient>,org.refcodes.web.OauthTokenAccessor.OauthTokenMutator,org.refcodes.web.OauthTokenAccessor.OauthTokenProperty,org.refcodes.component.Openable,org.refcodes.component.Openable.OpenBuilder<HttpRestClient>,org.refcodes.component.OpenedAccessor,org.refcodes.web.PostHttpClientInterceptable,org.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpClientInterceptor>,PostRestClient,org.refcodes.web.PreHttpClientInterceptable,org.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpClientInterceptor>,PutRestClient,RestClient,RestRequestClient,RestRequestHandler,org.refcodes.security.TrustStoreDescriptorAccessor,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpRestClient>,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty,org.refcodes.web.UserAgentAccessor,org.refcodes.web.UserAgentAccessor.UserAgentBuilder<RestClient>,org.refcodes.web.UserAgentAccessor.UserAgentMutator,org.refcodes.web.UserAgentAccessor.UserAgentProperty
- All Known Subinterfaces:
HttpRestDiscoveryClient<B>
- All Known Implementing Classes:
AbstractHttpRestClientDecorator,AbstractHttpRestDiscoveryClientDecorator,JdkHttpRestClient,JdkHttpRestClientSingleton
public interface HttpRestClient
extends RestClient, org.refcodes.web.HttpClientInterceptable, org.refcodes.component.ConnectionStatusAccessor, org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpClientContext>, org.refcodes.component.LinkComponent, org.refcodes.component.Openable.OpenBuilder<HttpRestClient>, org.refcodes.web.BaseUrlAccessor.BaseUrlProperty, org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpRestClient>
Extends a
RestClient to be capable of providing a User-Agent with
UserAgentAccessor.UserAgentMutator.setUserAgent(String) (withUserAgent(String)) and to be
capable of using base URLs to be set with BaseUrlAccessor.BaseUrlMutator.setBaseUrl(String) (
withBaseUrl(String)). This type is intended to be used by different
separate hierarchy branches by providing the generic type <B>, ensuring
a coherent type hierarchy for each branch. To prepare HTTPS connections, use
the methods such as: open(Url, TrustStoreDescriptor) or
open(HttpClientContext). A HttpRestClient can be shutdown
via Closable.close().-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.BaseUrlAccessor
org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<B extends org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<B>>, org.refcodes.web.BaseUrlAccessor.BaseUrlMutator, org.refcodes.web.BaseUrlAccessor.BaseUrlPropertyNested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyNested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionComponent
org.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionOpenable
org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.LinkComponent
org.refcodes.component.LinkComponent.LinkAutomaton, org.refcodes.component.LinkComponent.LinkComponentBuilder<B extends org.refcodes.component.LinkComponent.LinkComponentBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.web.MediaTypeFactoryLookup
org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookupNested classes/interfaces inherited from interface org.refcodes.web.OauthTokenAccessor
org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<B extends org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<B>>, org.refcodes.web.OauthTokenAccessor.OauthTokenMutator, org.refcodes.web.OauthTokenAccessor.OauthTokenPropertyNested classes/interfaces inherited from interface org.refcodes.component.Openable
org.refcodes.component.Openable.OpenAutomaton, org.refcodes.component.Openable.OpenBuilder<B extends org.refcodes.component.Openable.OpenBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedPropertyNested classes/interfaces inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.web.UserAgentAccessor
org.refcodes.web.UserAgentAccessor.UserAgentBuilder<B extends org.refcodes.web.UserAgentAccessor.UserAgentBuilder<B>>, org.refcodes.web.UserAgentAccessor.UserAgentMutator, org.refcodes.web.UserAgentAccessor.UserAgentProperty -
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptiondefault voidopen()default voidopen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default voidopen(org.refcodes.web.HttpClientContext aCtx) default voidopen(org.refcodes.web.Url aBaseUrl) Configures the HTTPS client connection with the provided configuration parameters.voidopen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientwithBaseUrl(String aBaseUrl) default HttpRestClientwithBaseUrl(URL aBaseURL) default HttpRestClientwithBaseUrl(org.refcodes.web.Url aBaseUrl) default HttpRestClientwithBasicAuthCredentials(String aUserName, String aSecret) default HttpRestClientwithBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) default HttpRestClientwithOAuthToken(org.refcodes.web.OauthToken aOauthToken) default HttpRestClientwithOpen()Open the component's connection(s).default HttpRestClientwithOpen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientwithOpen(org.refcodes.web.HttpClientContext aCtx) Opens the component with the given connection.default HttpRestClientwithOpen(org.refcodes.web.Url aBaseUrl) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientwithOpen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientwithTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) default HttpRestClientwithUserAgent(String aUserAgent) Methods inherited from interface org.refcodes.web.BaseUrlAccessor
getBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder
withBaseUrl, withBaseUrl, withBaseUrl, withBaseUrl, withBaseUrl, withBaseUrl, withBaseUrl, withBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlMutator
setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlProperty
letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrlMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
getBasicAuthCredentialsMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
setBasicAuthCredentials, setBasicAuthCredentialsMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
letBasicAuthCredentials, letBasicAuthCredentialsMethods inherited from interface org.refcodes.component.Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable
openUncheckedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpenedMethods inherited from interface org.refcodes.rest.DeleteRestClient
buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDeleteMethods inherited from interface org.refcodes.rest.GetRestClient
buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGetMethods inherited from interface org.refcodes.web.HttpClientInterceptable
addHttpInterceptor, hasHttpInterceptor, removeHttpInterceptorMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup
getFactoryMediaTypes, hasMediaTypeFactory, toMediaTypeFactoryMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup
addMediaTypeFactoryMethods inherited from interface org.refcodes.web.OauthTokenAccessor
getOauthTokenMethods inherited from interface org.refcodes.web.OauthTokenAccessor.OauthTokenMutator
setOauthTokenMethods inherited from interface org.refcodes.web.OauthTokenAccessor.OauthTokenProperty
letOauthTokenMethods inherited from interface org.refcodes.component.Openable
openUncheckedMethods inherited from interface org.refcodes.component.Openable.OpenBuilder
withOpenUncheckedMethods inherited from interface org.refcodes.web.PostHttpInterceptable
addPostHttpInterceptor, hasPostHttpInterceptor, removePostHttpInterceptorMethods inherited from interface org.refcodes.rest.PostRestClient
buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPostMethods inherited from interface org.refcodes.web.PreHttpInterceptable
addPreHttpInterceptor, hasPreHttpInterceptor, removePreHttpInterceptorMethods inherited from interface org.refcodes.rest.PutRestClient
buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPutMethods inherited from interface org.refcodes.rest.RestRequestClient
buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponseMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
getTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator
setTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
letTrustStoreDescriptorMethods inherited from interface org.refcodes.web.UserAgentAccessor
getUserAgentMethods inherited from interface org.refcodes.web.UserAgentAccessor.UserAgentMutator
setUserAgentMethods inherited from interface org.refcodes.web.UserAgentAccessor.UserAgentProperty
letUserAgent
-
Field Details
-
DEFAULT_KEYSTORE_TYPE
-
DEFAULT_SSL_PROTOCOL
- See Also:
-
-
Method Details
-
open
- Specified by:
openin interfaceorg.refcodes.component.Openable- Throws:
IOException
-
open
- Specified by:
openin interfaceorg.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpClientContext>- Throws:
IOException
-
open
Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Throws:
IOException- thrown in case something went wrong.
-
open
Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aBaseUrl- The baseUrlto be used.- Throws:
IOException- thrown in case something went wrong.
-
open
void open(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aBaseUrl- The baseUrlto be used.aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Throws:
IOException- thrown in case something went wrong.
-
withOpen
Open the component's connection(s).- Specified by:
withOpenin interfaceorg.refcodes.component.Openable.OpenBuilder<HttpRestClient>- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
withOpen
Opens the component with the given connection.- Parameters:
aCtx- The context used for opening the connection.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
withOpen
default HttpRestClient withOpen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withOpen
Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aBaseUrl- The baseUrlto be used.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withOpen
default HttpRestClient withOpen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Parameters:
aBaseUrl- The baseUrlto be used.aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>- Throws:
MalformedURLException
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>
-
withBasicAuthCredentials
default HttpRestClient withBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) - Specified by:
withBasicAuthCredentialsin interfaceorg.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestClient>
-
withBasicAuthCredentials
- Specified by:
withBasicAuthCredentialsin interfaceorg.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestClient>
-
withOAuthToken
- Specified by:
withOAuthTokenin interfaceorg.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<RestClient>
-
withTrustStoreDescriptor
default HttpRestClient withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) - Specified by:
withTrustStoreDescriptorin interfaceorg.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpRestClient>
-
withUserAgent
- Specified by:
withUserAgentin interfaceorg.refcodes.web.UserAgentAccessor.UserAgentBuilder<RestClient>
-