Interface HttpServerDescriptor
- All Superinterfaces:
AliasAccessor, HostAccessor, IpAddressAccessor, PingUrlAccessor, PortAccessor
- All Known Subinterfaces:
HttpServerDescriptor.HttpServerDescriptorBuilder<B>
public interface HttpServerDescriptor
extends AliasAccessor, PingUrlAccessor, PortAccessor, HostAccessor, IpAddressAccessor
The
HttpServerDescriptor describes a server to be registered at a
discovery registry so clients can resolve the server's URL.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceHttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>TheHttpServerDescriptor.HttpServerDescriptorBuilderinterface extends theHttpServerDescriptorinterface with builder functionality as of the builder pattern.Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface HostAccessor
HostAccessor.HostBuilder<B>, HostAccessor.HostMutator, HostAccessor.HostPropertyNested classes/interfaces inherited from interface IpAddressAccessor
IpAddressAccessor.IpAddressBuilder<B>, IpAddressAccessor.IpAddressMutator, IpAddressAccessor.IpAddressPropertyNested classes/interfaces inherited from interface PingUrlAccessor
PingUrlAccessor.PingUrlBuilder<B>, PingUrlAccessor.PingUrlMutator, PingUrlAccessor.PingUrlPropertyNested classes/interfaces inherited from interface PortAccessor
PortAccessor.PortBuilder<B>, PortAccessor.PortMutator, PortAccessor.PortProperty -
Method Summary
Methods inherited from interface AliasAccessor
getAliasMethods inherited from interface HostAccessor
getHostMethods inherited from interface IpAddressAccessor
getIpAddress, toCidrNotationMethods inherited from interface PingUrlAccessor
getPingUrlMethods inherited from interface PortAccessor
getPort