Interface HttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
- Type Parameters:
B- the generic type
- All Superinterfaces:
AliasAccessor, AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasProperty, HostAccessor, HostAccessor.HostBuilder<B>, HostAccessor.HostMutator, HostAccessor.HostProperty, HttpServerDescriptor, IpAddressAccessor, IpAddressAccessor.IpAddressBuilder<B>, IpAddressAccessor.IpAddressMutator, IpAddressAccessor.IpAddressProperty, PingUrlAccessor, PingUrlAccessor.PingUrlBuilder<B>, PingUrlAccessor.PingUrlMutator, PingUrlAccessor.PingUrlProperty, PortAccessor, PortAccessor.PortBuilder<B>, PortAccessor.PortMutator, PortAccessor.PortProperty, VirtualHostAccessor, VirtualHostAccessor.VirtualHostBuilder<B>, VirtualHostAccessor.VirtualHostMutator, VirtualHostAccessor.VirtualHostProperty
- Enclosing interface:
HttpServerDescriptor
public static interface HttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
extends HttpServerDescriptor, IpAddressAccessor.IpAddressProperty, IpAddressAccessor.IpAddressBuilder<B>, HostAccessor.HostProperty, HostAccessor.HostBuilder<B>, VirtualHostAccessor.VirtualHostProperty, VirtualHostAccessor.VirtualHostBuilder<B>, PortAccessor.PortProperty, PortAccessor.PortBuilder<B>, PingUrlAccessor.PingUrlProperty, PingUrlAccessor.PingUrlBuilder<B>, AliasAccessor.AliasProperty, AliasAccessor.AliasBuilder<B>
The
HttpServerDescriptor.HttpServerDescriptorBuilder interface extends the
HttpServerDescriptor interface with builder functionality as of
the builder pattern.-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface HostAccessor
HostAccessor.HostBuilder<B>, HostAccessor.HostMutator, HostAccessor.HostPropertyNested classes/interfaces inherited from interface HttpServerDescriptor
HttpServerDescriptor.HttpServerDescriptorBuilder<B>Nested classes/interfaces inherited from interface IpAddressAccessor
IpAddressAccessor.IpAddressBuilder<B>, IpAddressAccessor.IpAddressMutator, IpAddressAccessor.IpAddressPropertyNested classes/interfaces inherited from interface PingUrlAccessor
PingUrlAccessor.PingUrlBuilder<B>, PingUrlAccessor.PingUrlMutator, PingUrlAccessor.PingUrlPropertyNested classes/interfaces inherited from interface PortAccessor
PortAccessor.PortBuilder<B>, PortAccessor.PortMutator, PortAccessor.PortPropertyNested classes/interfaces inherited from interface VirtualHostAccessor
VirtualHostAccessor.VirtualHostBuilder<B>, VirtualHostAccessor.VirtualHostMutator, VirtualHostAccessor.VirtualHostProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault Bdefault BwithCidrNotation(String aCidrNotation) default Bdefault BwithIpAddress(int[] aIpAddress) default BwithPingUrl(Url aUrl) Sets the pingUrlto use and returns this builder as of the builder pattern.default BwithPort(int aPort) default BwithVirtualHost(String aVirtualHost) Methods inherited from interface AliasAccessor
getAliasMethods inherited from interface AliasAccessor.AliasMutator
setAliasMethods inherited from interface AliasAccessor.AliasProperty
letAliasMethods inherited from interface HostAccessor
getHostMethods inherited from interface HostAccessor.HostMutator
setHostMethods inherited from interface HostAccessor.HostProperty
letHostMethods inherited from interface IpAddressAccessor
getIpAddress, toCidrNotationMethods inherited from interface IpAddressAccessor.IpAddressMutator
fromCidrNotation, setIpAddressMethods inherited from interface IpAddressAccessor.IpAddressProperty
letIpAddressMethods inherited from interface PingUrlAccessor
getPingUrlMethods inherited from interface PingUrlAccessor.PingUrlMutator
setPingUrlMethods inherited from interface PingUrlAccessor.PingUrlProperty
letPingUrlMethods inherited from interface PortAccessor
getPortMethods inherited from interface PortAccessor.PortMutator
setPortMethods inherited from interface PortAccessor.PortProperty
letPortMethods inherited from interface VirtualHostAccessor
getVirtualHostMethods inherited from interface VirtualHostAccessor.VirtualHostMutator
setVirtualHostMethods inherited from interface VirtualHostAccessor.VirtualHostProperty
letVirtualHost
-
Method Details
-
withAlias
- Specified by:
withAliasin interfaceAliasAccessor.AliasBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withIpAddress
- Specified by:
withIpAddressin interfaceIpAddressAccessor.IpAddressBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withPingUrl
Sets the pingUrlto use and returns this builder as of the builder pattern.- Specified by:
withPingUrlin interfacePingUrlAccessor.PingUrlBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>- Parameters:
aUrl- The pingUrlto be stored by the pingUrlproperty.- Returns:
- This
PingUrlAccessor.PingUrlBuilderinstance to continue configuration.
-
withCidrNotation
- Specified by:
withCidrNotationin interfaceIpAddressAccessor.IpAddressBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withPort
- Specified by:
withPortin interfacePortAccessor.PortBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withHost
- Specified by:
withHostin interfaceHostAccessor.HostBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withVirtualHost
- Specified by:
withVirtualHostin interfaceVirtualHostAccessor.VirtualHostBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-