Module org.refcodes.rest
Package org.refcodes.rest
Interface HttpServerDescriptorAccessor<DESC extends HttpServerDescriptor>
- Type Parameters:
DESC- TheHttpServerDescriptor(sub-)type of the truststore descriptor.
- All Known Subinterfaces:
HttpRegistry<DESC,B>,HttpRegistryContext<DESC>,HttpRegistryContext.HttpRegistryContextBuilder<DESC>,HttpRegistryRestServer<DESC,B>,HttpRegistrySidecar<DESC,B>,HttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC>
- All Known Implementing Classes:
AbstractHttpRegistryContextBuilder,AbstractHttpRegistryRestServerDecorator,AbstractHttpRegistrySidecar
public interface HttpServerDescriptorAccessor<DESC extends HttpServerDescriptor>
Provides an accessor for a
HttpServerDescriptor property.-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC extends HttpServerDescriptor,B extends HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC,B>>Provides a builder method for aHttpServerDescriptorproperty returning the builder for applying multiple build operations.static interfaceHttpServerDescriptorAccessor.HttpServerDescriptorMutator<DESC extends HttpServerDescriptor>Provides a mutator for aHttpServerDescriptorproperty.static interfaceHttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC extends HttpServerDescriptor>Provides aHttpServerDescriptorproperty. -
Method Summary
Modifier and Type Method Description DESCgetHttpServerDescriptor()Retrieves theHttpServerDescriptorfrom theHttpServerDescriptorproperty.
-
Method Details
-
getHttpServerDescriptor
DESC getHttpServerDescriptor()Retrieves theHttpServerDescriptorfrom theHttpServerDescriptorproperty.- Returns:
- The
HttpServerDescriptorstored by theHttpServerDescriptorproperty.
-