Interface HttpServerDescriptorFactory<DESC extends HttpServerDescriptor>
- Type Parameters:
DESC- The type of the server discovery descriptor (the object describing your service and locating the service registry).
- All Known Subinterfaces:
HttpRegistry<DESC,B>, HttpRegistrySidecar<DESC, B>, HttpRestRegistryServer<DESC, B>
- All Known Implementing Classes:
AbstractHttpRegistrySidecar, AbstractHttpRestRegistryServerDecorator
public interface HttpServerDescriptorFactory<DESC extends HttpServerDescriptor>
The
HttpServerDescriptorFactory provides factory functionality for
creating HttpServerDescriptor instances.-
Method Summary
Modifier and TypeMethodDescriptiondefault DESCPrepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments.default DESCtoHttpServerDescriptor(String aAlias, String aInstanceId, Scheme aScheme, int aPort) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments.toHttpServerDescriptor(String aAlias, String aInstanceId, Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments.default DESCtoHttpServerDescriptor(String aAlias, Scheme aScheme, String aHost, int aPort) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments.default DESCtoHttpServerDescriptor(String aAlias, Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments.
-
Method Details
-
toHttpServerDescriptor
Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments. The provided arguments can modify the instance's state. TheHttpServerDescriptoras finally used is returned. You may modify this context and use it after modification to initialize the according server viaHttpRegistry.initialize(HttpServerDescriptor, Url)orHttpRegistry.initialize(HttpServerDescriptor, Url, TrustStoreDescriptor).- Returns:
- The
HttpServerDescriptoras would be used when initializing the according server viaHttpRegistry.initialize()
-
toHttpServerDescriptor
Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments. The provided arguments can modify the instance's state. TheHttpServerDescriptoras finally used is returned. You may modify this context and use it after modification to initialize the according server viaHttpRegistry.initialize(HttpServerDescriptor, Url)orHttpRegistry.initialize(HttpServerDescriptor, Url, TrustStoreDescriptor).- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aInstanceId- The TID for the instance when being registered at the service registry. If omitted, then the host name is used.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aPort- The port of your service being registered.- Returns:
- The
HttpServerDescriptoras would be used when initializing the according server viaHttpRegistry.initialize()
-
toHttpServerDescriptor
Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments. The provided arguments can modify the instance's state. TheHttpServerDescriptoras finally used is returned. You may modify this context and use it after modification to initialize the according server viaHttpRegistry.initialize(HttpServerDescriptor, Url)orHttpRegistry.initialize(HttpServerDescriptor, Url, TrustStoreDescriptor).- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aHost- The host name to be used to address this server. If omitted, then the system's host name should be used.aPort- The port of your service being registered. Make sure, you do not- Returns:
- The
HttpServerDescriptoras would be used when initializing the according server viaHttpRegistry.initialize()
-
toHttpServerDescriptor
default DESC toHttpServerDescriptor(String aAlias, Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments. The provided arguments can modify the instance's state. TheHttpServerDescriptoras finally used is returned. You may modify this context and use it after modification to initialize the according server viaHttpRegistry.initialize(HttpServerDescriptor, Url)orHttpRegistry.initialize(HttpServerDescriptor, Url, TrustStoreDescriptor).- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aHost- The host name to be used to address this server. If omitted, then the system's host name should be used.aVirtualHost- The virtual host name to be used for resolving.aIpAddress- The IP-Address identifying the host.aPort- The port of your service being registered. Make sure, you do notaPingPath- The path to use as health-check end-point by this server.- Returns:
- The
HttpServerDescriptoras would be used when initializing the according server viaHttpRegistry.initialize()
-
toHttpServerDescriptor
DESC toHttpServerDescriptor(String aAlias, String aInstanceId, Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath) Prepares theHttpServerDescriptorby creating it from this instance's state and the provided arguments. The provided arguments can modify the instance's state. TheHttpServerDescriptoras finally used is returned. You may modify this context and use it after modification to initialize the according server viaHttpRegistry.initialize(HttpServerDescriptor, Url)orHttpRegistry.initialize(HttpServerDescriptor, Url, TrustStoreDescriptor).- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aInstanceId- The TID for the instance when being registered at the service registry. If omitted, then the host name is used.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aHost- The host name to be used to address this server. If omitted, then the system's host name should be used.aVirtualHost- The virtual host name to be used for resolving.aIpAddress- The IP-Address identifying the host.aPort- The port of your service being registered. Make sure, you do notaPingPath- The path to use as health-check end-point by this server.- Returns:
- The
HttpServerDescriptoras would be used when initializing the according server viaHttpRegistry.initialize()
-