Class OauthTokenHandler

java.lang.Object
org.refcodes.web.OauthToken
org.refcodes.rest.OauthTokenHandler
All Implemented Interfaces:
org.refcodes.mixin.Disposable, org.refcodes.mixin.ValidAccessor

public class OauthTokenHandler extends org.refcodes.web.OauthToken
Self refreshing implementation of the OauthToken. In case a refresh token (as of OauthToken.getRefreshToken() and has been provided, then the access token (as of OauthToken.getAccessToken() is refreshed within the "expires in" time (as of OauthToken.getExpiresIn(). The refresh daemon terminates and this instance is disposed when the provided RestfulHttpClient's Closable.close() method is called or the dispose() method is invoked.