-
- All Known Subinterfaces:
HttpRegistryContext<DESC>,HttpRegistryContext.HttpRegistryContextBuilder<DESC>,HttpRegistryRestServer<DESC,B>,PingRequestObserverAccessor.PingRequestObserverProperty
- All Known Implementing Classes:
AbstractHttpRegistryContextBuilder,AbstractHttpRegistryRestServerDecorator
public interface PingRequestObserverAccessorProvides an accessor for a pingRestRequestConsumerproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePingRequestObserverAccessor.PingRequestObserverBuilder<B extends PingRequestObserverAccessor.PingRequestObserverBuilder<B>>Provides a builder method for a pingRestRequestConsumerproperty returning the builder for applying multiple build operations.static interfacePingRequestObserverAccessor.PingRequestObserverMutatorProvides a mutator for a pingRestRequestConsumerproperty.static interfacePingRequestObserverAccessor.PingRequestObserverPropertyProvides a pingRestRequestConsumerproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description RestRequestConsumergetPingRequestObserver()Retrieves the pingRestRequestConsumerfrom the pingRestRequestConsumerproperty.
-
-
-
Method Detail
-
getPingRequestObserver
RestRequestConsumer getPingRequestObserver()
Retrieves the pingRestRequestConsumerfrom the pingRestRequestConsumerproperty.- Returns:
- The ping
RestRequestConsumerstored by the pingRestRequestConsumerproperty.
-
-