Module org.refcodes.rest
Package org.refcodes.rest
Interface PingRequestObserverAccessor.PingRequestObserverBuilder<B extends PingRequestObserverAccessor.PingRequestObserverBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
HttpRegistryContext.HttpRegistryContextBuilder<DESC>,HttpRegistryRestServer<DESC,B>
- All Known Implementing Classes:
AbstractHttpRegistryContextBuilder,AbstractHttpRegistryRestServerDecorator
- Enclosing interface:
- PingRequestObserverAccessor
public static interface PingRequestObserverAccessor.PingRequestObserverBuilder<B extends PingRequestObserverAccessor.PingRequestObserverBuilder<B>>Provides a builder method for a pingRestRequestConsumerproperty returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithPingRequestObserver(RestRequestConsumer aRequestConsumer)Sets the pingRestRequestConsumerfor the pingRestRequestConsumerproperty.
-
-
-
Method Detail
-
withPingRequestObserver
B withPingRequestObserver(RestRequestConsumer aRequestConsumer)
Sets the pingRestRequestConsumerfor the pingRestRequestConsumerproperty.- Parameters:
aRequestConsumer- The pingRestRequestConsumerto be stored by the pingRestRequestConsumerproperty.- Returns:
- The builder for applying multiple build operations.
-
-