Interface RestClient

All Superinterfaces:
BasicAuthCredentialsAccessor, BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestClient>, BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty, DeleteRestClient, GetRestClient, MediaTypeFactoryLookup, MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup, OauthTokenAccessor, OauthTokenAccessor.OauthTokenBuilder<RestClient>, OauthTokenAccessor.OauthTokenMutator, OauthTokenAccessor.OauthTokenProperty, PostRestClient, PutRestClient, RestRequestClient, RestRequestHandler, UserAgentAccessor, UserAgentAccessor.UserAgentBuilder<RestClient>, UserAgentAccessor.UserAgentMutator, UserAgentAccessor.UserAgentProperty
All Known Subinterfaces:
HttpRestClient, HttpRestDiscoveryClient<B>
All Known Implementing Classes:
AbstractHttpRestClientDecorator, AbstractHttpRestDiscoveryClientDecorator, AbstractRestClient, JdkHttpRestClient, JdkHttpRestClientSingleton, LoopbackRestClient, LoopbackRestClientSingleton

A client to send requests for communicating with a RESTful server such as the HttpRestServer. For marshaling and unmarshaling HTTP bodies you have to register the according MediaTypeFactory instances being capable of handling the according MediaType definitions. Examples for ready to use MediaTypeFactory implementations are

Implementations of the RestClient interface, such as the JdkHttpRestClient, are initialized with some common MediaTypeFactory instances. You may set an individual User-Agent via UserAgentAccessor.UserAgentMutator.setUserAgent(String), not setting it will result in the default User-Agent to be set as coded into the RestClient implementations.