Class RestRequest

All Implemented Interfaces:
HeaderFieldsAccessor<RequestHeaderFields>, HeaderFieldsAccessor.HeaderFieldsMutator<RequestHeaderFields>, HeaderFieldsAccessor.HeaderFieldsProperty<RequestHeaderFields>, HttpBodyAccessor.HttpBodyProvider<BadRequestException>, HttpMethodAccessor, HttpRequest, RedirectDepthAccessor, RedirectDepthAccessor.RedirectDepthMutator, RedirectDepthAccessor.RedirectDepthProperty, UrlAccessor
Direct Known Subclasses:
RestRequestBuilder

A RestRequest describes a REST request and the RestResponse providing the response. The RestRequest describes the HttpMethod to be used, the targeted URL, the HeaderFields as well as the Query-Fields and the request Object or InputStream.
  • Constructor Details

    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aHeaderFields - the Header-Fields
      aRequest - the request
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aRequest - the request
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 represents the default behavior, e.g. using HttpURLConnection's redirection means.
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aRequest - the request
      aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 represents the default behavior, e.g. using HttpURLConnection's redirection means.
      aRestClient - the rest client
    • RestRequest

      protected RestRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, RestClient aRestClient)
      Instantiates a new rest request builder impl.
      Parameters:
      aHttpMethod - the http method
      aUrl - The Url from which to take the URL specific data.
      aHeaderFields - the Header-Fields
      aRequest - the request
      aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 represents the default behavior, e.g. using HttpURLConnection's redirection means.
      aRestClient - the rest client
  • Method Details