Interface RestRequestConsumer

All Known Subinterfaces:
RestEndpoint
All Known Implementing Classes:
RestEndpointBuilder
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface RestRequestConsumer
The RestRequestConsumer can be coded using the lambda syntax and processes a request for a given locator and for a given HttpMethod. A RestRequestConsumer is invoked with a request of type RestRequestEvent and a response being of type HttpServerResponse. The RestRequestEvent describes the context of the request whereas the HttpServerResponse is used by the lambda expression to prepare the response e.g. via HttpServerResponse.setResponse(Object).