Interface RestRequestHandler

All Known Subinterfaces:
DeleteRestClient, GetRestClient, HttpRestClient, HttpRestDiscoveryClient<B>, PostRestClient, PutRestClient, RestClient, RestRequestClient
All Known Implementing Classes:
AbstractHttpRestClientDecorator, AbstractHttpRestDiscoveryClientDecorator, AbstractRestClient, JdkHttpRestClient, JdkHttpRestClientSingleton, LoopbackRestClient, LoopbackRestClientSingleton
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface RestRequestHandler
A RestRequestHandler handles a REST request on the RestClient instance's side to do the actual technical implementation of sending that request (or mocking the send-out of a request).
  • Method Summary

    Modifier and Type
    Method
    Description
    doRequest(HttpClientRequest aHttpClientRequest)
    Hook receiving a prepared RestResponseHandler instance to be used to do the technical request with the technology chosen by the implementing sub-class.