Class RestResponseHandler

All Implemented Interfaces:
Closable, Closable.CloseBuilder<LinkComponent.LinkComponentBuilder<RestResponseHandler>>, ConnectionStatusAccessor, LinkComponent, LinkComponent.LinkComponentBuilder<RestResponseHandler>, Openable, Openable.OpenBuilder<LinkComponent.LinkComponentBuilder<RestResponseHandler>>, OpenedAccessor, RestResponseConsumer, HeaderFieldsAccessor<RequestHeaderFields>, HeaderFieldsAccessor.HeaderFieldsBuilder<RequestHeaderFields, RestResponseHandler>, HeaderFieldsAccessor.HeaderFieldsMutator<RequestHeaderFields>, HeaderFieldsAccessor.HeaderFieldsProperty<RequestHeaderFields>, HttpBodyAccessor.HttpBodyProvider<BadRequestException>, HttpMethodAccessor, HttpMethodAccessor.HttpMethodBuilder<RestResponseHandler>, HttpMethodAccessor.HttpMethodMutator, HttpMethodAccessor.HttpMethodProperty, HttpRequest, HttpRequestBuilder<RestResponseHandler>, QueryFieldsAccessor, QueryFieldsAccessor.QueryFieldsMutator, QueryFieldsAccessor.QueryFieldsProperty, RedirectDepthAccessor, RedirectDepthAccessor.RedirectDepthBuilder<RestResponseHandler>, RedirectDepthAccessor.RedirectDepthMutator, RedirectDepthAccessor.RedirectDepthProperty, UrlAccessor, UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator

A RestResponseHandler describes a REST request and the RestResponseConsumer in charge for handling a REST response. The RestResponseHandler describes the HttpMethod to be used, the targeted URL, the HeaderFields as well as the Query-Fields and the request Object or InputStream. It provides builder functionality and lambda support for handling the responses addressed to this RestResponseHandler. The lambda defined as RestResponseConsumer acts as the single listener to this RestResponseHandler responsible for handling the responses for which this RestResponseHandler is responsible. The locator to which a RestResponseHandler targets for is defined by the getUrl() property.