Interface RestServer

All Superinterfaces:
BaseLocatorAccessor, BaseLocatorAccessor.BaseLocatorBuilder<RestServer>, BaseLocatorAccessor.BaseLocatorMutator, BaseLocatorAccessor.BaseLocatorProperty, MediaTypeFactoryLookup, MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup, Observable<RestEndpoint>, Observers<RestEndpoint, RestServer>, RealmAccessor, RealmAccessor.RealmBuilder<RestServer>, RealmAccessor.RealmMutator, RealmAccessor.RealmProperty
All Known Subinterfaces:
HttpRestRegistryServer<DESC,B>, HttpRestServer
All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator, AbstractHttpRestServerDecorator, AbstractRestServer, JdkHttpRestServer, JdkHttpRestServerSingleton, LoopbackRestServer, LoopbackRestServerSingleton

The RestServer acts as the target for clients issuing REST requests. RestEndpointBuilder instances, most easily being created with the onRequest(HttpMethod, String, RestRequestConsumer) method (or the like), are registered as listeners to the RestServer ( HttpRestServer). The RestServer (HttpRestServer) fires RestRequestEvent events to the RestRequestConsumers of an RestEndpoint dedicated to an according locator (pattern) for a specific HttpMethod.