Interface RestfulHttpServer

All Superinterfaces:
org.refcodes.web.BaseLocatorAccessor, org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<RestfulServer>, org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator, org.refcodes.web.BaseLocatorAccessor.BaseLocatorProperty, org.refcodes.web.BasicAuthObservable<RestfulHttpServer>, org.refcodes.component.Closable, org.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,RestfulHttpServer>>, org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpServerContext>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,RestfulHttpServer>, org.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpServerContext>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<org.refcodes.web.HttpServerContext,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,RestfulHttpServer>>, org.refcodes.component.ConnectionStatusAccessor, HttpExceptionHandlerAccessor, HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<RestfulHttpServer>, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator, HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty, HttpExceptionHandlingAccessor, HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<RestfulHttpServer>, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator, HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty, org.refcodes.web.HttpsConnectionRequestObservable<RestfulHttpServer>, org.refcodes.web.HttpServerInterceptable, org.refcodes.security.KeyStoreDescriptorAccessor, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<RestfulHttpServer>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty, org.refcodes.component.LinkComponent, org.refcodes.io.MaxConnectionsAccessor, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<RestfulHttpServer>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty, org.refcodes.web.MediaTypeFactoryLookup, org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup, org.refcodes.observer.Observable<RestEndpoint>, org.refcodes.observer.Observers<RestEndpoint,RestfulServer>, org.refcodes.component.Openable, org.refcodes.component.OpenedAccessor, org.refcodes.mixin.PortAccessor, org.refcodes.mixin.PortAccessor.PortBuilder<RestfulHttpServer>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpServerInterceptor>, org.refcodes.web.PostHttpServerInterceptable, org.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpServerInterceptor>, org.refcodes.web.PreHttpServerInterceptable, org.refcodes.web.RealmAccessor, org.refcodes.web.RealmAccessor.RealmBuilder<RestfulServer>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmProperty, RestfulServer, org.refcodes.web.SchemeAccessor, org.refcodes.web.SchemeAccessor.SchemeBuilder<RestfulHttpServer>, org.refcodes.web.SchemeAccessor.SchemeMutator, org.refcodes.web.SchemeAccessor.SchemeProperty
All Known Subinterfaces:
RestfulHttpRegistryServer<DESC,B>
All Known Implementing Classes:
AbstractRestfulHttpRegistryServerDecorator, AbstractRestfulHttpServerDecorator, HttpRestServer, HttpRestServerSingleton

public interface RestfulHttpServer extends RestfulServer, org.refcodes.web.HttpServerInterceptable, HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty, HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<RestfulHttpServer>, HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty, HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<RestfulHttpServer>, org.refcodes.component.LinkComponent, org.refcodes.component.ConnectionStatusAccessor, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,RestfulHttpServer>, org.refcodes.web.BasicAuthObservable<RestfulHttpServer>, org.refcodes.web.HttpsConnectionRequestObservable<RestfulHttpServer>, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.mixin.PortAccessor.PortBuilder<RestfulHttpServer>, org.refcodes.web.SchemeAccessor.SchemeProperty, org.refcodes.web.SchemeAccessor.SchemeBuilder<RestfulHttpServer>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<RestfulHttpServer>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<RestfulHttpServer>
Extends a RestfulServer to be capable of opening a server socket on the local host with the provided port number via ConnectionOpenable.open(Object) or with an additional maximum number of connections via open(int, int). To open a HTTPS port, use the methods such as: open(KeyStoreDescriptor, int) or open(KeyStoreDescriptor, int, int) or open(String, KeyStoreDescriptor, int) or open(String, KeyStoreDescriptor, int, int). A RestfulHttpServer can be shutdown via Closable.close().