-
- All Known Subinterfaces:
StatusPathAccessor.StatusPathProperty
public interface StatusPathAccessorProvides an accessor for a status path property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceStatusPathAccessor.StatusPathBuilder<B extends StatusPathAccessor.StatusPathBuilder<?>>Provides a mutator for an status path property.static interfaceStatusPathAccessor.StatusPathMutatorProvides a mutator for a status path property.static interfaceStatusPathAccessor.StatusPathPropertyProvides a status path property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringgetStatusPath()Retrieves the status path from the status path property.
-
-
-
Method Detail
-
getStatusPath
String getStatusPath()
Retrieves the status path from the status path property.- Returns:
- The status path stored by the status path property.
-
-