Interface StatusPathAccessor.StatusPathBuilder<B extends StatusPathAccessor.StatusPathBuilder<?>>
- Type Parameters:
B- The builder which implements theStatusPathAccessor.StatusPathBuilder.
- Enclosing interface:
StatusPathAccessor
public static interface StatusPathAccessor.StatusPathBuilder<B extends StatusPathAccessor.StatusPathBuilder<?>>
Provides a mutator for an status path property.
-
Method Summary
Modifier and TypeMethodDescriptionwithStatusPath(String aStatusPath) Sets the status path to use and returns this builder as of the builder pattern.
-
Method Details
-
withStatusPath
Sets the status path to use and returns this builder as of the builder pattern.- Parameters:
aStatusPath- The status path to be stored by the status path property.- Returns:
- This
StatusPathAccessor.StatusPathBuilderinstance to continue configuration.
-