Interface StatusPathAccessor.StatusPathProperty
- All Superinterfaces:
StatusPathAccessor, StatusPathAccessor.StatusPathMutator
- Enclosing interface:
StatusPathAccessor
public static interface StatusPathAccessor.StatusPathProperty
extends StatusPathAccessor, StatusPathAccessor.StatusPathMutator
Provides a status path property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface StatusPathAccessor
StatusPathAccessor.StatusPathBuilder<B>, StatusPathAccessor.StatusPathMutator, StatusPathAccessor.StatusPathProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault StringletStatusPath(String aStatusPath) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofStatusPathAccessor.StatusPathMutator.setStatusPath(String)and returns the very same value (getter).Methods inherited from interface StatusPathAccessor
getStatusPathMethods inherited from interface StatusPathAccessor.StatusPathMutator
setStatusPath
-
Method Details
-
letStatusPath
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofStatusPathAccessor.StatusPathMutator.setStatusPath(String)and returns the very same value (getter).- Parameters:
aStatusPath- TheStringto set (viaStatusPathAccessor.StatusPathMutator.setStatusPath(String)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-