Uses of Interface
org.refcodes.rest.GetRestClient
-
Uses of GetRestClient in org.refcodes.rest
Subinterfaces of GetRestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceHttpRestDiscoveryClient<B extends HttpRestDiscoveryClient<B>>TheHttpRestDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.Classes in org.refcodes.rest that implement GetRestClientModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstract class for easily decorating aHttpRestDiscoveryClient.classAbstract base implementation of theRestClientinterface being the foundation for variousRestClientimplementations such asJdkHttpRestClientorLoopbackRestClient.classTheJdkHttpRestClientimplements theHttpRestClientinterface.classThe singleton of theJdkHttpRestClientfor easyHttpRestClientaccess.classImplements theRestClientinterface to be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.classThe singleton of theLoopbackRestClientfor easyLoopbackRestClientaccess.