Uses of Interface
org.refcodes.rest.HttpDiscoveryRestClient
-
Uses of HttpDiscoveryRestClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpDiscoveryRestClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpDiscoveryRestClient.interfaceHttpDiscoveryRestClient<B extends HttpDiscoveryRestClient<B>>TheHttpDiscoveryRestClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpDiscoveryRestClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpDiscoveryRestClient.