Uses of Interface
org.refcodes.rest.HttpExceptionHandler
-
Uses of HttpExceptionHandler in org.refcodes.rest
Methods in org.refcodes.rest that return HttpExceptionHandlerModifier and TypeMethodDescriptionHttpExceptionHandlerAccessor.getHttpExceptionHandler()Retrieves theHttpExceptionHandlerfrom theHttpExceptionHandlerproperty.JdkHttpRestServer.getHttpExceptionHandler()Retrieves theHttpExceptionHandlerfrom theHttpExceptionHandlerproperty.default HttpExceptionHandlerHttpExceptionHandlerAccessor.HttpExceptionHandlerProperty.letHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).Methods in org.refcodes.rest with parameters of type HttpExceptionHandlerModifier and TypeMethodDescriptiondefault HttpExceptionHandlerHttpExceptionHandlerAccessor.HttpExceptionHandlerProperty.letHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).default voidHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.onHttpException(HttpExceptionHandler aHttpExceptionHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.static HttpRestServerJdkHttpRestServerSugar.onHttpException(HttpExceptionHandler aHttpExceptionHandler) voidHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.voidJdkHttpRestServer.setHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder.withHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.JdkHttpRestServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default BHttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder.withOnHttpException(HttpExceptionHandler aHttpExceptionHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.JdkHttpRestServer.withOnHttpException(HttpExceptionHandler aHttpExceptionHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.