Uses of Interface
org.refcodes.rest.HttpExceptionHandlerAccessor
-
Uses of HttpExceptionHandlerAccessor in org.refcodes.rest
Subinterfaces of HttpExceptionHandlerAccessor in org.refcodes.restModifier and TypeInterfaceDescriptionstatic interfaceExtends theHttpExceptionHandlerAccessorwith a setter method.interfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host .Classes in org.refcodes.rest that implement HttpExceptionHandlerAccessorModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classJDK based implementation of theHttpRestServerinterface using thecom.sun.net.httpserverpackage provided by the Java runtime.