Uses of Interface
org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder
-
Uses of HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilderModifier and TypeInterfaceDescriptionstatic interfaceHttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B extends HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B>>Provides a builder method for aHttpExceptionHandlerproperty returning the builder for applying multiple build operations.Subinterfaces of HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host .Classes in org.refcodes.rest that implement HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilderModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classJDK based implementation of theHttpRestServerinterface using thecom.sun.net.httpserverpackage provided by the Java runtime.