Uses of Interface
org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
-
Uses of HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty in org.refcodes.rest
Subinterfaces of HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host .Classes in org.refcodes.rest that implement HttpExceptionHandlerAccessor.HttpExceptionHandlerPropertyModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classJDK based implementation of theHttpRestServerinterface using thecom.sun.net.httpserverpackage provided by the Java runtime.