Uses of Enum Class
org.refcodes.rest.HttpExceptionHandling
-
Uses of HttpExceptionHandling in org.refcodes.rest
Subclasses with type arguments of type HttpExceptionHandling in org.refcodes.restModifier and TypeClassDescriptionenumDefines how errors affect the HTTP-Body whilst processing aHttpRequestor aHttpResponsealong with the according sub-classes.Methods in org.refcodes.rest that return HttpExceptionHandlingModifier and TypeMethodDescriptionHttpExceptionHandlingAccessor.getHttpExceptionHandling()Retrieves theHttpExceptionHandlingfrom theHttpExceptionHandlingproperty.JdkHttpRestServer.getHttpExceptionHandling()Retrieves theHttpExceptionHandlingfrom theHttpExceptionHandlingproperty.default HttpExceptionHandlingHttpExceptionHandlingAccessor.HttpExceptionHandlingProperty.letHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).static HttpExceptionHandlingReturns the enum constant of this class with the specified name.static HttpExceptionHandling[]HttpExceptionHandling.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.rest with parameters of type HttpExceptionHandlingModifier and TypeMethodDescriptiondefault HttpExceptionHandlingHttpExceptionHandlingAccessor.HttpExceptionHandlingProperty.letHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).voidHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.voidJdkHttpRestServer.setHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder.withHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.JdkHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.