Uses of Interface
org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder
-
Uses of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeInterfaceDescriptionstatic interfaceHttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>Provides a builder method for aHttpExceptionHandlingproperty returning the builder for applying multiple build operations.Subinterfaces of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).Classes in org.refcodes.rest that implement HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classImplementation of theHttpRestServerinterface using theHttpRestServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theJdkHttpRestServerfor easyHttpRestServeraccess.