Uses of Interface
org.refcodes.rest.HttpRegistryContext
-
Uses of HttpRegistryContext in org.refcodes.rest
Subinterfaces with type arguments of type HttpRegistryContext in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRegistry<DESC extends HttpServerDescriptor, B extends HttpRegistry<DESC,B>> TheHttpRegistrydescribes the functionality required in order to register a service at a service registry and discovery service.Methods in org.refcodes.rest with parameters of type HttpRegistryContextModifier and TypeMethodDescriptiondefault voidHttpRegistry.initialize(HttpRegistryContext<DESC> aRegistryContext) Initializes theHttpRegistryby registering it at the service registry with a status such as "starting" or "initializing" or "not-ready-yet".