Uses of Interface
org.refcodes.rest.HttpRestDiscoveryClient
-
Uses of HttpRestDiscoveryClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestDiscoveryClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpRestDiscoveryClient.interfaceHttpRestDiscoveryClient<B extends HttpRestDiscoveryClient<B>>TheHttpRestDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestDiscoveryClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpRestDiscoveryClient.