Uses of Interface
org.refcodes.rest.HttpRestServer
-
Uses of HttpRestServer in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.Subinterfaces of HttpRestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classJDK based implementation of theHttpRestServerinterface using thecom.sun.net.httpserverpackage provided by the Java runtime.Subinterfaces with type arguments of type HttpRestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceExtends aRestServerto be capable of opening a server socket on the local host .interfaceExtends aRestServerto be capable of opening a server socket on the local host .interfaceExtends aRestServerto be capable of opening a server socket on the local host .interfaceExtends aRestServerto be capable of opening a server socket on the local host .interfaceExtends aRestServerto be capable of opening a server socket on the local host .Fields in org.refcodes.rest declared as HttpRestServerModifier and TypeFieldDescriptionprotected HttpRestServerAbstractHttpRestServerDecorator._serverMethods in org.refcodes.rest that return HttpRestServerModifier and TypeMethodDescriptionJdkHttpRestServer.onBasicAuthRequest(BasicAuthObserver aBasicAuthObserver) JdkHttpRestServer.onConnectionRequest(HttpsConnectionRequestObserver aObserver) default HttpRestServerHttpRestServer.withClose()default HttpRestServerHttpRestServer.withCloseIn(int aCloseMillis) default HttpRestServerHttpRestServer.withCloseQuietly()default HttpRestServerHttpRestServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.Constructors in org.refcodes.rest with parameters of type HttpRestServerModifierConstructorDescriptionDecorates the givenHttpRestServerwith discovery functionality.Decorates the givenHttpRestServerwith additional functionality.