Uses of Interface
org.refcodes.rest.HttpServerDescriptor
-
Uses of HttpServerDescriptor in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpServerDescriptorModifier and TypeClassDescriptionclassAbstractHttpRegistryContextBuilder<DESC extends HttpServerDescriptor>The Class AbstractHttpRegistryContextBuilder.classAbstractHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> Abstract class for easily decorating aHttpRegistrySidecar.classAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> Abstract class for easily decorating aHttpRestRegistryServer.interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRegistry<DESC, B>> TheHttpRegistrydescribes the functionality required in order to register a service at a service registry and discovery service.interfaceHttpRegistryContext<DESC extends HttpServerDescriptor>This context describes all information required to register a server ("service") at a service discovery registry.static interfaceTheHttpRegistryContext.HttpRegistryContextBuilderinterface extends theHttpRegistryContextwith builder functionality as of the builder pattern.interfaceHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> TheHttpRegistrySidecardescribes the functionality required in order to register a service at a service registry and discovery service.interfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceHttpServerDescriptorAccessor<DESC extends HttpServerDescriptor>Provides an accessor for aHttpServerDescriptorproperty.static interfaceHttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC extends HttpServerDescriptor,B extends HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC, B>> Provides a builder method for aHttpServerDescriptorproperty returning the builder for applying multiple build operations.static interfaceProvides a mutator for aHttpServerDescriptorproperty.static interfaceProvides aHttpServerDescriptorproperty.interfaceHttpServerDescriptorFactory<DESC extends HttpServerDescriptor>TheHttpServerDescriptorFactoryprovides factory functionality for creatingHttpServerDescriptorinstances.Subinterfaces of HttpServerDescriptor in org.refcodes.restModifier and TypeInterfaceDescriptionstatic interfaceHttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>TheHttpServerDescriptor.HttpServerDescriptorBuilderinterface extends theHttpServerDescriptorinterface with builder functionality as of the builder pattern.Methods in org.refcodes.rest with type parameters of type HttpServerDescriptorModifier and TypeMethodDescriptionprotected static <DESC extends HttpServerDescriptor>
DESCAbstractHttpRegistrySidecar.toHttpServerDescriptor(DESC aServerDescriptor, HttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC> aProperty) Resolves the property from the provided value and the provided property and the and sets the property in case the provided value is not null.