Uses of Interface
org.refcodes.rest.PingPathAccessor.PingPathBuilder
-
Uses of PingPathAccessor.PingPathBuilder in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type PingPathAccessor.PingPathBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for an ping path property.Subinterfaces of PingPathAccessor.PingPathBuilder in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRegistry<DESC, B>> TheHttpRegistrydescribes the functionality required in order to register a service at a service registry and discovery service.interfaceHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> TheHttpRegistrySidecardescribes the functionality required in order to register a service at a service registry and discovery service.interfaceRestfulHttpRegistryServer<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> TheRestfulHttpRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement PingPathAccessor.PingPathBuilderModifier and TypeClassDescriptionclassAbstractHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> Abstract class for easily decorating aHttpRegistrySidecar.classAbstractRestfulHttpRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> Abstract class for easily decorating aRestfulHttpRegistryServer.