Uses of Interface
org.refcodes.rest.PingPathAccessor.PingPathProperty
-
Uses of PingPathAccessor.PingPathProperty in org.refcodes.rest
Subinterfaces of PingPathAccessor.PingPathProperty in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRegistry<DESC, B>> TheHttpRegistrydescribes the functionality required in order to register a service at a service registry and discovery service.interfaceHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> TheHttpRegistrySidecardescribes the functionality required in order to register a service at a service registry and discovery service.interfaceRestfulHttpRegistryServer<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> TheRestfulHttpRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement PingPathAccessor.PingPathPropertyModifier and TypeClassDescriptionclassAbstractHttpRegistrySidecar<DESC extends HttpServerDescriptor,B extends HttpRegistrySidecar<DESC, B>> Abstract class for easily decorating aHttpRegistrySidecar.classAbstractRestfulHttpRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> Abstract class for easily decorating aRestfulHttpRegistryServer.Methods in org.refcodes.rest with parameters of type PingPathAccessor.PingPathPropertyModifier and TypeMethodDescriptionprotected static StringAbstractHttpRegistrySidecar.toPingPath(String aPingPath, String aDefaultPingPath, PingPathAccessor.PingPathProperty aProperty) Resolves the property from the provided value and the provided property and the and sets the property in case the provided value is not null.