Uses of Interface
org.refcodes.rest.RestClient
-
Uses of RestClient in org.refcodes.rest
Subinterfaces of RestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceHttpRestDiscoveryClient<B extends HttpRestDiscoveryClient<B>>TheHttpRestDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement RestClientModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstract class for easily decorating aHttpRestDiscoveryClient.classAbstract base implementation of theRestClientinterface being the foundation for variousRestClientimplementations such asJdkHttpRestClientorLoopbackRestClient.classTheJdkHttpRestClientimplements theHttpRestClientinterface.classThe singleton of theJdkHttpRestClientfor easyHttpRestClientaccess.classImplements theRestClientinterface to be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.classThe singleton of theLoopbackRestClientfor easyLoopbackRestClientaccess.Subinterfaces with type arguments of type RestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.interfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.interfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.Methods in org.refcodes.rest with parameters of type RestClientModifier and TypeMethodDescriptionRestRequest.build(RestClient aRestClient) This is a convenience method for easily instantiating the according builder.RestRequestBuilder.build(RestClient aRestClient) This is a convenience method for easily instantiating the according builder.static RestResponseHandlerRestResponseHandler.build(RestClient aRestClient) This is a convenience method for easily instantiating the according builder.RestResponseResult.build(RestClient aRestClient) This is a convenience method for easily instantiating the according builder.Constructors in org.refcodes.rest with parameters of type RestClientModifierConstructorDescriptionprotectedRestRequest(RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, Object aRequest, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, RestClient aRestClient) Instantiates a new rest request builder impl.protectedRestRequestBuilder(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, RestClient aRestClient) Instantiates a new rest request builder impl.RestResponseEvent(RestResponse aRestResponse, RestClient aRestClient) Constructs aRestResponseEventwith all required attributes.RestResponseEvent(Url aUrl, InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields, InputStream aHttpInputStream, RestClient aRestClient) Constructs aRestResponseEventwith all required attributes.