Uses of Class
org.refcodes.rest.RestRequest
-
Uses of RestRequest in org.refcodes.rest
Subclasses of RestRequest in org.refcodes.restModifier and TypeClassDescriptionclassThe implementation of theRestResponseHandlerinterface as good old POJO for use by differentRestClientimplementations.Methods in org.refcodes.rest that return RestRequestModifier and TypeMethodDescriptionRestRequest.build(RestClient aRestClient) This is a convenience method for easily instantiating the according builder.Methods in org.refcodes.rest with parameters of type RestRequestModifier and TypeMethodDescriptiondefault RestResponseRestRequestClient.doRequest(RestRequest aRequest) Sends a request with the possible attributes and returns the according request'sRestResponseinstance synchronously.static RestResponseRestRequestClientSugar.doRequest(RestRequest aRequest) See alsoRestRequestClient.doRequest(RestRequest).