The invoker provides a request context being a RestRequestEvent)
describing the request and a response being a HttpServerResponse
to be processed upon by your lambda's code.
The invoker provides a request context being a RestRequestEvent)
describing the request and a response being a HttpServerResponse
to be processed upon by your lambda's code.