Uses of Interface
org.refcodes.rest.RestRequestHandler
-
Uses of RestRequestHandler in org.refcodes.rest
Subinterfaces of RestRequestHandler in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceHttpRestDiscoveryClient<B extends HttpRestDiscoveryClient<B>>TheHttpRestDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.interfaceHelper interface to keep the huge amount of convenience methods under control.Classes in org.refcodes.rest that implement RestRequestHandlerModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstract class for easily decorating aHttpRestDiscoveryClient.classAbstract base implementation of theRestClientinterface being the foundation for variousRestClientimplementations such asJdkHttpRestClientorLoopbackRestClient.classTheJdkHttpRestClientimplements theHttpRestClientinterface.classThe singleton of theJdkHttpRestClientfor easyHttpRestClientaccess.classImplements theRestClientinterface to be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.classThe singleton of theLoopbackRestClientfor easyLoopbackRestClientaccess.Methods in org.refcodes.rest with parameters of type RestRequestHandlerModifier and TypeMethodDescriptionprotected voidAbstractRestClient.onRestRequest(RestRequestHandler aHandler) Sets the hook receiving a preparedRestResponseHandlerinstance to be used to do the technical request with the technology chosen by the implementing sub-class.voidLoopbackRestClient.onRestRequest(RestRequestHandler aHandler) Registers aRestRequestHandlerto simulate a REST response: TheRestRequestHandler.doRequest(org.refcodes.web.HttpClientRequest)method is invoked with a preparedRestResponseHandlerinstance representing the request being sent and produces an accordingRestResponseEventto be passed back to the issuer of the request.