Uses of Interface
org.refcodes.rest.RestServer
-
Uses of RestServer in org.refcodes.rest
Subinterfaces of RestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).Classes in org.refcodes.rest that implement RestServerModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classImplementation of the base functionality of theRestServerinterface omitting the HTTP handling part being the foundation for variousRestServerimplementations such asJdkHttpRestServerorLoopbackRestServer.classImplementation of theHttpRestServerinterface using theHttpRestServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theJdkHttpRestServerfor easyHttpRestServeraccess.classImplements aRestServerto be used as loopback device e.g. for testing purposes such as testing yourRestRequestConsumerimplementations.classThe singleton of theLoopbackRestServerfor easyRestServeraccess.Subinterfaces with type arguments of type RestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceTheRestServeracts as the target for clients issuing REST requests.interfaceTheRestServeracts as the target for clients issuing REST requests.interfaceTheRestServeracts as the target for clients issuing REST requests.Classes in org.refcodes.rest that implement interfaces with type arguments of type RestServerModifier and TypeClassDescriptionclassclassDefines aRestRequestEventbeing the request as consumed by aRestEndpoint.classDefines aRestResponseEventbeing the response as consumed by aRestResponseHandler'sRestResponseConsumer.Methods in org.refcodes.rest that return RestServerModifier and TypeMethodDescriptionBasicAuthEvent.getSource()RestRequestEvent.getSource()RestResponseEvent.getSource()default RestServerRestServer.withBaseLocator(String aBaseLocator) default RestServerRestServer.withDisableObservers()default RestServerRestServer.withEnableObservers()default RestServerRestServer.withObserversActive(boolean isActive) default RestServerConstructors in org.refcodes.rest with parameters of type RestServerModifierConstructorDescriptionBasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, Url aUrl, WildcardSubstitutes aWildcardSubstitutes, BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer) Instantiates a new basic auth event.RestRequestEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, Url aUrl, WildcardSubstitutes aWildcardSubstitutes, RequestHeaderFields aHeaderFields, InputStream aHttpInputStream, RestServer aRestServer) Constructs aRestRequestEventwith all required attributes.