Uses of Interface
org.refcodes.rest.RestfulHttpClient
-
Uses of RestfulHttpClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type RestfulHttpClientSubinterfaces of RestfulHttpClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceRestfulHttpDiscoveryClient<B extends RestfulHttpDiscoveryClient<B>>TheRestfulHttpDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement RestfulHttpClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aRestfulHttpClient.classAbstract class for easily decorating aRestfulHttpDiscoveryClient.classTheHttpRestClientimplements theRestfulHttpClientinterface.classThe singleton of theHttpRestClientfor easyRestfulHttpClientaccess.Fields in org.refcodes.rest declared as RestfulHttpClientModifier and TypeFieldDescriptionprotected RestfulHttpClientAbstractRestfulHttpClientDecorator._clientMethods in org.refcodes.rest that return RestfulHttpClientModifier and TypeMethodDescriptionstatic RestfulHttpClientHttpRestClientSingleton.getInstance()Returns the singleton's instance as fabricated by thisHttpRestClientSingleton.static RestfulHttpClientHttpRestClientSugar.withBaseUrl(String aBaseUrl) See alsowithBaseUrl(String).static RestfulHttpClientHttpRestClientSugar.withBaseUrl(URL aBaseUrl) See alsowithBaseUrl(URL).default RestfulHttpClientRestfulHttpClient.withBaseUrl(String aBaseUrl) default RestfulHttpClientRestfulHttpClient.withBaseUrl(URL aBaseURL) default RestfulHttpClientRestfulHttpClient.withBaseUrl(org.refcodes.web.Url aBaseUrl) default RestfulHttpClientRestfulHttpClient.withBasicAuthCredentials(String aUserName, String aSecret) default RestfulHttpClientRestfulHttpClient.withBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) default RestfulHttpClientRestfulHttpClient.withOAuthToken(org.refcodes.web.OauthToken aOauthToken) default RestfulHttpClientRestfulHttpClient.withOpen()Open the component's connection(s).default RestfulHttpClientRestfulHttpClient.withOpen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default RestfulHttpClientRestfulHttpClient.withOpen(org.refcodes.web.HttpClientContext aCtx) Opens the component with the given connection.default RestfulHttpClientRestfulHttpClient.withOpen(org.refcodes.web.Url aBaseUrl) Configures the HTTPS client connection with the provided configuration parameters.default RestfulHttpClientRestfulHttpClient.withOpen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default RestfulHttpClientRestfulHttpClient.withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) static RestfulHttpClientHttpRestClientSugar.withUserAgent(String aUserAgent) See alsowithUserAgent(String).default RestfulHttpClientRestfulHttpClient.withUserAgent(String aUserAgent) Constructors in org.refcodes.rest with parameters of type RestfulHttpClientModifierConstructorDescriptionDecorates the givenRestfulHttpClient.Decorates the givenRestfulHttpClientwith discovery functionality.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, RestfulHttpClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken, org.refcodes.controlflow.RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.