Uses of Interface
org.refcodes.rest.RestfulHttpDiscoveryClient
-
Uses of RestfulHttpDiscoveryClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type RestfulHttpDiscoveryClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aRestfulHttpDiscoveryClient.interfaceRestfulHttpDiscoveryClient<B extends RestfulHttpDiscoveryClient<B>>TheRestfulHttpDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement RestfulHttpDiscoveryClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aRestfulHttpDiscoveryClient.