java.lang.Object
org.refcodes.web.BasicAuthRequest
org.refcodes.rest.BasicAuthEvent
- All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.SourceAccessor<RestfulServer>,org.refcodes.mixin.WildcardSubstitutes,org.refcodes.observer.ActionEvent<org.refcodes.web.HttpMethod,,RestfulServer> org.refcodes.observer.Event<RestfulServer>,org.refcodes.web.BasicAuthCredentialsAccessor,org.refcodes.web.HttpMethodAccessor,org.refcodes.web.LocalAddressAccessor,org.refcodes.web.RealmAccessor,org.refcodes.web.RemoteAddressAccessor,org.refcodes.web.UrlAccessor
public class BasicAuthEvent
extends org.refcodes.web.BasicAuthRequest
implements org.refcodes.observer.ActionEvent<org.refcodes.web.HttpMethod,RestfulServer>, org.refcodes.mixin.WildcardSubstitutes, org.refcodes.web.RealmAccessor, org.refcodes.web.LocalAddressAccessor, org.refcodes.web.RemoteAddressAccessor
The
BasicAuthEvent describes a BasicAuthRequest being the
request as consumed by a RestEndpoint. Usually you will use
RestfulServer.onRequest(HttpMethod, String, RestRequestConsumer) for
registering a RestRequestConsumer to the RestfulServer (
RestfulHttpServer).-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A, B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A>, org.refcodes.mixin.ActionAccessor.ActionProperty<A> Nested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyNested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor
org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B extends org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B>>, org.refcodes.web.HttpMethodAccessor.HttpMethodMutator, org.refcodes.web.HttpMethodAccessor.HttpMethodPropertyNested classes/interfaces inherited from interface org.refcodes.web.LocalAddressAccessor
org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B extends org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B>>, org.refcodes.web.LocalAddressAccessor.LocalAddressMutator, org.refcodes.web.LocalAddressAccessor.LocalAddressPropertyNested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmPropertyNested classes/interfaces inherited from interface org.refcodes.web.RemoteAddressAccessor
org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B extends org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B>>, org.refcodes.web.RemoteAddressAccessor.RemoteAddressMutator, org.refcodes.web.RemoteAddressAccessor.RemoteAddressPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor
org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC,B extends org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC, B>>, org.refcodes.mixin.SourceAccessor.SourceMutator<SRC>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC> Nested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor
org.refcodes.web.UrlAccessor.UrlBuilder, org.refcodes.web.UrlAccessor.UrlMutator, org.refcodes.web.UrlAccessor.UrlProperty -
Constructor Summary
ConstructorsConstructorDescriptionBasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.mixin.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestfulServer aRestfulServer) Instantiates a new basic auth event. -
Method Summary
Modifier and TypeMethodDescriptionorg.refcodes.web.HttpMethodgetRealm()String[]getWildcardReplacement(String aWildcardName) getWildcardReplacementAt(int aIndex) String[]String[]getWildcardReplacements(String... aWildcardNames) String[]getWildcardReplacementsAt(int... aIndexes) Methods inherited from class org.refcodes.web.BasicAuthRequest
getBasicAuthCredentials, getHttpMethod, getUrlMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Dumpable
toDump, toDump
-
Constructor Details
-
BasicAuthEvent
public BasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.mixin.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestfulServer aRestfulServer) Instantiates a new basic auth event.- Parameters:
aLocalAddress- The local address where the event is being received.aRemoteAddress- The remote address from which the request originates.aHttpMethod- TheHttpMethodwith which the request has been sent.aUrl- TheUrlfrom which to take the URL specific data.aWildcardSubstitutes- The text being substituted by the wildcard of theRestEndpoint's Locator-Pattern.aCredentials- The credentials retrieved from the request.aRealm- The realm to which this request is being addressed.aRestfulServer- The system firing the event.
-
-
Method Details
-
getAction
public org.refcodes.web.HttpMethod getAction()- Specified by:
getActionin interfaceorg.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>
-
getWildcardReplacements
- Specified by:
getWildcardReplacementsin interfaceorg.refcodes.mixin.WildcardSubstitutes
-
getWildcardReplacementAt
- Specified by:
getWildcardReplacementAtin interfaceorg.refcodes.mixin.WildcardSubstitutes
-
getWildcardReplacement
-
getWildcardReplacements
-
getWildcardReplacementsAt
- Specified by:
getWildcardReplacementsAtin interfaceorg.refcodes.mixin.WildcardSubstitutes
-
getRemoteAddress
- Specified by:
getRemoteAddressin interfaceorg.refcodes.web.RemoteAddressAccessor
-
getLocalAddress
- Specified by:
getLocalAddressin interfaceorg.refcodes.web.LocalAddressAccessor
-
getRealm
- Specified by:
getRealmin interfaceorg.refcodes.web.RealmAccessor
-
getSource
- Specified by:
getSourcein interfaceorg.refcodes.mixin.SourceAccessor<RestfulServer>
-
getWildcardNames
- Specified by:
getWildcardNamesin interfaceorg.refcodes.mixin.WildcardSubstitutes
-