- java.lang.Object
-
- org.refcodes.web.BasicAuthRequest
-
- org.refcodes.rest.BasicAuthEvent
-
- All Implemented Interfaces:
org.refcodes.matcher.WildcardSubstitutes,org.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.SourceAccessor<RestServer>,org.refcodes.observer.GenericActionEvent<org.refcodes.web.HttpMethod,RestServer>,org.refcodes.observer.GenericEvent<RestServer>,org.refcodes.web.BasicAuthCredentialsAccessor,org.refcodes.web.HttpMethodAccessor,org.refcodes.web.LocalAddressAccessor,org.refcodes.web.RealmAccessor,org.refcodes.web.RemoteAddressAccessor,org.refcodes.web.UrlAccessor
public class BasicAuthEvent extends org.refcodes.web.BasicAuthRequest implements org.refcodes.observer.GenericActionEvent<org.refcodes.web.HttpMethod,RestServer>, org.refcodes.matcher.WildcardSubstitutes, org.refcodes.web.RealmAccessor, org.refcodes.web.LocalAddressAccessor, org.refcodes.web.RemoteAddressAccessor
TheBasicAuthEventdescribes aBasicAuthRequestbeing the request as consumed by aRestEndpoint. Usually you will useRestServer.onRequest(HttpMethod, String, RestRequestConsumer)for registering aRestRequestConsumerto theRestServer(HttpRestServer).
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor
org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B extends org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B>>, org.refcodes.web.HttpMethodAccessor.HttpMethodMutator, org.refcodes.web.HttpMethodAccessor.HttpMethodProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.LocalAddressAccessor
org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B extends org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B>>, org.refcodes.web.LocalAddressAccessor.LocalAddressMutator, org.refcodes.web.LocalAddressAccessor.LocalAddressProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.RemoteAddressAccessor
org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B extends org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B>>, org.refcodes.web.RemoteAddressAccessor.RemoteAddressMutator, org.refcodes.web.RemoteAddressAccessor.RemoteAddressProperty
-
-
Constructor Summary
Constructors Constructor Description BasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description org.refcodes.web.HttpMethodgetAction()InetSocketAddressgetLocalAddress()StringgetRealm()InetSocketAddressgetRemoteAddress()RestServergetSource()String[]getWildcardNames()StringgetWildcardReplacement(String aWildcardName)StringgetWildcardReplacementAt(int aIndex)String[]getWildcardReplacements()String[]getWildcardReplacements(String... aWildcardNames)String[]getWildcardReplacementsAt(int... aIndexes)-
Methods inherited from class org.refcodes.web.BasicAuthRequest
getBasicAuthCredentials, getHttpMethod, getUrl
-
-
-
-
Constructor Detail
-
BasicAuthEvent
public BasicAuthEvent(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer)
- Parameters:
aLocalAddress- The local address where the event is being received.aRemoteAddress- The remote address from which the request originates.aHttpMethod- TheHttpMethodwith which the request has been sent.aUrl- TheUrlfrom which to take the URL specific data.aWildcardSubstitutes- The text being substituted by the wildcard of theRestEndpoint's Locator-Pattern.aCredentials- The credentials retrieved from the request.aRealm- The realm to which this request is being addressed.aRestServer- The system firing the event.
-
-
Method Detail
-
getAction
public org.refcodes.web.HttpMethod getAction()
- Specified by:
getActionin interfaceorg.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>
-
getWildcardReplacements
public String[] getWildcardReplacements()
- Specified by:
getWildcardReplacementsin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacementAt
public String getWildcardReplacementAt(int aIndex)
- Specified by:
getWildcardReplacementAtin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacement
public String getWildcardReplacement(String aWildcardName)
- Specified by:
getWildcardReplacementin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacements
public String[] getWildcardReplacements(String... aWildcardNames)
- Specified by:
getWildcardReplacementsin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacementsAt
public String[] getWildcardReplacementsAt(int... aIndexes)
- Specified by:
getWildcardReplacementsAtin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getRemoteAddress
public InetSocketAddress getRemoteAddress()
- Specified by:
getRemoteAddressin interfaceorg.refcodes.web.RemoteAddressAccessor
-
getLocalAddress
public InetSocketAddress getLocalAddress()
- Specified by:
getLocalAddressin interfaceorg.refcodes.web.LocalAddressAccessor
-
getRealm
public String getRealm()
- Specified by:
getRealmin interfaceorg.refcodes.web.RealmAccessor
-
getSource
public RestServer getSource()
- Specified by:
getSourcein interfaceorg.refcodes.mixin.SourceAccessor<RestServer>
-
getWildcardNames
public String[] getWildcardNames()
- Specified by:
getWildcardNamesin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
-