java.lang.Object
org.refcodes.web.BasicAuthRequestImpl
org.refcodes.rest.BasicAuthEventImpl
- All Implemented Interfaces:
org.refcodes.matcher.WildcardSubstitutes,org.refcodes.mixin.ActionAccessor<org.refcodes.web.HttpMethod>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.SourceAccessor<RestServer>,org.refcodes.observer.GenericActionEvent<org.refcodes.web.HttpMethod,RestServer>,org.refcodes.observer.GenericEvent<RestServer>,BasicAuthEvent,org.refcodes.web.BasicAuthCredentialsAccessor,org.refcodes.web.BasicAuthRequest,org.refcodes.web.HttpMethodAccessor,org.refcodes.web.LocalAddressAccessor,org.refcodes.web.RealmAccessor,org.refcodes.web.RemoteAddressAccessor,org.refcodes.web.UrlAccessor
public class BasicAuthEventImpl extends org.refcodes.web.BasicAuthRequestImpl implements BasicAuthEvent
The
BasicAuthEventImpl class implements the BasicAuthEvent
type.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>Nested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyNested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor
org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B extends org.refcodes.web.HttpMethodAccessor.HttpMethodBuilder<B>>, org.refcodes.web.HttpMethodAccessor.HttpMethodMutator, org.refcodes.web.HttpMethodAccessor.HttpMethodPropertyNested classes/interfaces inherited from interface org.refcodes.web.LocalAddressAccessor
org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B extends org.refcodes.web.LocalAddressAccessor.LocalAddressBuilder<B>>, org.refcodes.web.LocalAddressAccessor.LocalAddressMutator, org.refcodes.web.LocalAddressAccessor.LocalAddressPropertyNested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmPropertyNested classes/interfaces inherited from interface org.refcodes.web.RemoteAddressAccessor
org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B extends org.refcodes.web.RemoteAddressAccessor.RemoteAddressBuilder<B>>, org.refcodes.web.RemoteAddressAccessor.RemoteAddressMutator, org.refcodes.web.RemoteAddressAccessor.RemoteAddressPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor
org.refcodes.mixin.SourceAccessor.SourceMutator<SRC extends Object>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC extends Object>Nested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor
org.refcodes.web.UrlAccessor.UrlBuilder, org.refcodes.web.UrlAccessor.UrlMutator, org.refcodes.web.UrlAccessor.UrlProperty -
Constructor Summary
Constructors Constructor Description BasicAuthEventImpl(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer) -
Method Summary
Modifier and Type Method Description InetSocketAddressgetLocalAddress()StringgetRealm()InetSocketAddressgetRemoteAddress()RestServergetSource()String[]getWildcardNames()StringgetWildcardReplacement(String aWildcardName)StringgetWildcardReplacementAt(int aIndex)String[]getWildcardReplacements()String[]getWildcardReplacements(String... aWildcardNames)String[]getWildcardReplacementsAt(int... aIndexes)Methods inherited from class org.refcodes.web.BasicAuthRequestImpl
getBasicAuthCredentials, getHttpMethod, getUrlMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
getBasicAuthCredentialsMethods inherited from interface org.refcodes.rest.BasicAuthEvent
getActionMethods inherited from interface org.refcodes.mixin.Dumpable
toDump, toDump, toPrintableMethods inherited from interface org.refcodes.web.HttpMethodAccessor
getHttpMethodMethods inherited from interface org.refcodes.web.UrlAccessor
getUrl
-
Constructor Details
-
BasicAuthEventImpl
public BasicAuthEventImpl(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.matcher.WildcardSubstitutes aWildcardSubstitutes, org.refcodes.web.BasicAuthCredentials aCredentials, String aRealm, RestServer aRestServer)- Parameters:
aLocalAddress- The local address where the event is being received.aRemoteAddress- The remote address from which the request originates.aHttpMethod- TheHttpMethodwith which the request has been sent.aUrl- TheUrlfrom which to take the URL specific data.aWildcardSubstitutes- The text being substituted by the wildcard of theRestEndpoint's Locator-Pattern.aCredentials- The credentials retrieved from the request.aRealm- The realm to which this request is being addressed.aRestServer- The system firing the event.
-
-
Method Details
-
getWildcardReplacements
- Specified by:
getWildcardReplacementsin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacementAt
- Specified by:
getWildcardReplacementAtin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacement
- Specified by:
getWildcardReplacementin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacements
- Specified by:
getWildcardReplacementsin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getWildcardReplacementsAt
- Specified by:
getWildcardReplacementsAtin interfaceorg.refcodes.matcher.WildcardSubstitutes
-
getRemoteAddress
- Specified by:
getRemoteAddressin interfaceorg.refcodes.web.RemoteAddressAccessor
-
getLocalAddress
- Specified by:
getLocalAddressin interfaceorg.refcodes.web.LocalAddressAccessor
-
getRealm
- Specified by:
getRealmin interfaceorg.refcodes.web.RealmAccessor
-
getSource
- Specified by:
getSourcein interfaceorg.refcodes.mixin.SourceAccessor<RestServer>
-
getWildcardNames
- Specified by:
getWildcardNamesin interfaceorg.refcodes.matcher.WildcardSubstitutes
-