Interface HttpExceptionHandler

Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface HttpExceptionHandler
A lambda "catch-all" for handling exceptions during HTTP-Request processing.