Module org.refcodes.rest
Package org.refcodes.rest
Interface HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
-
- All Superinterfaces:
HttpExceptionHandlerAccessor,HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
- All Known Subinterfaces:
HttpRegistryRestServer<DESC,B>,HttpRestServer,LoopbackRestServer,RestServer
- All Known Implementing Classes:
AbstractHttpRegistryRestServerDecorator,AbstractHttpRestServerDecorator,AbstractRestServer,HttpRestServerImpl,HttpRestServerSingleton,LoopbackRestServerImpl,LoopbackRestServerSingleton
- Enclosing interface:
- HttpExceptionHandlerAccessor
public static interface HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty extends HttpExceptionHandlerAccessor, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
Extends theHttpExceptionHandlerAccessorwith a setter method.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B extends HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B>>, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator, HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default HttpExceptionHandlerletHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
getHttpExceptionHandler
-
Methods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
onHttpException, setHttpExceptionHandler
-
-
-
-
Method Detail
-
letHttpExceptionHandler
default HttpExceptionHandler letHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).- Parameters:
aHttpExceptionHandler- TheHttpExceptionHandlerto set (viaHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-