Interface HttpRegistryContext<DESC extends HttpServerDescriptor>

Type Parameters:
DESC - The HttpServerDescriptor which describes a server to be registered at a discovery registry so clients can resolve the server's URL.
All Superinterfaces:
HttpRegistryUrlAccessor, HttpServerDescriptorAccessor<DESC>, PingRequestObserverAccessor, TrustStoreDescriptorAccessor

This context describes all information required to register a server ("service") at a service discovery registry.