java.lang.Object
org.refcodes.rest.AbstractRestfulClient
org.refcodes.rest.HttpRestClient
- All Implemented Interfaces:
org.refcodes.component.Closable,org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpClientContext>,org.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpClientContext>,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.LinkComponent,org.refcodes.component.Openable,org.refcodes.component.Openable.OpenBuilder<RestfulHttpClient>,org.refcodes.component.OpenedAccessor,RestDeleteClient,RestfulClient,RestfulHttpClient,RestGetClient,RestPostClient,RestPutClient,RestRequestClient,RestRequestHandler,org.refcodes.security.TrustStoreDescriptorAccessor,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<RestfulHttpClient>,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty,org.refcodes.web.BaseUrlAccessor,org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>,org.refcodes.web.BaseUrlAccessor.BaseUrlMutator,org.refcodes.web.BaseUrlAccessor.BaseUrlProperty,org.refcodes.web.BasicAuthCredentialsAccessor,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestfulClient>,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator,org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty,org.refcodes.web.HttpClientInterceptable,org.refcodes.web.MediaTypeFactoryLookup,org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup,org.refcodes.web.OauthTokenAccessor,org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<RestfulClient>,org.refcodes.web.OauthTokenAccessor.OauthTokenMutator,org.refcodes.web.OauthTokenAccessor.OauthTokenProperty,org.refcodes.web.PostHttpClientInterceptable,org.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpClientInterceptor>,org.refcodes.web.PreHttpClientInterceptable,org.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpClientInterceptor>,org.refcodes.web.UserAgentAccessor,org.refcodes.web.UserAgentAccessor.UserAgentBuilder<RestfulClient>,org.refcodes.web.UserAgentAccessor.UserAgentMutator,org.refcodes.web.UserAgentAccessor.UserAgentProperty
- Direct Known Subclasses:
HttpRestClientSingleton
The
HttpRestClient implements the RestfulHttpClient
interface. The HttpRestClient is being initialized with some common
MediaTypeFactory instances (as implemented by the
AbstractRestfulClient). At the time of writing this document the
MediaTypeFactory instances being preconfigured are:
JsonMediaTypeFactoryXmlMediaTypeFactoryTextMediaTypeFactoryFormMediaTypeFactoryHtmlMediaTypeFactory
HttpRestClient supports HTTP as well as HTTPS protocols as being
based on the HttpURLConnection. For configuring HTTPS capabilities,
refer to the methods such as open(Url, TrustStoreDescriptor) or
open(Url, TrustStoreDescriptor).-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.BaseUrlAccessor
org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<B extends org.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<B>>, org.refcodes.web.BaseUrlAccessor.BaseUrlMutator, org.refcodes.web.BaseUrlAccessor.BaseUrlPropertyNested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyNested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionComponent
org.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionOpenable
org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.LinkComponent
org.refcodes.component.LinkComponent.LinkAutomaton, org.refcodes.component.LinkComponent.LinkComponentBuilder<B extends org.refcodes.component.LinkComponent.LinkComponentBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.web.MediaTypeFactoryLookup
org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookupNested classes/interfaces inherited from interface org.refcodes.web.OauthTokenAccessor
org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<B extends org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<B>>, org.refcodes.web.OauthTokenAccessor.OauthTokenMutator, org.refcodes.web.OauthTokenAccessor.OauthTokenPropertyNested classes/interfaces inherited from interface org.refcodes.component.Openable
org.refcodes.component.Openable.OpenAutomaton, org.refcodes.component.Openable.OpenBuilder<B extends org.refcodes.component.Openable.OpenBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedPropertyNested classes/interfaces inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.web.UserAgentAccessor
org.refcodes.web.UserAgentAccessor.UserAgentBuilder<B extends org.refcodes.web.UserAgentAccessor.UserAgentBuilder<B>>, org.refcodes.web.UserAgentAccessor.UserAgentMutator, org.refcodes.web.UserAgentAccessor.UserAgentProperty -
Field Summary
Fields inherited from interface org.refcodes.rest.RestfulHttpClient
DEFAULT_KEYSTORE_TYPE, DEFAULT_SSL_PROTOCOL -
Constructor Summary
ConstructorsConstructorDescriptionConstructs aHttpRestClient.HttpRestClient(ExecutorService aExecutorService) Constructs aHttpRestClient. -
Method Summary
Modifier and TypeMethodDescriptionbooleanaddPostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) booleanaddPreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) voidclose()org.refcodes.web.Urlorg.refcodes.component.ConnectionStatusorg.refcodes.security.TrustStoreDescriptorbooleanhasPostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) booleanhasPreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) voidopen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.protected static voidpipe(InputStream aInputStream, OutputStream aOutoutStream) Pipes theInputStreamto theOutputStream.protected voidpostIntercept(org.refcodes.web.HttpClientRequest aRequest, org.refcodes.web.HttpClientResponse aResponse) Invoked to post-process aHttpClientRequestalongside aHttpClientResponse.protected voidpreIntercept(org.refcodes.web.HttpClientRequest aRequest, org.refcodes.web.HttpClientResponse aResponse) Invoked to pre-process aHttpClientRequestalongside aHttpClientResponse.booleanremovePostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) booleanremovePreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) voidsetBaseUrl(URL aBaseUrl) voidsetBaseUrl(org.refcodes.web.Url aBaseUrl) voidsetTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aTrustStoreDescriptor) withBaseUrl(String aBaseUrl) withBaseUrl(String aProtocol, String aHost) withBaseUrl(String aProtocol, String aHost, int aPort) withBaseUrl(String aProtocol, String aHost, int aPort, String aPath) withBaseUrl(String aProtocol, String aHost, String aPath) withBaseUrl(URL aBaseURL) withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) withBaseUrl(org.refcodes.web.Url aBaseUrl) withBasicAuthCredentials(String aUserName, String aSecret) withBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) withOAuthToken(org.refcodes.web.OauthToken aOauthToken) withOpen()Open the component's connection(s).withOpen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.withOpen(org.refcodes.web.HttpClientContext aCtx) Opens the component with the given connection.withOpen(org.refcodes.web.Url aBaseUrl) Configures the HTTPS client connection with the provided configuration parameters.withOpen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) withUserAgent(String aUserAgent) Methods inherited from class org.refcodes.rest.AbstractRestfulClient
addMediaTypeFactory, buildRequest, doRequest, getBasicAuthCredentials, getFactoryMediaTypes, getOauthToken, getUserAgent, initMedaTypeFactories, onResponse, onResponse, onRestRequest, preProcessHeaderFields, setBasicAuthCredentials, setOauthToken, setUserAgent, toMediaTypeFactoryMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlMutator
setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlProperty
letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrlMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
getBasicAuthCredentialsMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
setBasicAuthCredentials, setBasicAuthCredentialsMethods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
letBasicAuthCredentials, letBasicAuthCredentialsMethods inherited from interface org.refcodes.component.Closable
closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable
openUncheckedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
isOpenedMethods inherited from interface org.refcodes.web.HttpClientInterceptable
addHttpInterceptor, hasHttpInterceptor, removeHttpInterceptorMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup
getFactoryMediaTypes, hasMediaTypeFactory, toMediaTypeFactoryMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup
addMediaTypeFactoryMethods inherited from interface org.refcodes.web.OauthTokenAccessor
getOauthTokenMethods inherited from interface org.refcodes.web.OauthTokenAccessor.OauthTokenMutator
setOauthTokenMethods inherited from interface org.refcodes.web.OauthTokenAccessor.OauthTokenProperty
letOauthTokenMethods inherited from interface org.refcodes.component.Openable
openUncheckedMethods inherited from interface org.refcodes.rest.RestDeleteClient
buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, buildDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, doDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDelete, onDeleteMethods inherited from interface org.refcodes.rest.RestfulHttpClient
open, open, open, openMethods inherited from interface org.refcodes.rest.RestGetClient
buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, buildGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, doGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGet, onGetMethods inherited from interface org.refcodes.rest.RestPostClient
buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, buildPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, doPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPost, onPostMethods inherited from interface org.refcodes.rest.RestPutClient
buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, buildPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, doPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPut, onPutMethods inherited from interface org.refcodes.rest.RestRequestClient
buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, buildRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, doRequest, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponse, onResponseMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
letTrustStoreDescriptorMethods inherited from interface org.refcodes.web.UserAgentAccessor
getUserAgentMethods inherited from interface org.refcodes.web.UserAgentAccessor.UserAgentMutator
setUserAgentMethods inherited from interface org.refcodes.web.UserAgentAccessor.UserAgentProperty
letUserAgent
-
Constructor Details
-
HttpRestClient
public HttpRestClient()Constructs aHttpRestClient. UseRestfulHttpClient.open()or similar to activate it. -
HttpRestClient
Constructs aHttpRestClient. UseRestfulHttpClient.open()or similar to activate it.- Parameters:
aExecutorService- An executor service to be used when creatingThreads.
-
-
Method Details
-
close
- Specified by:
closein interfaceorg.refcodes.component.Closable- Throws:
IOException
-
getBaseUrl
public org.refcodes.web.Url getBaseUrl()- Specified by:
getBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor
-
getConnectionStatus
public org.refcodes.component.ConnectionStatus getConnectionStatus()- Specified by:
getConnectionStatusin interfaceorg.refcodes.component.ConnectionStatusAccessor
-
getTrustStoreDescriptor
public org.refcodes.security.TrustStoreDescriptor getTrustStoreDescriptor()- Specified by:
getTrustStoreDescriptorin interfaceorg.refcodes.security.TrustStoreDescriptorAccessor
-
open
public void open(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Specified by:
openin interfaceRestfulHttpClient- Parameters:
aBaseUrl- The baseUrlto be used.aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Throws:
IOException- thrown in case something went wrong.
-
setBaseUrl
public void setBaseUrl(org.refcodes.web.Url aBaseUrl) - Specified by:
setBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlMutator
-
setBaseUrl
- Specified by:
setBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlMutator
-
setTrustStoreDescriptor
public void setTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aTrustStoreDescriptor) - Specified by:
setTrustStoreDescriptorin interfaceorg.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator
-
hasPreHttpInterceptor
public boolean hasPreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) - Specified by:
hasPreHttpInterceptorin interfaceorg.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpClientInterceptor>
-
addPreHttpInterceptor
public boolean addPreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) - Specified by:
addPreHttpInterceptorin interfaceorg.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpClientInterceptor>
-
removePreHttpInterceptor
public boolean removePreHttpInterceptor(org.refcodes.web.PreHttpClientInterceptor aPreInterceptor) - Specified by:
removePreHttpInterceptorin interfaceorg.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpClientInterceptor>
-
hasPostHttpInterceptor
public boolean hasPostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) - Specified by:
hasPostHttpInterceptorin interfaceorg.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpClientInterceptor>
-
addPostHttpInterceptor
public boolean addPostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) - Specified by:
addPostHttpInterceptorin interfaceorg.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpClientInterceptor>
-
removePostHttpInterceptor
public boolean removePostHttpInterceptor(org.refcodes.web.PostHttpClientInterceptor aPostInterceptor) - Specified by:
removePostHttpInterceptorin interfaceorg.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpClientInterceptor>
-
withOpen
Open the component's connection(s).- Specified by:
withOpenin interfaceorg.refcodes.component.Openable.OpenBuilder<RestfulHttpClient>- Specified by:
withOpenin interfaceRestfulHttpClient- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
withOpen
Opens the component with the given connection.- Specified by:
withOpenin interfaceRestfulHttpClient- Parameters:
aCtx- The context used for opening the connection.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
withOpen
public HttpRestClient withOpen(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Specified by:
withOpenin interfaceRestfulHttpClient- Parameters:
aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withOpen
Configures the HTTPS client connection with the provided configuration parameters.- Specified by:
withOpenin interfaceRestfulHttpClient- Parameters:
aBaseUrl- The baseUrlto be used.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withOpen
public HttpRestClient withOpen(org.refcodes.web.Url aBaseUrl, org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) throws IOException Configures the HTTPS client connection with the provided configuration parameters.- Specified by:
withOpenin interfaceRestfulHttpClient- Parameters:
aBaseUrl- The baseUrlto be used.aStoreDescriptor- TheTrustStoreDescriptorpointing to yourKeyStore.- Returns:
- This instance as of the builder pattern.
- Throws:
IOException- thrown in case something went wrong.
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Specified by:
withBaseUrlin interfaceRestfulHttpClient- Throws:
MalformedURLException
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Specified by:
withBaseUrlin interfaceRestfulHttpClient
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Specified by:
withBaseUrlin interfaceRestfulHttpClient
-
withBasicAuthCredentials
public HttpRestClient withBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) - Specified by:
withBasicAuthCredentialsin interfaceorg.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestfulClient>- Specified by:
withBasicAuthCredentialsin interfaceRestfulHttpClient
-
withBasicAuthCredentials
- Specified by:
withBasicAuthCredentialsin interfaceorg.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestfulClient>- Specified by:
withBasicAuthCredentialsin interfaceRestfulHttpClient
-
withOAuthToken
- Specified by:
withOAuthTokenin interfaceorg.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<RestfulClient>- Specified by:
withOAuthTokenin interfaceRestfulHttpClient
-
withTrustStoreDescriptor
public HttpRestClient withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) - Specified by:
withTrustStoreDescriptorin interfaceRestfulHttpClient- Specified by:
withTrustStoreDescriptorin interfaceorg.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<RestfulHttpClient>
-
withUserAgent
- Specified by:
withUserAgentin interfaceRestfulHttpClient- Specified by:
withUserAgentin interfaceorg.refcodes.web.UserAgentAccessor.UserAgentBuilder<RestfulClient>
-
withBaseUrl
- Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(String aProtocol, String aHost, String aPath) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(String aProtocol, String aHost, int aPort) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(String aProtocol, String aHost, int aPort, String aPath) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withBaseUrl
public HttpRestClient withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) throws MalformedURLException - Specified by:
withBaseUrlin interfaceorg.refcodes.web.BaseUrlAccessor.BaseUrlBuilder<RestfulHttpClient>- Throws:
MalformedURLException
-
withOpenUnchecked
- Specified by:
withOpenUncheckedin interfaceorg.refcodes.component.Openable.OpenBuilder<RestfulHttpClient>
-
pipe
Pipes theInputStreamto theOutputStream.- Parameters:
aInputStream- TheInputStreamfrom which to pipe.aOutoutStream- TheOutputStreamto pipe to.- Throws:
IOException- Signals that an I/O exception has occurred.
-
preIntercept
protected void preIntercept(org.refcodes.web.HttpClientRequest aRequest, org.refcodes.web.HttpClientResponse aResponse) Invoked to pre-process aHttpClientRequestalongside aHttpClientResponse.- Overrides:
preInterceptin classAbstractRestfulClient- Parameters:
aRequest- TheHttpClientRequestto pre-process.aResponse- TheHttpClientResponseto post-process.
-
postIntercept
protected void postIntercept(org.refcodes.web.HttpClientRequest aRequest, org.refcodes.web.HttpClientResponse aResponse) Invoked to post-process aHttpClientRequestalongside aHttpClientResponse.- Overrides:
postInterceptin classAbstractRestfulClient- Parameters:
aRequest- TheHttpClientRequestto post-process.aResponse- TheHttpClientResponseto post-process.
-