Interface HttpRestRegistryServer<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC,B>>
- Type Parameters:
DESC- The type of the server discovery descriptor (the object describing your service and locating the service registry).B- In order to implement the builder pattern with a coherent type hierarchy.
- All Superinterfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.AliasAccessor.AliasBuilder<B>,org.refcodes.mixin.AliasAccessor.AliasMutator,org.refcodes.mixin.AliasAccessor.AliasProperty,org.refcodes.web.BaseLocatorAccessor,org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<RestServer>,org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator,org.refcodes.web.BaseLocatorAccessor.BaseLocatorProperty,org.refcodes.web.BasicAuthObservable<HttpRestServer>,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,,HttpRestServer>> org.refcodes.component.Configurable<HttpRegistryContext<DESC>>,org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpServerContext>,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,,HttpRestServer> org.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpServerContext>,org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<org.refcodes.web.HttpServerContext,,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext, HttpRestServer>> org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.Destroyable,org.refcodes.component.Destroyable.DestroyAutomaton,org.refcodes.web.HostAccessor,org.refcodes.web.HostAccessor.HostBuilder<B>,org.refcodes.web.HostAccessor.HostMutator,org.refcodes.web.HostAccessor.HostProperty,HttpExceptionHandlerAccessor,HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<HttpRestServer>,HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator,HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty,HttpExceptionHandlingAccessor,HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<HttpRestServer>,HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator,HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty,HttpRegistry<DESC,,B> HttpRegistryUrlAccessor,HttpRegistryUrlAccessor.HttpRegistryUrlBuilder<B>,HttpRegistryUrlAccessor.HttpRegistryUrlMutator,HttpRegistryUrlAccessor.HttpRegistryUrlProperty,HttpRestServer,org.refcodes.web.HttpsConnectionRequestObservable<HttpRestServer>,HttpServerDescriptorAccessor<DESC>,HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC,,B> HttpServerDescriptorAccessor.HttpServerDescriptorMutator<DESC>,HttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC>,HttpServerDescriptorFactory<DESC>,org.refcodes.web.HttpServerInterceptable,org.refcodes.component.Initializable,org.refcodes.component.Initializable.InitializeAutomaton,org.refcodes.component.InitializedAccessor,org.refcodes.mixin.InstanceIdAccessor,org.refcodes.mixin.InstanceIdAccessor.InstanceIdBuilder<B>,org.refcodes.mixin.InstanceIdAccessor.InstanceIdMutator,org.refcodes.mixin.InstanceIdAccessor.InstanceIdProperty,org.refcodes.net.IpAddressAccessor,org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B>,org.refcodes.net.IpAddressAccessor.IpAddressMutator,org.refcodes.net.IpAddressAccessor.IpAddressProperty,org.refcodes.security.KeyStoreDescriptorAccessor,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpRestServer>,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty,org.refcodes.component.LifecycleComponent,org.refcodes.component.LifecycleComponent.LifecycleAutomaton,org.refcodes.component.LifecycleStatusAccessor,org.refcodes.component.LinkComponent,org.refcodes.io.MaxConnectionsAccessor,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpRestServer>,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty,org.refcodes.web.MediaTypeFactoryLookup,org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup,org.refcodes.observer.Observable<RestEndpoint>,org.refcodes.observer.Observers<RestEndpoint,,RestServer> org.refcodes.component.Openable,org.refcodes.component.OpenedAccessor,org.refcodes.component.Pausable,org.refcodes.component.Pausable.PauseAutomaton,PingPathAccessor,PingPathAccessor.PingPathBuilder<B>,PingPathAccessor.PingPathMutator,PingPathAccessor.PingPathProperty,PingRequestObserver,PingRequestObserverAccessor,PingRequestObserverAccessor.PingRequestObserverBuilder<B>,org.refcodes.mixin.PortAccessor,org.refcodes.mixin.PortAccessor.PortBuilder<HttpRestServer>,org.refcodes.mixin.PortAccessor.PortMutator,org.refcodes.mixin.PortAccessor.PortProperty,org.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpServerInterceptor>,org.refcodes.web.PostHttpServerInterceptable,org.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpServerInterceptor>,org.refcodes.web.PreHttpServerInterceptable,org.refcodes.web.RealmAccessor,org.refcodes.web.RealmAccessor.RealmBuilder<RestServer>,org.refcodes.web.RealmAccessor.RealmMutator,org.refcodes.web.RealmAccessor.RealmProperty,RestServer,org.refcodes.component.Resumable,org.refcodes.component.Resumable.ResumeAutomaton,org.refcodes.component.RunningAccessor,org.refcodes.web.SchemeAccessor,org.refcodes.web.SchemeAccessor.SchemeBuilder<HttpRestServer>,org.refcodes.web.SchemeAccessor.SchemeMutator,org.refcodes.web.SchemeAccessor.SchemeProperty,org.refcodes.component.Startable,org.refcodes.component.Startable.StartAutomaton,org.refcodes.component.Stoppable,org.refcodes.component.Stoppable.StopAutomaton,org.refcodes.security.TrustStoreDescriptorAccessor,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty,org.refcodes.web.VirtualHostAccessor,org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B>,org.refcodes.web.VirtualHostAccessor.VirtualHostMutator,org.refcodes.web.VirtualHostAccessor.VirtualHostProperty
- All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator
HttpRestRegistryServer provides additional functionality for
registering at and signing off from a service discovery service in order to
resolve URLs to or from other services. This type is intended to be used by
different separate hierarchy branches by providing of the generic type
<B>, ensuring a coherent type hierarchy for each branch.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.web.BaseLocatorAccessor
org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<B extends org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<B>>, org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator, org.refcodes.web.BaseLocatorAccessor.BaseLocatorPropertyNested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.Configurable
org.refcodes.component.Configurable.ConfigureAutomaton<CTX>, org.refcodes.component.Configurable.ConfigureBuilder<CTX,B extends org.refcodes.component.Configurable.ConfigureBuilder<CTX, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionComponent
org.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionOpenable
org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.Destroyable
org.refcodes.component.Destroyable.DestroyAutomatonNested classes/interfaces inherited from interface org.refcodes.web.HostAccessor
org.refcodes.web.HostAccessor.HostBuilder<B extends org.refcodes.web.HostAccessor.HostBuilder<?>>, org.refcodes.web.HostAccessor.HostMutator, org.refcodes.web.HostAccessor.HostPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B extends HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B>>, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator, HttpExceptionHandlerAccessor.HttpExceptionHandlerPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor
HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator, HttpExceptionHandlingAccessor.HttpExceptionHandlingPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpRegistryUrlAccessor
HttpRegistryUrlAccessor.HttpRegistryUrlBuilder<B extends HttpRegistryUrlAccessor.HttpRegistryUrlBuilder<B>>, HttpRegistryUrlAccessor.HttpRegistryUrlMutator, HttpRegistryUrlAccessor.HttpRegistryUrlPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpServerDescriptorAccessor
HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC extends HttpServerDescriptor,B extends HttpServerDescriptorAccessor.HttpServerDescriptorBuilder<DESC, B>>, HttpServerDescriptorAccessor.HttpServerDescriptorMutator<DESC extends HttpServerDescriptor>, HttpServerDescriptorAccessor.HttpServerDescriptorProperty<DESC extends HttpServerDescriptor> Nested classes/interfaces inherited from interface org.refcodes.component.Initializable
org.refcodes.component.Initializable.InitializeAutomaton, org.refcodes.component.Initializable.InitializeBuilder<B extends org.refcodes.component.Initializable.InitializeBuilder<B>>, org.refcodes.component.Initializable.UncheckedInitializableNested classes/interfaces inherited from interface org.refcodes.component.InitializedAccessor
org.refcodes.component.InitializedAccessor.InitializedMutator, org.refcodes.component.InitializedAccessor.InitializedPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.InstanceIdAccessor
org.refcodes.mixin.InstanceIdAccessor.InstanceIdBuilder<B extends org.refcodes.mixin.InstanceIdAccessor.InstanceIdBuilder<B>>, org.refcodes.mixin.InstanceIdAccessor.InstanceIdMutator, org.refcodes.mixin.InstanceIdAccessor.InstanceIdPropertyNested classes/interfaces inherited from interface org.refcodes.net.IpAddressAccessor
org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B extends org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B>>, org.refcodes.net.IpAddressAccessor.IpAddressMutator, org.refcodes.net.IpAddressAccessor.IpAddressPropertyNested classes/interfaces inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor
org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.component.LifecycleComponent
org.refcodes.component.LifecycleComponent.LifecycleAutomaton, org.refcodes.component.LifecycleComponent.UncheckedLifecycleComponentNested classes/interfaces inherited from interface org.refcodes.component.LifecycleStatusAccessor
org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusBuilder<B extends org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusBuilder<B>>, org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusMutator, org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.LinkComponent
org.refcodes.component.LinkComponent.LinkAutomaton, org.refcodes.component.LinkComponent.LinkComponentBuilder<B extends org.refcodes.component.LinkComponent.LinkComponentBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.io.MaxConnectionsAccessor
org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B extends org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B>>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsPropertyNested classes/interfaces inherited from interface org.refcodes.web.MediaTypeFactoryLookup
org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookupNested classes/interfaces inherited from interface org.refcodes.component.Openable
org.refcodes.component.Openable.OpenAutomaton, org.refcodes.component.Openable.OpenBuilder<B extends org.refcodes.component.Openable.OpenBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedPropertyNested classes/interfaces inherited from interface org.refcodes.component.Pausable
org.refcodes.component.Pausable.PauseAutomaton, org.refcodes.component.Pausable.PauseBuilder<B extends org.refcodes.component.Pausable.PauseBuilder<B>>, org.refcodes.component.Pausable.UncheckedPausableNested classes/interfaces inherited from interface org.refcodes.rest.PingPathAccessor
PingPathAccessor.PingPathBuilder<B extends PingPathAccessor.PingPathBuilder<?>>, PingPathAccessor.PingPathMutator, PingPathAccessor.PingPathPropertyNested classes/interfaces inherited from interface org.refcodes.rest.PingRequestObserverAccessor
PingRequestObserverAccessor.PingRequestObserverBuilder<B extends PingRequestObserverAccessor.PingRequestObserverBuilder<B>>, PingRequestObserverAccessor.PingRequestObserverMutator, PingRequestObserverAccessor.PingRequestObserverPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortPropertyNested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmPropertyNested classes/interfaces inherited from interface org.refcodes.component.Resumable
org.refcodes.component.Resumable.ResumeAutomaton, org.refcodes.component.Resumable.ResumeBuilder<B extends org.refcodes.component.Resumable.ResumeBuilder<B>>, org.refcodes.component.Resumable.UncheckedResumableNested classes/interfaces inherited from interface org.refcodes.component.RunningAccessor
org.refcodes.component.RunningAccessor.RunningMutator, org.refcodes.component.RunningAccessor.RunningPropertyNested classes/interfaces inherited from interface org.refcodes.web.SchemeAccessor
org.refcodes.web.SchemeAccessor.SchemeBuilder<B extends org.refcodes.web.SchemeAccessor.SchemeBuilder<B>>, org.refcodes.web.SchemeAccessor.SchemeMutator, org.refcodes.web.SchemeAccessor.SchemePropertyNested classes/interfaces inherited from interface org.refcodes.component.Startable
org.refcodes.component.Startable.StartAutomaton, org.refcodes.component.Startable.StartBuilder<B extends org.refcodes.component.Startable.StartBuilder<B>>, org.refcodes.component.Startable.UncheckedStartableNested classes/interfaces inherited from interface org.refcodes.component.Stoppable
org.refcodes.component.Stoppable.StopAutomaton, org.refcodes.component.Stoppable.StopBuilder<B extends org.refcodes.component.Stoppable.StopBuilder<B>>, org.refcodes.component.Stoppable.UncheckedStoppableNested classes/interfaces inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.web.VirtualHostAccessor
org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B extends org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<?>>, org.refcodes.web.VirtualHostAccessor.VirtualHostMutator, org.refcodes.web.VirtualHostAccessor.VirtualHostProperty -
Method Summary
Modifier and TypeMethodDescriptionvoiddestroy()This server is taken (removed) from the registry server.voidinitialize(String aAlias, String aInstanceId, org.refcodes.data.Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath, RestRequestConsumer aPingRequestObserver, org.refcodes.web.Url aRegistryUrl) Initializes theHttpRestRegistryServerby registering it at the service registry with a status such as "starting" or "initializing" or "not-ready-yet".default voidinitialize(String aAlias, org.refcodes.data.Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath, RestRequestConsumer aPingRequestObserver, org.refcodes.web.Url aRegistryUrl) Initializes theHttpRestRegistryServerby registering it at the service registry with a status such as "starting" or "initializing" or "not-ready-yet".voidpause()Some "deactivated" status is communicated to the registry server.voidresume()Some "up-and-running (again)" status is communicated to the registry server.voidstart()Some "up-and-running" status is communicated to the registry server.voidstop()Some "out-of-order" status is communicated to the registry server.default BwithPingRequestObserver(RestRequestConsumer aRequestConsumer) Sets the pingRestRequestConsumerfor the pingRestRequestConsumerproperty.default BwithPort(int aPort) default BwithProtocol(String aProtocol) default BwithScheme(org.refcodes.data.Scheme aScheme) Methods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.mixin.AliasAccessor.AliasMutator
setAliasMethods inherited from interface org.refcodes.mixin.AliasAccessor.AliasProperty
letAliasMethods inherited from interface org.refcodes.web.BaseLocatorAccessor
getBaseLocatorMethods inherited from interface org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator
setBaseLocatorMethods inherited from interface org.refcodes.web.BaseLocatorAccessor.BaseLocatorProperty
letBaseLocatorMethods inherited from interface org.refcodes.web.BasicAuthObservable
onBasicAuthRequestMethods inherited from interface org.refcodes.component.Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.Closable.CloseBuilder
withCloseUncheckedMethods inherited from interface org.refcodes.component.Configurable
initializeUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable
openUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder
withOpenUncheckedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpenedMethods inherited from interface org.refcodes.component.Destroyable.DestroyAutomaton
isDestroyable, isDestroyedMethods inherited from interface org.refcodes.web.HostAccessor
getHostMethods inherited from interface org.refcodes.web.HostAccessor.HostMutator
setHostMethods inherited from interface org.refcodes.web.HostAccessor.HostProperty
letHostMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
getHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder
withOnHttpExceptionMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
onHttpException, setHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
letHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor
getHttpExceptionHandlingMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator
setHttpExceptionHandlingMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty
letHttpExceptionHandlingMethods inherited from interface org.refcodes.rest.HttpRegistry
initialize, initialize, initialize, initialize, initialize, initialize, initialize, initialize, withAlias, withCidrNotation, withHost, withHttpRegistryUrl, withHttpServerDescriptor, withInstanceId, withIpAddress, withPingPath, withTrustStoreDescriptor, withVirtualHostMethods inherited from interface org.refcodes.rest.HttpRegistryUrlAccessor
getHttpRegistryUrlMethods inherited from interface org.refcodes.rest.HttpRegistryUrlAccessor.HttpRegistryUrlMutator
setHttpRegistryUrlMethods inherited from interface org.refcodes.rest.HttpRegistryUrlAccessor.HttpRegistryUrlProperty
letHttpRegistryUrlMethods inherited from interface org.refcodes.rest.HttpRestServer
open, open, open, open, open, open, open, open, open, open, open, open, open, withBaseLocator, withClose, withCloseIn, withCloseQuietly, withHttpExceptionHandler, withHttpExceptionHandling, withKeyStoreDescriptor, withMaxConnections, withOpen, withOpen, withRealmMethods inherited from interface org.refcodes.web.HttpsConnectionRequestObservable
onConnectionRequestMethods inherited from interface org.refcodes.rest.HttpServerDescriptorAccessor
getHttpServerDescriptorMethods inherited from interface org.refcodes.rest.HttpServerDescriptorAccessor.HttpServerDescriptorMutator
setHttpServerDescriptorMethods inherited from interface org.refcodes.rest.HttpServerDescriptorAccessor.HttpServerDescriptorProperty
letHttpServerDescriptorMethods inherited from interface org.refcodes.rest.HttpServerDescriptorFactory
toHttpServerDescriptor, toHttpServerDescriptor, toHttpServerDescriptor, toHttpServerDescriptor, toHttpServerDescriptorMethods inherited from interface org.refcodes.web.HttpServerInterceptable
addHttpInterceptor, hasHttpInterceptor, removeHttpInterceptorMethods inherited from interface org.refcodes.component.Initializable
initializeUncheckedMethods inherited from interface org.refcodes.component.Initializable.InitializeAutomaton
isInitalizableMethods inherited from interface org.refcodes.component.InitializedAccessor
isInitializedMethods inherited from interface org.refcodes.mixin.InstanceIdAccessor
getInstanceIdMethods inherited from interface org.refcodes.mixin.InstanceIdAccessor.InstanceIdMutator
setInstanceIdMethods inherited from interface org.refcodes.mixin.InstanceIdAccessor.InstanceIdProperty
letInstanceIdMethods inherited from interface org.refcodes.net.IpAddressAccessor
getIpAddress, toCidrNotationMethods inherited from interface org.refcodes.net.IpAddressAccessor.IpAddressMutator
fromCidrNotation, setIpAddressMethods inherited from interface org.refcodes.net.IpAddressAccessor.IpAddressProperty
letIpAddressMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor
getKeyStoreDescriptorMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator
setKeyStoreDescriptorMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty
letKeyStoreDescriptorMethods inherited from interface org.refcodes.component.LifecycleStatusAccessor
getLifecycleStatusMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor
getMaxConnectionsMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator
setMaxConnectionsMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty
letMaxConnectionsMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup
getFactoryMediaTypes, hasMediaTypeFactory, toMediaTypeFactoryMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup
addMediaTypeFactoryMethods inherited from interface org.refcodes.observer.Observable
hasObserver, subscribeObserver, unsubscribeObserverMethods inherited from interface org.refcodes.observer.Observers
disableObservers, enableObservers, isObserversActive, observers, setObserversActiveMethods inherited from interface org.refcodes.component.Openable
openUncheckedMethods inherited from interface org.refcodes.component.Pausable
pauseUncheckedMethods inherited from interface org.refcodes.component.Pausable.PauseAutomaton
isPausable, isPausedMethods inherited from interface org.refcodes.rest.PingPathAccessor
getPingPathMethods inherited from interface org.refcodes.rest.PingPathAccessor.PingPathMutator
setPingPathMethods inherited from interface org.refcodes.rest.PingPathAccessor.PingPathProperty
letPingPathMethods inherited from interface org.refcodes.rest.PingRequestObserver
onPingRequestMethods inherited from interface org.refcodes.rest.PingRequestObserverAccessor
getPingRequestObserverMethods inherited from interface org.refcodes.mixin.PortAccessor
getPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortMutator
setPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortProperty
letPortMethods inherited from interface org.refcodes.web.PostHttpInterceptable
addPostHttpInterceptor, hasPostHttpInterceptor, removePostHttpInterceptorMethods inherited from interface org.refcodes.web.PreHttpInterceptable
addPreHttpInterceptor, hasPreHttpInterceptor, removePreHttpInterceptorMethods inherited from interface org.refcodes.web.RealmAccessor
getRealmMethods inherited from interface org.refcodes.web.RealmAccessor.RealmMutator
setRealmMethods inherited from interface org.refcodes.web.RealmAccessor.RealmProperty
letRealmMethods inherited from interface org.refcodes.rest.RestServer
onDelete, onDelete, onGet, onGet, onPost, onPost, onPut, onPut, onRequest, onRequest, onRequest, onRequest, onRequest, withDisableObservers, withEnableObservers, withObserversActiveMethods inherited from interface org.refcodes.component.Resumable
resumeUncheckedMethods inherited from interface org.refcodes.component.Resumable.ResumeAutomaton
isResumableMethods inherited from interface org.refcodes.component.RunningAccessor
isRunningMethods inherited from interface org.refcodes.web.SchemeAccessor
getScheme, toProtocolMethods inherited from interface org.refcodes.web.SchemeAccessor.SchemeMutator
setProtocol, setSchemeMethods inherited from interface org.refcodes.web.SchemeAccessor.SchemeProperty
letProtocol, letSchemeMethods inherited from interface org.refcodes.component.Startable
startUncheckedMethods inherited from interface org.refcodes.component.Startable.StartAutomaton
isStartableMethods inherited from interface org.refcodes.component.Stoppable
stopUncheckedMethods inherited from interface org.refcodes.component.Stoppable.StopAutomaton
isStoppable, isStoppedMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
getTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator
setTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
letTrustStoreDescriptorMethods inherited from interface org.refcodes.web.VirtualHostAccessor
getVirtualHostMethods inherited from interface org.refcodes.web.VirtualHostAccessor.VirtualHostMutator
setVirtualHostMethods inherited from interface org.refcodes.web.VirtualHostAccessor.VirtualHostProperty
letVirtualHost
-
Method Details
-
withPort
- Specified by:
withPortin interfaceHttpRestServer- Specified by:
withPortin interfaceorg.refcodes.mixin.PortAccessor.PortBuilder<DESC extends HttpServerDescriptor>
-
withScheme
- Specified by:
withSchemein interfaceHttpRestServer- Specified by:
withSchemein interfaceorg.refcodes.web.SchemeAccessor.SchemeBuilder<DESC extends HttpServerDescriptor>
-
withProtocol
- Specified by:
withProtocolin interfaceHttpRestServer- Specified by:
withProtocolin interfaceorg.refcodes.web.SchemeAccessor.SchemeBuilder<DESC extends HttpServerDescriptor>
-
withPingRequestObserver
Sets the pingRestRequestConsumerfor the pingRestRequestConsumerproperty.- Specified by:
withPingRequestObserverin interfacePingRequestObserverAccessor.PingRequestObserverBuilder<DESC extends HttpServerDescriptor>- Parameters:
aRequestConsumer- The pingRestRequestConsumerto be stored by the pingRestRequestConsumerproperty.- Returns:
- The builder for applying multiple build operations.
-
initialize
default void initialize(String aAlias, org.refcodes.data.Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath, RestRequestConsumer aPingRequestObserver, org.refcodes.web.Url aRegistryUrl) throws org.refcodes.component.InitializeException Initializes theHttpRestRegistryServerby registering it at the service registry with a status such as "starting" or "initializing" or "not-ready-yet".- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aHost- The host name to be used to address this server. If omitted, then the system's host name should be used.aVirtualHost- The virtual host name to be used for resolving.aIpAddress- The IP-Address identifying the host.aPort- The port of your service being registered.aPingPath- The path to use as health-check end-point by this server.aPingRequestObserver- TheRestRequestConsumerhooking into a ping request.aRegistryUrl- The registry server where to register.- Throws:
org.refcodes.component.InitializeException- thrown in case initializing a component caused problems. Usually a method similar to "initialize()" throws such an exception.
-
initialize
void initialize(String aAlias, String aInstanceId, org.refcodes.data.Scheme aScheme, String aHost, String aVirtualHost, int[] aIpAddress, int aPort, String aPingPath, RestRequestConsumer aPingRequestObserver, org.refcodes.web.Url aRegistryUrl) throws org.refcodes.component.InitializeException Initializes theHttpRestRegistryServerby registering it at the service registry with a status such as "starting" or "initializing" or "not-ready-yet".- Parameters:
aAlias- The name ("alias") which identifies the server in the registry.aInstanceId- The TID for the instance when being registered at the service registry. If omitted, then the host name is used.aScheme- TheSchemeto which this server is being attached (HTTP or HTTPS).aHost- The host name to be used to address this server. If omitted, then the system's host name should be used.aVirtualHost- The virtual host name to be used for resolving.aIpAddress- The IP-Address identifying the host.aPort- The port of your service being registered.aPingPath- The path to use as health-check end-point by this server.aPingRequestObserver- TheRestRequestConsumerhooking into a ping request.aRegistryUrl- The registry server where to register.- Throws:
org.refcodes.component.InitializeException- thrown in case initializing a component caused problems. Usually a method similar to "initialize()" throws such an exception.
-
start
void start() throws org.refcodes.component.StartExceptionSome "up-and-running" status is communicated to the registry server. The registered
RestEndpointinstances (observers) (e.g. viaRestServer.onRequest(org.refcodes.web.HttpMethod, String, RestRequestConsumer),RestServer.onGet(String, RestRequestConsumer)RestServer.onPut(String, RestRequestConsumer),RestServer.onPut(String, RestRequestConsumer)orRestServer.onDelete(String, RestRequestConsumer)) are enabled by callingObservers.enableObservers(). If necessary, the connection is opened viaHttpRestServer.open()or the like. May also start a "ping" or "heartbeat" daemon.Some "up-and-running" status is communicated to the registry server. May also start a "ping" or "heartbeat" daemon.
- Specified by:
startin interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> - Specified by:
startin interfaceorg.refcodes.component.Startable- Throws:
org.refcodes.component.StartException
-
pause
void pause() throws org.refcodes.component.PauseExceptionSome "deactivated" status is communicated to the registry server. The registered
RestEndpointinstances (observers) (e.g. viaRestEndpointBuilderbeing registered e.g. viaRestServer.onRequest(org.refcodes.web.HttpMethod, String, RestRequestConsumer),RestServer.onGet(String, RestRequestConsumer)RestServer.onPut(String, RestRequestConsumer),RestServer.onPut(String, RestRequestConsumer)orRestServer.onDelete(String, RestRequestConsumer)is closed by calling itsRestEndpointBuilder.close()) are disabled by callingObservers.disableObservers().Some "deactivated" status is communicated to the registry server.
- Specified by:
pausein interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> - Specified by:
pausein interfaceorg.refcodes.component.Pausable- Throws:
org.refcodes.component.PauseException
-
resume
void resume() throws org.refcodes.component.ResumeExceptionSome "up-and-running (again)" status is communicated to the registry server. The registered
RestEndpointinstances (observers) (e.g. viaRestEndpointBuilderbeing registered e.g. viaRestServer.onRequest(org.refcodes.web.HttpMethod, String, RestRequestConsumer),RestServer.onGet(String, RestRequestConsumer)RestServer.onPut(String, RestRequestConsumer),RestServer.onPut(String, RestRequestConsumer)orRestServer.onDelete(String, RestRequestConsumer)is closed by calling itsRestEndpointBuilder.close()) are enabled (again) by callingObservers.enableObservers().Some "up-and-running (again)" status is communicated to the registry server.
- Specified by:
resumein interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> - Specified by:
resumein interfaceorg.refcodes.component.Resumable- Throws:
org.refcodes.component.ResumeException
-
stop
void stop() throws org.refcodes.component.StopExceptionSome "out-of-order" status is communicated to the registry server. The registered
RestEndpointinstances (observers) (e.g. viaRestServer.onRequest(org.refcodes.web.HttpMethod, String, RestRequestConsumer),RestServer.onGet(String, RestRequestConsumer)RestServer.onPut(String, RestRequestConsumer),RestServer.onPut(String, RestRequestConsumer)orRestServer.onDelete(String, RestRequestConsumer)) are disabled by callingObservers.disableObservers(). Also stops a "ping" or "heartbeat" daemon.Some "out-of-order" status is communicated to the registry server. Also stops a "ping" or "heartbeat" daemon.
- Specified by:
stopin interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>> - Specified by:
stopin interfaceorg.refcodes.component.Stoppable- Throws:
org.refcodes.component.StopException
-
destroy
void destroy()This server is taken (removed) from the registry server. The registered
RestEndpointinstances (observers) (e.g. viaRestServer.onRequest(org.refcodes.web.HttpMethod, String, RestRequestConsumer),RestServer.onGet(String, RestRequestConsumer)RestServer.onPut(String, RestRequestConsumer),RestServer.onPut(String, RestRequestConsumer)orRestServer.onDelete(String, RestRequestConsumer)) are disabled by callingObservers.disableObservers(). Also stops a "ping" or "heartbeat" daemon. Finally the connection is closed viaClosable.close().This server is taken (removed) from the registry server. Also stops a "ping" or "heartbeat" daemon. Finally the connection is closed.
- Specified by:
destroyin interfaceorg.refcodes.component.Destroyable- Specified by:
destroyin interfaceHttpRegistry<DESC extends HttpServerDescriptor,B extends HttpRestRegistryServer<DESC, B>>
-