Interface HttpRestServer
- All Superinterfaces:
org.refcodes.web.BaseLocatorAccessor,org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<RestServer>,org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator,org.refcodes.web.BaseLocatorAccessor.BaseLocatorProperty,org.refcodes.web.BasicAuthObservable<HttpRestServer>,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,,HttpRestServer>> org.refcodes.component.ConnectionComponent<org.refcodes.web.HttpServerContext>,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,,HttpRestServer> org.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpServerContext>,org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<org.refcodes.web.HttpServerContext,,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext, HttpRestServer>> org.refcodes.component.ConnectionStatusAccessor,HttpExceptionHandlerAccessor,HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<HttpRestServer>,HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator,HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty,HttpExceptionHandlingAccessor,HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<HttpRestServer>,HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator,HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty,org.refcodes.web.HttpsConnectionRequestObservable<HttpRestServer>,org.refcodes.web.HttpServerInterceptable,org.refcodes.security.KeyStoreDescriptorAccessor,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpRestServer>,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty,org.refcodes.component.LinkComponent,org.refcodes.io.MaxConnectionsAccessor,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpRestServer>,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty,org.refcodes.web.MediaTypeFactoryLookup,org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup,org.refcodes.observer.Observable<RestEndpoint>,org.refcodes.observer.Observers<RestEndpoint,,RestServer> org.refcodes.component.Openable,org.refcodes.component.OpenedAccessor,org.refcodes.mixin.PortAccessor,org.refcodes.mixin.PortAccessor.PortBuilder<HttpRestServer>,org.refcodes.mixin.PortAccessor.PortMutator,org.refcodes.mixin.PortAccessor.PortProperty,org.refcodes.web.PostHttpInterceptable<org.refcodes.web.PostHttpServerInterceptor>,org.refcodes.web.PostHttpServerInterceptable,org.refcodes.web.PreHttpInterceptable<org.refcodes.web.PreHttpServerInterceptor>,org.refcodes.web.PreHttpServerInterceptable,org.refcodes.web.RealmAccessor,org.refcodes.web.RealmAccessor.RealmBuilder<RestServer>,org.refcodes.web.RealmAccessor.RealmMutator,org.refcodes.web.RealmAccessor.RealmProperty,RestServer,org.refcodes.web.SchemeAccessor,org.refcodes.web.SchemeAccessor.SchemeBuilder<HttpRestServer>,org.refcodes.web.SchemeAccessor.SchemeMutator,org.refcodes.web.SchemeAccessor.SchemeProperty
- All Known Subinterfaces:
HttpRestRegistryServer<DESC,B>
- All Known Implementing Classes:
AbstractHttpRestRegistryServerDecorator,AbstractHttpRestServerDecorator,JdkHttpRestServer,JdkHttpRestServerSingleton
public interface HttpRestServer
extends RestServer, org.refcodes.web.HttpServerInterceptable, HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty, HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<HttpRestServer>, HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty, HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<HttpRestServer>, org.refcodes.component.LinkComponent, org.refcodes.component.ConnectionStatusAccessor, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,HttpRestServer>, org.refcodes.web.BasicAuthObservable<HttpRestServer>, org.refcodes.web.HttpsConnectionRequestObservable<HttpRestServer>, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.mixin.PortAccessor.PortBuilder<HttpRestServer>, org.refcodes.web.SchemeAccessor.SchemeProperty, org.refcodes.web.SchemeAccessor.SchemeBuilder<HttpRestServer>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpRestServer>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpRestServer>
Extends a
RestServer to be capable of opening a server socket on the
local host with the provided port number via ConnectionOpenable.open(Object) or with an
additional maximum number of connections via open(int, int). To open
a HTTPS port, use the methods such as: open(KeyStoreDescriptor, int)
or open(KeyStoreDescriptor, int, int) or
open(String, KeyStoreDescriptor, int) or
open(String, KeyStoreDescriptor, int, int). A HttpRestServer
can be shutdown via Closable.close().-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.BaseLocatorAccessor
org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<B extends org.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<B>>, org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator, org.refcodes.web.BaseLocatorAccessor.BaseLocatorPropertyNested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionComponent
org.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionOpenable
org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON, B>> Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B extends HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<B>>, HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator, HttpExceptionHandlerAccessor.HttpExceptionHandlerPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor
HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>, HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator, HttpExceptionHandlingAccessor.HttpExceptionHandlingPropertyNested classes/interfaces inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor
org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.component.LinkComponent
org.refcodes.component.LinkComponent.LinkAutomaton, org.refcodes.component.LinkComponent.LinkComponentBuilder<B extends org.refcodes.component.LinkComponent.LinkComponentBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.io.MaxConnectionsAccessor
org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B extends org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B>>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsPropertyNested classes/interfaces inherited from interface org.refcodes.web.MediaTypeFactoryLookup
org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookupNested classes/interfaces inherited from interface org.refcodes.component.Openable
org.refcodes.component.Openable.OpenAutomaton, org.refcodes.component.Openable.OpenBuilder<B extends org.refcodes.component.Openable.OpenBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortPropertyNested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
org.refcodes.web.RealmAccessor.RealmBuilder<B extends org.refcodes.web.RealmAccessor.RealmBuilder<B>>, org.refcodes.web.RealmAccessor.RealmMutator, org.refcodes.web.RealmAccessor.RealmPropertyNested classes/interfaces inherited from interface org.refcodes.web.SchemeAccessor
org.refcodes.web.SchemeAccessor.SchemeBuilder<B extends org.refcodes.web.SchemeAccessor.SchemeBuilder<B>>, org.refcodes.web.SchemeAccessor.SchemeMutator, org.refcodes.web.SchemeAccessor.SchemeProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault voidopen()default voidopen(int aPort) Opens the HTTP sever connection (socket) at the given port.default voidopen(int aPort, int aMaxConnections) Opens the HTTP sever connection (socket) at the given port allowing the given number of maximum connections at the same time.default voidSame asopen(String, KeyStoreDescriptor, int)but: The number of maximum connections at the same time is decided upon by the implementations's default value.default voidSame asopen(String, KeyStoreDescriptor, int, int)but: The number of maximum connections at the same time is decided upon by the implementations's default value.voidopen(String aProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) Opens the HTTPS sever connection (socket) at the given port allowing the given number of maximum connections at the same time using the provided HTTPS configuration parameters.default voidopen(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor) Same asopen(String, KeyStoreDescriptor, int)but: The number of maximum connections at the same time is decided upon by the implementations's default value.default voidopen(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort) Same asopen(String, KeyStoreDescriptor, int, int)but: The number of maximum connections at the same time is decided upon by the implementations's default value.default voidopen(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) Opens the HTTPS sever connection (socket) at the given port allowing the given number of maximum connections at the same time using the provided HTTPS configuration parameters.default voidopen(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor) Same asopen(String, KeyStoreDescriptor, int)but: The protocol for the underlyingSSLContextused is set to "TLS".default voidopen(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort) Same asopen(String, KeyStoreDescriptor, int, int)but: The protocol for the underlyingSSLContextused is set to "TLS".default voidopen(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) Same asopen(String, KeyStoreDescriptor, int, int)but: The protocol for the underlyingSSLContextused is set to "TLS".default voidopen(org.refcodes.web.HttpServerContext aConnection) default HttpRestServerwithBaseLocator(String aBaseLocator) default HttpRestServerdefault HttpRestServerwithCloseIn(int aCloseMillis) default HttpRestServerdefault HttpRestServerwithHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerwithHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default HttpRestServerwithKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) default HttpRestServerwithMaxConnections(int aMaxConnections) default HttpRestServerwithOpen(int aPort) Builder method for opening theHttpRestServer.default HttpRestServerwithOpen(org.refcodes.web.HttpServerContext aConnection) default HttpRestServerwithPort(int aPort) default HttpRestServerwithProtocol(String aProtocol) default HttpRestServerdefault HttpRestServerwithScheme(org.refcodes.data.Scheme aScheme) Methods inherited from interface org.refcodes.web.BaseLocatorAccessor
getBaseLocatorMethods inherited from interface org.refcodes.web.BaseLocatorAccessor.BaseLocatorMutator
setBaseLocatorMethods inherited from interface org.refcodes.web.BaseLocatorAccessor.BaseLocatorProperty
letBaseLocatorMethods inherited from interface org.refcodes.web.BasicAuthObservable
onBasicAuthRequestMethods inherited from interface org.refcodes.component.Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.Closable.CloseBuilder
withCloseUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable
openUncheckedMethods inherited from interface org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder
withOpenUncheckedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpenedMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor
getHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder
withOnHttpExceptionMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerMutator
onHttpException, setHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
letHttpExceptionHandlerMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor
getHttpExceptionHandlingMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingMutator
setHttpExceptionHandlingMethods inherited from interface org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingProperty
letHttpExceptionHandlingMethods inherited from interface org.refcodes.web.HttpsConnectionRequestObservable
onConnectionRequestMethods inherited from interface org.refcodes.web.HttpServerInterceptable
addHttpInterceptor, hasHttpInterceptor, removeHttpInterceptorMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor
getKeyStoreDescriptorMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator
setKeyStoreDescriptorMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty
letKeyStoreDescriptorMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor
getMaxConnectionsMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator
setMaxConnectionsMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty
letMaxConnectionsMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup
getFactoryMediaTypes, hasMediaTypeFactory, toMediaTypeFactoryMethods inherited from interface org.refcodes.web.MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup
addMediaTypeFactoryMethods inherited from interface org.refcodes.observer.Observable
hasObserver, subscribeObserver, unsubscribeObserverMethods inherited from interface org.refcodes.observer.Observers
disableObservers, enableObservers, isObserversActive, observers, setObserversActiveMethods inherited from interface org.refcodes.component.Openable
openUncheckedMethods inherited from interface org.refcodes.mixin.PortAccessor
getPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortMutator
setPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortProperty
letPortMethods inherited from interface org.refcodes.web.PostHttpInterceptable
addPostHttpInterceptor, hasPostHttpInterceptor, removePostHttpInterceptorMethods inherited from interface org.refcodes.web.PreHttpInterceptable
addPreHttpInterceptor, hasPreHttpInterceptor, removePreHttpInterceptorMethods inherited from interface org.refcodes.web.RealmAccessor
getRealmMethods inherited from interface org.refcodes.web.RealmAccessor.RealmMutator
setRealmMethods inherited from interface org.refcodes.web.RealmAccessor.RealmProperty
letRealmMethods inherited from interface org.refcodes.rest.RestServer
onDelete, onDelete, onGet, onGet, onPost, onPost, onPut, onPut, onRequest, onRequest, onRequest, onRequest, onRequest, withDisableObservers, withEnableObservers, withObserversActiveMethods inherited from interface org.refcodes.web.SchemeAccessor
getScheme, toProtocolMethods inherited from interface org.refcodes.web.SchemeAccessor.SchemeMutator
setProtocol, setSchemeMethods inherited from interface org.refcodes.web.SchemeAccessor.SchemeProperty
letProtocol, letScheme
-
Method Details
-
withHttpExceptionHandler
Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.- Specified by:
withHttpExceptionHandlerin interfaceHttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder<HttpRestServer>- Parameters:
aHttpErrorHandler- TheHttpExceptionHandlerto be stored by theHttpExceptionHandlerproperty.- Returns:
- The builder for applying multiple build operations.
-
withHttpExceptionHandling
Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.- Specified by:
withHttpExceptionHandlingin interfaceHttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<HttpRestServer>- Parameters:
aHttpErrorHandling- TheHttpExceptionHandlingto be stored by theHttpExceptionHandlingproperty.- Returns:
- The builder for applying multiple build operations.
-
withRealm
- Specified by:
withRealmin interfaceorg.refcodes.web.RealmAccessor.RealmBuilder<RestServer>- Specified by:
withRealmin interfaceRestServer
-
withBaseLocator
- Specified by:
withBaseLocatorin interfaceorg.refcodes.web.BaseLocatorAccessor.BaseLocatorBuilder<RestServer>- Specified by:
withBaseLocatorin interfaceRestServer
-
withClose
- Specified by:
withClosein interfaceorg.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,HttpRestServer>> - Throws:
IOException
-
withCloseQuietly
- Specified by:
withCloseQuietlyin interfaceorg.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,HttpRestServer>>
-
withCloseIn
- Specified by:
withCloseInin interfaceorg.refcodes.component.Closable.CloseBuilder<org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext,HttpRestServer>>
-
withOpen
- Specified by:
withOpenin interfaceorg.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<org.refcodes.web.HttpServerContext,org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<org.refcodes.web.HttpServerContext, HttpRestServer>> - Throws:
IOException
-
withOpen
Builder method for opening theHttpRestServer. Delegates toopen(int)and returns this method.- Parameters:
aPort- The port on which to listen for requests.- Returns:
- This instance for applying method chaining.
- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
withPort
- Specified by:
withPortin interfaceorg.refcodes.mixin.PortAccessor.PortBuilder<HttpRestServer>
-
withScheme
- Specified by:
withSchemein interfaceorg.refcodes.web.SchemeAccessor.SchemeBuilder<HttpRestServer>
-
withProtocol
- Specified by:
withProtocolin interfaceorg.refcodes.web.SchemeAccessor.SchemeBuilder<HttpRestServer>
-
withKeyStoreDescriptor
default HttpRestServer withKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) - Specified by:
withKeyStoreDescriptorin interfaceorg.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpRestServer>
-
withMaxConnections
- Specified by:
withMaxConnectionsin interfaceorg.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpRestServer>
-
open
- Specified by:
openin interfaceorg.refcodes.component.Openable- Throws:
IOException
-
open
Opens the HTTP sever connection (socket) at the given port.- Parameters:
aPort- The port on which to listen for requests.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
Opens the HTTP sever connection (socket) at the given port allowing the given number of maximum connections at the same time.- Parameters:
aPort- The port on which to listen for requests.aMaxConnections- The number of maximum connections at the same time.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
default void open(String aProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort) throws IOException Same asopen(String, KeyStoreDescriptor, int, int)but:- The number of maximum connections at the same time is decided upon by the implementations's default value.
- Parameters:
aProtocol- The protocol to use, e.g. "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
default void open(String aProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor) throws IOException Same asopen(String, KeyStoreDescriptor, int)but:- The number of maximum connections at the same time is decided upon by the implementations's default value.
- Parameters:
aProtocol- The protocol to use, e.g. "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
default void open(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) throws IOException Same asopen(String, KeyStoreDescriptor, int, int)but:- The protocol for the underlying
SSLContextused is set to "TLS". - The type of
KeyStoreis set to "JKS". - The password for the
KeyStore's key is assumed to be the same as the providedKeyStorepassword.
- Parameters:
aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.aMaxConnections- The number of maximum connections at the same time.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
- The protocol for the underlying
-
open
default void open(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort) throws IOException Same asopen(String, KeyStoreDescriptor, int, int)but:- The protocol for the underlying
SSLContextused is set to "TLS". - The type of
KeyStoreis set to "JKS".
- Parameters:
aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
- The protocol for the underlying
-
open
Same asopen(String, KeyStoreDescriptor, int)but:- The protocol for the underlying
SSLContextused is set to "TLS". - The type of
KeyStoreis set to "JKS".
- Parameters:
aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
- The protocol for the underlying
-
open
default void open(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) throws IOException Opens the HTTPS sever connection (socket) at the given port allowing the given number of maximum connections at the same time using the provided HTTPS configuration parameters.- Parameters:
aScheme- TheSchemeto use, e.g.Scheme.HTTPSdefaults to "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.aMaxConnections- The number of maximum connections at the same time.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
default void open(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort) throws IOException Same asopen(String, KeyStoreDescriptor, int, int)but:- The number of maximum connections at the same time is decided upon by the implementations's default value.
- Parameters:
aScheme- TheSchemeto use, e.g.Scheme.HTTPSdefaults to "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
default void open(org.refcodes.data.Scheme aScheme, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor) throws IOException Same asopen(String, KeyStoreDescriptor, int)but:- The number of maximum connections at the same time is decided upon by the implementations's default value.
- Parameters:
aScheme- TheSchemeto use, e.g.Scheme.HTTPSdefaults to "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
void open(String aProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aPort, int aMaxConnections) throws IOException Opens the HTTPS sever connection (socket) at the given port allowing the given number of maximum connections at the same time using the provided HTTPS configuration parameters.- Parameters:
aProtocol- The protocol to use, e.g. "TLS".aStoreDescriptor- The store descriptor describing yourKeyStorerequired for HTTPS.aPort- The port on which to listen for requests.aMaxConnections- The number of maximum connections at the same time.- Throws:
IOException- thrown in case something went wrong such as the port being already in use.
-
open
- Specified by:
openin interfaceorg.refcodes.component.ConnectionOpenable<org.refcodes.web.HttpServerContext>- Throws:
IOException
-