Interface HttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
- Type Parameters:
B- the generic type
- All Superinterfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.AliasAccessor.AliasBuilder<B>,org.refcodes.mixin.AliasAccessor.AliasMutator,org.refcodes.mixin.AliasAccessor.AliasProperty,org.refcodes.web.HostAccessor,org.refcodes.web.HostAccessor.HostBuilder<B>,org.refcodes.web.HostAccessor.HostMutator,org.refcodes.web.HostAccessor.HostProperty,HttpServerDescriptor,org.refcodes.net.IpAddressAccessor,org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B>,org.refcodes.net.IpAddressAccessor.IpAddressMutator,org.refcodes.net.IpAddressAccessor.IpAddressProperty,PingUrlAccessor,PingUrlAccessor.PingUrlBuilder<B>,PingUrlAccessor.PingUrlMutator,PingUrlAccessor.PingUrlProperty,org.refcodes.mixin.PortAccessor,org.refcodes.mixin.PortAccessor.PortBuilder<B>,org.refcodes.mixin.PortAccessor.PortMutator,org.refcodes.mixin.PortAccessor.PortProperty,org.refcodes.web.VirtualHostAccessor,org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B>,org.refcodes.web.VirtualHostAccessor.VirtualHostMutator,org.refcodes.web.VirtualHostAccessor.VirtualHostProperty
- Enclosing interface:
HttpServerDescriptor
public static interface HttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
extends HttpServerDescriptor, org.refcodes.net.IpAddressAccessor.IpAddressProperty, org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B>, org.refcodes.web.HostAccessor.HostProperty, org.refcodes.web.HostAccessor.HostBuilder<B>, org.refcodes.web.VirtualHostAccessor.VirtualHostProperty, org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B>, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.mixin.PortAccessor.PortBuilder<B>, PingUrlAccessor.PingUrlProperty, PingUrlAccessor.PingUrlBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasProperty, org.refcodes.mixin.AliasAccessor.AliasBuilder<B>
The
HttpServerDescriptor.HttpServerDescriptorBuilder interface extends the
HttpServerDescriptor interface with builder functionality as of
the builder pattern.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.web.HostAccessor
org.refcodes.web.HostAccessor.HostBuilder<B extends org.refcodes.web.HostAccessor.HostBuilder<?>>, org.refcodes.web.HostAccessor.HostMutator, org.refcodes.web.HostAccessor.HostPropertyNested classes/interfaces inherited from interface org.refcodes.rest.HttpServerDescriptor
HttpServerDescriptor.HttpServerDescriptorBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.net.IpAddressAccessor
org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B extends org.refcodes.net.IpAddressAccessor.IpAddressBuilder<B>>, org.refcodes.net.IpAddressAccessor.IpAddressMutator, org.refcodes.net.IpAddressAccessor.IpAddressPropertyNested classes/interfaces inherited from interface org.refcodes.rest.PingUrlAccessor
PingUrlAccessor.PingUrlBuilder<B extends PingUrlAccessor.PingUrlBuilder<?>>, PingUrlAccessor.PingUrlMutator, PingUrlAccessor.PingUrlPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortPropertyNested classes/interfaces inherited from interface org.refcodes.web.VirtualHostAccessor
org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B extends org.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<?>>, org.refcodes.web.VirtualHostAccessor.VirtualHostMutator, org.refcodes.web.VirtualHostAccessor.VirtualHostProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault Bdefault BwithCidrNotation(String aCidrNotation) default Bdefault BwithIpAddress(int[] aIpAddress) default BwithPingUrl(org.refcodes.web.Url aUrl) Sets the pingUrlto use and returns this builder as of the builder pattern.default BwithPort(int aPort) default BwithVirtualHost(String aVirtualHost) Methods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.mixin.AliasAccessor.AliasMutator
setAliasMethods inherited from interface org.refcodes.mixin.AliasAccessor.AliasProperty
letAliasMethods inherited from interface org.refcodes.web.HostAccessor
getHostMethods inherited from interface org.refcodes.web.HostAccessor.HostMutator
setHostMethods inherited from interface org.refcodes.web.HostAccessor.HostProperty
letHostMethods inherited from interface org.refcodes.net.IpAddressAccessor
getIpAddress, toCidrNotationMethods inherited from interface org.refcodes.net.IpAddressAccessor.IpAddressMutator
fromCidrNotation, setIpAddressMethods inherited from interface org.refcodes.net.IpAddressAccessor.IpAddressProperty
letIpAddressMethods inherited from interface org.refcodes.rest.PingUrlAccessor
getPingUrlMethods inherited from interface org.refcodes.rest.PingUrlAccessor.PingUrlMutator
setPingUrlMethods inherited from interface org.refcodes.rest.PingUrlAccessor.PingUrlProperty
letPingUrlMethods inherited from interface org.refcodes.mixin.PortAccessor
getPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortMutator
setPortMethods inherited from interface org.refcodes.mixin.PortAccessor.PortProperty
letPortMethods inherited from interface org.refcodes.web.VirtualHostAccessor
getVirtualHostMethods inherited from interface org.refcodes.web.VirtualHostAccessor.VirtualHostMutator
setVirtualHostMethods inherited from interface org.refcodes.web.VirtualHostAccessor.VirtualHostProperty
letVirtualHost
-
Method Details
-
withAlias
- Specified by:
withAliasin interfaceorg.refcodes.mixin.AliasAccessor.AliasBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withIpAddress
- Specified by:
withIpAddressin interfaceorg.refcodes.net.IpAddressAccessor.IpAddressBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withPingUrl
Sets the pingUrlto use and returns this builder as of the builder pattern.- Specified by:
withPingUrlin interfacePingUrlAccessor.PingUrlBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>- Parameters:
aUrl- The pingUrlto be stored by the pingUrlproperty.- Returns:
- This
PingUrlAccessor.PingUrlBuilderinstance to continue configuration.
-
withCidrNotation
- Specified by:
withCidrNotationin interfaceorg.refcodes.net.IpAddressAccessor.IpAddressBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withPort
- Specified by:
withPortin interfaceorg.refcodes.mixin.PortAccessor.PortBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withHost
- Specified by:
withHostin interfaceorg.refcodes.web.HostAccessor.HostBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-
withVirtualHost
- Specified by:
withVirtualHostin interfaceorg.refcodes.web.VirtualHostAccessor.VirtualHostBuilder<B extends HttpServerDescriptor.HttpServerDescriptorBuilder<B>>
-