Class JdkHttpRestClient

java.lang.Object
org.refcodes.rest.AbstractRestClient
org.refcodes.rest.JdkHttpRestClient
All Implemented Interfaces:
Closable, ConnectionComponent<HttpClientContext>, ConnectionOpenable<HttpClientContext>, ConnectionStatusAccessor, LinkComponent, Openable, Openable.OpenBuilder<HttpRestClient>, OpenedAccessor, DeleteRestClient, GetRestClient, HttpRestClient, PostRestClient, PutRestClient, RestClient, RestRequestClient, RestRequestHandler, TrustStoreDescriptorAccessor, TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpRestClient>, TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty, BaseUrlAccessor, BaseUrlAccessor.BaseUrlBuilder<HttpRestClient>, BaseUrlAccessor.BaseUrlMutator, BaseUrlAccessor.BaseUrlProperty, BasicAuthCredentialsAccessor, BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<RestClient>, BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty, HttpClientInterceptable, MediaTypeFactoryLookup, MediaTypeFactoryLookup.MutableMediaTypeFactoryLookup, OauthTokenAccessor, OauthTokenAccessor.OauthTokenBuilder<RestClient>, OauthTokenAccessor.OauthTokenMutator, OauthTokenAccessor.OauthTokenProperty, PostHttpClientInterceptable, PostHttpInterceptable<PostHttpClientInterceptor>, PreHttpClientInterceptable, PreHttpInterceptable<PreHttpClientInterceptor>, UserAgentAccessor, UserAgentAccessor.UserAgentBuilder<RestClient>, UserAgentAccessor.UserAgentMutator, UserAgentAccessor.UserAgentProperty
Direct Known Subclasses:
JdkHttpRestClientSingleton

public class JdkHttpRestClient extends AbstractRestClient implements HttpRestClient

The JdkHttpRestClient implements the HttpRestClient interface. The JdkHttpRestClient is being initialized with some common MediaTypeFactory instances (as implemented by the AbstractRestClient). At the time of writing this document the MediaTypeFactory instances being preconfigured are:

The JdkHttpRestClient supports HTTP as well as HTTPS protocols as being based on the HttpURLConnection. For configuring HTTPS capabilities, refer to the methods such as open(Url, TrustStoreDescriptor) or open(Url, TrustStoreDescriptor).