- java.lang.Object
-
- org.refcodes.web.OauthToken
-
- org.refcodes.rest.OauthTokenHandler
-
- All Implemented Interfaces:
org.refcodes.mixin.Disposable,org.refcodes.mixin.Disposable.Disposedable,org.refcodes.mixin.DisposedAccessor,org.refcodes.mixin.ValidAccessor
public class OauthTokenHandler extends org.refcodes.web.OauthTokenSelf refreshing implementation of theOauthToken. In case a refresh token (as ofOauthToken.getRefreshToken()and has been provided, then the access token (as ofOauthToken.getAccessToken()is refreshed within the "expires in" time (as ofOauthToken.getExpiresIn(). The refresh daemon terminates and this instance is disposed when the providedHttpRestClient'sClosable.close()method is called or thedispose()method is invoked.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.Disposable
org.refcodes.mixin.Disposable.Disposedable
-
-
Constructor Summary
Constructors Constructor Description OauthTokenHandler(String aUrl, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType)Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, org.refcodes.web.HttpBodyMap aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voiddispose()
-
-
-
Constructor Detail
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword) throws org.refcodes.web.HttpStatusException, MalformedURLExceptionConstructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) throws org.refcodes.web.HttpStatusException, MalformedURLExceptionConstructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLExceptionConstructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLExceptionConstructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) throws org.refcodes.web.HttpStatusException, MalformedURLException
Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.- Parameters:
aUrl- The URL to be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aClientId- The client's TID for "password" grant type.aClientSecret- The client's secret for "password" grant type.aUserName- The user's name for "password" grant type.aUserPassword- The user's password for "password" grant type.aGrantType- TheGrantTypeto use.- Throws:
org.refcodes.web.HttpStatusException- thrown in case a HTTP response was of an erroneous status.MalformedURLException- thrown in case of a malformed URL.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)
Constructs an instance of theOauthTokenHandlerwith the given parameters. For the refresh token parameters, please refer to "https://www.oauth.com/oauth2-servers/access-tokens/refreshing-access-tokens".- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aAccessToken- The access token to be stored (as ofOauthToken.getAccessToken()).aRefreshToken- The refresh token to be used (as ofOauthToken.getRefreshToken()).aTokenType- The token type to be stored (as ofOauthToken.getTokenType()).aExpiresIn- The "expires in" time to be stored (as ofOauthToken.getExpiresIn()).aScope- The scope to be stored (as ofOauthToken.getScope()).
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aAccessToken- The access token to be stored (as ofOauthToken.getAccessToken()).aRefreshToken- The refresh token to be used (as ofOauthToken.getRefreshToken()).aTokenType- The token type to be stored (as ofOauthToken.getTokenType()).aExpiresIn- The "expires in" time to be stored (as ofOauthToken.getExpiresIn()).aScope- The scope to be stored (as ofOauthToken.getScope()).
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, org.refcodes.web.HttpBodyMap aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aOauthToken- TheHttpBodyMapcontaining the OAuth token with the required information.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aOauthToken- TheOauthTokencontaining the required information.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, org.refcodes.web.OauthToken aOauthToken)
Constructs an instance of theOauthTokenHandlerwith the given parameters. For the refresh token parameters, please refer to "https://www.oauth.com/oauth2-servers/access-tokens/refreshing-access-tokens".- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aOauthToken- TheOauthTokencontaining the required information.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aAccessToken- The access token to be stored (as ofOauthToken.getAccessToken()).aRefreshToken- The refresh token to be used (as ofOauthToken.getRefreshToken()).aTokenType- The token type to be stored (as ofOauthToken.getTokenType()).aExpiresIn- The "expires in" time to be stored (as ofOauthToken.getExpiresIn()).aScope- The scope to be stored (as ofOauthToken.getScope()).
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aOauthToken- TheHttpBodyMapcontaining the OAuth token with the required information.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken)
Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- The URL to be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aOauthToken- TheOauthTokencontaining the required information.
-
OauthTokenHandler
public OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken)Constructs an instance of theOauthTokenHandlerwith the given parameters.- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aOauthToken- TheOauthTokencontaining the required information.
-
OauthTokenHandler
public OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)
Constructs an instance of theOauthTokenHandlerwith the given parameters. For the refresh token parameters, please refer to "https://www.oauth.com/oauth2-servers/access-tokens/refreshing-access-tokens".- Parameters:
aUrl- TheUrlto be used when refreshing the access token.aHttpRestClient- TheHttpRestClientto use when refreshing the token.aAccessToken- The access token to be stored (as ofOauthToken.getAccessToken()).aRefreshToken- The refresh token to be used (as ofOauthToken.getRefreshToken()).aTokenType- The token type to be stored (as ofOauthToken.getTokenType()).aExpiresIn- The "expires in" time to be stored (as ofOauthToken.getExpiresIn()).aScope- The scope to be stored (as ofOauthToken.getScope()).
-
-