- All Known Subinterfaces:
HttpRegistry<DESC,,B> HttpRegistrySidecar<DESC,,B> PingPathAccessor.PingPathProperty,RestfulHttpRegistryServer<DESC,B>
- All Known Implementing Classes:
AbstractHttpRegistrySidecar,AbstractRestfulHttpRegistryServerDecorator
public interface PingPathAccessor
Provides an accessor for a ping path property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for an ping path property.static interfaceProvides a mutator for a ping path property.static interfaceProvides a ping path property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the ping path from the ping path property.
-
Method Details
-
getPingPath
String getPingPath()Retrieves the ping path from the ping path property.- Returns:
- The ping path stored by the ping path property.
-