- All Known Subinterfaces:
HttpRegistry<DESC,,B> HttpRegistrySidecar<DESC,,B> PingPathAccessor.PingPathProperty,RestfulHttpRegistryServer<DESC,B>
- All Known Implementing Classes:
AbstractHttpRegistrySidecar,AbstractRestfulHttpRegistryServerDecorator
- Enclosing interface:
PingPathAccessor
public static interface PingPathAccessor.PingPathMutator
Provides a mutator for a ping path property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetPingPath(String aPingPath) Sets the ping path for the ping path property.
-
Method Details
-
setPingPath
Sets the ping path for the ping path property.- Parameters:
aPingPath- The ping path to be stored by the ping path property.
-