Interface PingPathAccessor.PingPathProperty
- All Superinterfaces:
PingPathAccessor,PingPathAccessor.PingPathMutator
- All Known Subinterfaces:
HttpRegistry<DESC,,B> HttpRegistrySidecar<DESC,,B> HttpRestRegistryServer<DESC,B>
- All Known Implementing Classes:
AbstractHttpRegistrySidecar,AbstractHttpRestRegistryServerDecorator
- Enclosing interface:
PingPathAccessor
public static interface PingPathAccessor.PingPathProperty
extends PingPathAccessor, PingPathAccessor.PingPathMutator
Provides a ping path property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.rest.PingPathAccessor
PingPathAccessor.PingPathBuilder<B extends PingPathAccessor.PingPathBuilder<?>>, PingPathAccessor.PingPathMutator, PingPathAccessor.PingPathProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault StringletPingPath(String aPingPath) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofPingPathAccessor.PingPathMutator.setPingPath(String)and returns the very same value (getter).Methods inherited from interface org.refcodes.rest.PingPathAccessor
getPingPathMethods inherited from interface org.refcodes.rest.PingPathAccessor.PingPathMutator
setPingPath
-
Method Details
-
letPingPath
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofPingPathAccessor.PingPathMutator.setPingPath(String)and returns the very same value (getter).- Parameters:
aPingPath- TheStringto set (viaPingPathAccessor.PingPathMutator.setPingPath(String)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-