Interface RestRequestHandler

All Known Subinterfaces:
RestDeleteClient, RestfulClient, RestfulHttpClient, RestfulHttpDiscoveryClient<B>, RestGetClient, RestPostClient, RestPutClient, RestRequestClient
All Known Implementing Classes:
AbstractRestfulClient, AbstractRestfulHttpClientDecorator, AbstractRestfulHttpDiscoveryClientDecorator, HttpRestClient, HttpRestClientSingleton, LoopbackRestClient, LoopbackRestClientSingleton
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface RestRequestHandler
A RestRequestHandler handles a REST request on the RestfulClient instance's side to do the actual technical implementation of sending that request (or mocking the send-out of a request).