- All Known Subinterfaces:
RestDeleteClient,RestfulClient,RestfulHttpClient,RestfulHttpDiscoveryClient<B>,RestGetClient,RestPostClient,RestPutClient,RestRequestClient
- All Known Implementing Classes:
AbstractRestfulClient,AbstractRestfulHttpClientDecorator,AbstractRestfulHttpDiscoveryClientDecorator,HttpRestClient,HttpRestClientSingleton,LoopbackRestClient,LoopbackRestClientSingleton
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
A
RestRequestHandler handles a REST request on the
RestfulClient instance's side to do the actual technical
implementation of sending that request (or mocking the send-out of a
request).-
Method Summary
Modifier and TypeMethodDescriptiondoRequest(org.refcodes.web.HttpClientRequest aHttpClientRequest) Hook receiving a preparedRestResponseHandlerinstance to be used to do the technical request with the technology chosen by the implementing sub-class.
-
Method Details
-
doRequest
RestResponse doRequest(org.refcodes.web.HttpClientRequest aHttpClientRequest) throws org.refcodes.web.HttpResponseException Hook receiving a preparedRestResponseHandlerinstance to be used to do the technical request with the technology chosen by the implementing sub-class.- Parameters:
aHttpClientRequest- The preparedHttpClientRequest.- Returns:
- The resulting
RestResponse. - Throws:
org.refcodes.web.HttpResponseException- thrown by a HTTP response handling system in case of some unexpected response.
-