Uses of Interface
org.refcodes.rest.HttpExceptionHandler
-
Uses of HttpExceptionHandler in org.refcodes.rest
Fields in org.refcodes.rest declared as HttpExceptionHandler Modifier and Type Field Description protected HttpExceptionHandlerAbstractRestServer. _httpExceptionHandlerMethods in org.refcodes.rest that return HttpExceptionHandler Modifier and Type Method Description HttpExceptionHandlerAbstractRestServer. getHttpExceptionHandler()Retrieves theHttpExceptionHandlerfrom theHttpExceptionHandlerproperty.HttpExceptionHandlerHttpExceptionHandlerAccessor. getHttpExceptionHandler()Retrieves theHttpExceptionHandlerfrom theHttpExceptionHandlerproperty.default HttpExceptionHandlerHttpExceptionHandlerAccessor.HttpExceptionHandlerProperty. letHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).Methods in org.refcodes.rest with parameters of type HttpExceptionHandler Modifier and Type Method Description default HttpExceptionHandlerHttpExceptionHandlerAccessor.HttpExceptionHandlerProperty. letHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandler(setter) as ofHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator.setHttpExceptionHandler(HttpExceptionHandler)and returns the very same value (getter).default voidHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator. onHttpException(HttpExceptionHandler aHttpExceptionHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.voidAbstractRestServer. setHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.voidHttpExceptionHandlerAccessor.HttpExceptionHandlerMutator. setHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.BHttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder. withHttpExceptionHandler(HttpExceptionHandler aHttpExceptionHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerHttpRestServer. withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default LoopbackRestServerLoopbackRestServer. withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default BHttpExceptionHandlerAccessor.HttpExceptionHandlerBuilder. withOnHttpException(HttpExceptionHandler aHttpExceptionHandler)Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.