Uses of Interface
org.refcodes.rest.HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty
-
Uses of HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty in org.refcodes.rest
Subinterfaces of HttpExceptionHandlerAccessor.HttpExceptionHandlerProperty in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceRestfulHttpRegistryServer<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> TheRestfulHttpRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestfulServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaRestfulHttpServer.open(int, int).Classes in org.refcodes.rest that implement HttpExceptionHandlerAccessor.HttpExceptionHandlerPropertyModifier and TypeClassDescriptionclassAbstractRestfulHttpRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> Abstract class for easily decorating aRestfulHttpRegistryServer.classAbstract class for easily decorating aRestfulHttpServer.classImplementation of theRestfulHttpServerinterface using theRestfulHttpServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theHttpRestServerfor easyRestfulHttpServeraccess.