Uses of Enum
org.refcodes.rest.HttpExceptionHandling
-
Uses of HttpExceptionHandling in org.refcodes.rest
Fields in org.refcodes.rest declared as HttpExceptionHandlingModifier and TypeFieldDescriptionprotected HttpExceptionHandlingAbstractRestServer._httpExceptionHandlingMethods in org.refcodes.rest that return HttpExceptionHandlingModifier and TypeMethodDescriptionAbstractRestServer.getHttpExceptionHandling()Retrieves theHttpExceptionHandlingfrom theHttpExceptionHandlingproperty.HttpExceptionHandlingAccessor.getHttpExceptionHandling()Retrieves theHttpExceptionHandlingfrom theHttpExceptionHandlingproperty.default HttpExceptionHandlingHttpExceptionHandlingAccessor.HttpExceptionHandlingProperty.letHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).static HttpExceptionHandlingReturns the enum constant of this type with the specified name.static HttpExceptionHandling[]HttpExceptionHandling.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.rest with parameters of type HttpExceptionHandlingModifier and TypeMethodDescriptiondefault HttpExceptionHandlingHttpExceptionHandlingAccessor.HttpExceptionHandlingProperty.letHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpExceptionHandling(setter) as ofHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling)and returns the very same value (getter).voidAbstractRestServer.setHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.voidHttpExceptionHandlingAccessor.HttpExceptionHandlingMutator.setHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder.withHttpExceptionHandling(HttpExceptionHandling aHttpExceptionHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default LoopbackRestServerLoopbackRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.