Uses of Interface
org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder
-
Uses of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeInterfaceDescriptionstatic interfaceHttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>Provides a builder method for aHttpExceptionHandlingproperty returning the builder for applying multiple build operations.Subinterfaces of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceRestfulHttpRegistryServer<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> TheRestfulHttpRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestfulServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaRestfulHttpServer.open(int, int).Classes in org.refcodes.rest that implement HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeClassDescriptionclassAbstractRestfulHttpRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> Abstract class for easily decorating aRestfulHttpRegistryServer.classAbstract class for easily decorating aRestfulHttpServer.classImplementation of theRestfulHttpServerinterface using theRestfulHttpServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theHttpRestServerfor easyRestfulHttpServeraccess.