Uses of Interface
org.refcodes.rest.HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder
-
Uses of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeInterfaceDescriptionstatic interfaceHttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B extends HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder<B>>Provides a builder method for aHttpExceptionHandlingproperty returning the builder for applying multiple build operations.Subinterfaces of HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilder in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRegistryRestServer<DESC extends HttpServerDescriptor,B extends HttpRegistryRestServer<DESC, B>> TheHttpRegistryRestServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be used as loopback device e.g. for testing purposes such as testing yourRestRequestConsumerimplementations.interfaceTheRestServeracts as the target for clients issuing REST requests.Classes in org.refcodes.rest that implement HttpExceptionHandlingAccessor.HttpExceptionHandlingBuilderModifier and TypeClassDescriptionclassAbstractHttpRegistryRestServerDecorator<DESC extends HttpServerDescriptor,B extends HttpRegistryRestServer<DESC, B>> Abstract class for easily decorating aHttpRegistryRestServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classImplementation of the base functionality of theRestServerinterface omitting the HTTP handling part being the foundation for variousRestServerimplementations such asHttpRestServerImplorLoopbackRestServerImpl.classImplementation of theHttpRestServerinterface using theHttpServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theHttpRestServerImplfor easyHttpRestServeraccess.classImplementation if theLoopbackRestServerfor easy testing of your requests being received by aRestServer(HttpRestServer) and the according responselambdaexpressions.classThe singleton of theLoopbackRestServerImplfor easyRestServeraccess.