Uses of Interface
org.refcodes.rest.HttpRestClient
-
Uses of HttpRestClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestClientModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.Subinterfaces of HttpRestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestDiscoveryClient<B extends HttpRestDiscoveryClient<B>>TheHttpRestDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestClientModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstract class for easily decorating aHttpRestDiscoveryClient.classTheJdkHttpRestClientimplements theHttpRestClientinterface.classThe singleton of theJdkHttpRestClientfor easyHttpRestClientaccess.Subinterfaces with type arguments of type HttpRestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).Fields in org.refcodes.rest declared as HttpRestClientModifier and TypeFieldDescriptionprotected HttpRestClientAbstractHttpRestClientDecorator._clientMethods in org.refcodes.rest that return HttpRestClientModifier and TypeMethodDescriptionstatic HttpRestClientJdkHttpRestClientSingleton.getInstance()Returns the singleton's instance as fabricated by thisJdkHttpRestClientSingleton.default HttpRestClientHttpRestClient.withBaseUrl(String aBaseUrl) default HttpRestClientHttpRestClient.withBaseUrl(URL aBaseURL) default HttpRestClientHttpRestClient.withBaseUrl(Url aBaseUrl) static HttpRestClientJdkHttpRestClientSugar.withBaseUrl(String aBaseUrl) See alsoHttpRestClient.withBaseUrl(String).static HttpRestClientJdkHttpRestClientSugar.withBaseUrl(URL aBaseUrl) See alsoHttpRestClient.withBaseUrl(URL).default HttpRestClientHttpRestClient.withBasicAuthCredentials(String aUserName, String aSecret) default HttpRestClientHttpRestClient.withBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) default HttpRestClientHttpRestClient.withOAuthToken(OauthToken aOauthToken) default HttpRestClientHttpRestClient.withOpen()Open the component's connection(s).default HttpRestClientHttpRestClient.withOpen(TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientHttpRestClient.withOpen(HttpClientContext aCtx) Opens the component with the given connection.default HttpRestClientConfigures the HTTPS client connection with the provided configuration parameters.default HttpRestClientHttpRestClient.withOpen(Url aBaseUrl, TrustStoreDescriptor aStoreDescriptor) Configures the HTTPS client connection with the provided configuration parameters.default HttpRestClientHttpRestClient.withTrustStoreDescriptor(TrustStoreDescriptor aStoreDescriptor) default HttpRestClientHttpRestClient.withUserAgent(String aUserAgent) static HttpRestClientJdkHttpRestClientSugar.withUserAgent(String aUserAgent) See alsoHttpRestClient.withUserAgent(String).Constructors in org.refcodes.rest with parameters of type HttpRestClientModifierConstructorDescriptionDecorates the givenHttpRestClient.Decorates the givenHttpRestClientwith discovery functionality.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, GrantType aGrantType, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, HttpBodyTable aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, HttpBodyTable aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, HttpBodyTable aOauthToken, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken, int aTokenRefreshRetries, long aTokenRefreshRetryWaitTimeMillis, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(Url aUrl, HttpRestClient aHttpRestClient, OauthToken aOauthToken, RetryCounter aTokenRefreshRetryCounter, long aServerRecoveryWaitTimeMillis) Constructs an instance of theOauthTokenHandlerwith the given parameters.