Uses of Interface
org.refcodes.rest.HttpRestClient
-
Uses of HttpRestClient in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestClientModifier and TypeClassDescriptionclassAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.Subinterfaces of HttpRestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpDiscoveryRestClient<B extends HttpDiscoveryRestClient<B>>TheHttpDiscoveryRestClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpDiscoveryRestClient.classAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classTheHttpRestClientImplimplements theHttpRestClientinterface.classThe singleton of theHttpRestClientImplfor easyHttpRestClientaccess.Fields in org.refcodes.rest declared as HttpRestClientModifier and TypeFieldDescriptionprotected HttpRestClientAbstractHttpRestClientDecorator._clientMethods in org.refcodes.rest that return HttpRestClientModifier and TypeMethodDescriptionstatic HttpRestClientHttpRestClientSingleton.getInstance()Returns the singleton's instance as fabricated by thisHttpRestClientSingleton.default HttpRestClientHttpRestClient.withBaseUrl(String aBaseUrl) default HttpRestClientHttpRestClient.withBaseUrl(URL aBaseURL) default HttpRestClientHttpRestClient.withBaseUrl(org.refcodes.web.Url aBaseUrl) static HttpRestClientHttpRestClientSugar.withBaseUrl(String aBaseUrl) See alsowithBaseUrl(String)static HttpRestClientHttpRestClientSugar.withBaseUrl(URL aBaseUrl) See alsowithBaseUrl(URL)default HttpRestClientHttpRestClient.withBasicAuthCredentials(String aUserName, String aSecret) default HttpRestClientHttpRestClient.withBasicAuthCredentials(org.refcodes.web.BasicAuthCredentials aBasicAuthCredentials) default HttpRestClientHttpRestClient.withDisableRequestCorrelation()default HttpRestClientHttpRestClient.withDisableSessionCorrelation()default HttpRestClientHttpRestClient.withEnableRequestCorrelation()default HttpRestClientHttpRestClient.withEnableSessionCorrelation()default HttpRestClientHttpRestClient.withOAuthToken(org.refcodes.web.OauthToken aOauthToken) default HttpRestClientHttpRestClient.withRequestCorrelation(boolean hasRequestCorrelation) default HttpRestClientHttpRestClient.withSessionCorrelation(boolean hasSessionCorrelation) default HttpRestClientHttpRestClient.withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor) default HttpRestClientHttpRestClient.withUserAgent(String aUserAgent) static HttpRestClientHttpRestClientSugar.withUserAgent(String aUserAgent) See alsowithUserAgent(String)Constructors in org.refcodes.rest with parameters of type HttpRestClientModifierConstructorDescriptionDecorates the givenHttpRestClientwith discovery functionality.Decorates the givenHttpRestClient.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(String aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, String aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, String aClientId, String aClientSecret, String aUserName, String aUserPassword, org.refcodes.web.GrantType aGrantType) Constructs an instance of theOauthTokenHandlerwith the given parameters by using the user's name and password for a "password" grant type authentication to retrieve aOauthToken.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.HttpBodyMap aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.OauthTokenHandler(org.refcodes.web.Url aUrl, HttpRestClient aHttpRestClient, org.refcodes.web.OauthToken aOauthToken) Constructs an instance of theOauthTokenHandlerwith the given parameters.