Uses of Interface
org.refcodes.rest.HttpRestServer
-
Uses of HttpRestServer in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.Subinterfaces of HttpRestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRestRegistryServer<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> TheHttpRestRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRestRegistryServerDecorator<DESC extends HttpServerDescriptor, B extends HttpRestRegistryServer<DESC,B>> Abstract class for easily decorating aHttpRestRegistryServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classImplementation of theHttpRestServerinterface using theHttpRestServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theJdkHttpRestServerfor easyHttpRestServeraccess.Subinterfaces with type arguments of type HttpRestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).interfaceExtends aRestServerto be capable of opening a server socket on the local host with the provided port number viaConnectionOpenable.open(Object)or with an additional maximum number of connections viaHttpRestServer.open(int, int).Fields in org.refcodes.rest declared as HttpRestServerModifier and TypeFieldDescriptionprotected HttpRestServerAbstractHttpRestServerDecorator._serverMethods in org.refcodes.rest that return HttpRestServerModifier and TypeMethodDescriptionstatic HttpRestServerJdkHttpRestServerSugar.close()SeeClosable.close().static HttpRestServerJdkHttpRestServerSugar.closeIn(int aCloseMillis) static HttpRestServerJdkHttpRestServerSugar.closeQuietly()static HttpRestServerJdkHttpRestServerSugar.getHttpRestServer()SeeHttpRestServer.static HttpRestServerJdkHttpRestServerSingleton.getInstance()Returns the singleton's instance as fabricated by thisJdkHttpRestServerSingleton.JdkHttpRestServer.onBasicAuthRequest(BasicAuthObserver aBasicAuthObserver) static HttpRestServerJdkHttpRestServerSugar.onBasicAuthRequest(BasicAuthObserver aObserver) JdkHttpRestServer.onConnectionRequest(HttpsConnectionRequestObserver aObserver) static HttpRestServerJdkHttpRestServerSugar.onHttpException(HttpExceptionHandler aHttpExceptionHandler) static HttpRestServerJdkHttpRestClientSugar.open(HttpServerContext aCtx) static HttpRestServerJdkHttpRestServerSugar.open(int aPort) static HttpRestServerJdkHttpRestServerSugar.open(int aPort, int aMaxConnections) static HttpRestServerJdkHttpRestServerSugar.open(String aSecureSocketProtocol, KeyStoreDescriptor aStoreDescriptor, Integer aPort) static HttpRestServerJdkHttpRestServerSugar.open(String aSecureSocketProtocol, KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static HttpRestServerJdkHttpRestServerSugar.open(KeyStoreDescriptor aStoreDescriptor, Integer aPort) static HttpRestServerJdkHttpRestServerSugar.open(KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static HttpRestServerJdkHttpRestServerSugar.open(HttpServerContext aCtx) default HttpRestServerHttpRestServer.withBaseLocator(String aBaseLocator) static HttpRestServerJdkHttpRestServerSugar.withBaseLocator(String aBaseLocator) default HttpRestServerHttpRestServer.withClose()default HttpRestServerHttpRestServer.withCloseIn(int aCloseMillis) default HttpRestServerHttpRestServer.withCloseQuietly()default HttpRestServerHttpRestServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default HttpRestServerHttpRestServer.withKeyStoreDescriptor(KeyStoreDescriptor aKeyStoreDescriptor) default HttpRestServerHttpRestServer.withMaxConnections(int aMaxConnections) default HttpRestServerHttpRestServer.withOpen(int aPort) Builder method for opening theHttpRestServer.default HttpRestServerHttpRestServer.withOpen(HttpServerContext aConnection) default HttpRestServerHttpRestServer.withPort(int aPort) default HttpRestServerHttpRestServer.withProtocol(String aProtocol) default HttpRestServerstatic HttpRestServerdefault HttpRestServerHttpRestServer.withScheme(Scheme aScheme) Constructors in org.refcodes.rest with parameters of type HttpRestServerModifierConstructorDescriptionDecorates the givenHttpRestServerwith discovery functionality.Decorates the givenHttpRestServerwith additional functionality.