Uses of Interface
org.refcodes.rest.HttpRestServer
-
Uses of HttpRestServer in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.Subinterfaces of HttpRestServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpRegistryRestServer<DESC extends HttpServerDescriptor,B extends HttpRegistryRestServer<DESC, B>> TheHttpRegistryRestServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement HttpRestServerModifier and TypeClassDescriptionclassAbstractHttpRegistryRestServerDecorator<DESC extends HttpServerDescriptor,B extends HttpRegistryRestServer<DESC, B>> Abstract class for easily decorating aHttpRegistryRestServer.classAbstractHttpRestServerDecorator<B extends HttpRestServer>Abstract class for easily decorating aHttpRestServer.classImplementation of theHttpRestServerinterface using theHttpServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theHttpRestServerImplfor easyHttpRestServeraccess.Fields in org.refcodes.rest declared as HttpRestServerModifier and TypeFieldDescriptionprotected HttpRestServerAbstractHttpRestServerDecorator._serverMethods in org.refcodes.rest that return HttpRestServerModifier and TypeMethodDescriptionstatic HttpRestServerHttpRestServerSugar.close()SeeClosable.close()static HttpRestServerHttpRestServerSugar.closeIn(int aCloseInMillis) SeeClosable.closeIn(int)static HttpRestServerHttpRestServerSugar.closeQuietly()SeeClosable.closeQuietly()static HttpRestServerHttpRestServerSingleton.getInstance()Returns the singleton's instance as fabricated by thisHttpRestServerSingleton.HttpRestServerImpl.onBasicAuthRequest(org.refcodes.web.BasicAuthObserver aBasicAuthObserver) static HttpRestServerHttpRestServerSugar.onBasicAuthRequest(org.refcodes.web.BasicAuthObserver aObserver) SeeBasicAuthObservable.onBasicAuthRequest(BasicAuthObserver)HttpRestServerImpl.onConnectionRequest(org.refcodes.web.HttpsConnectionRequestObserver aObserver) static HttpRestServerHttpRestClientSugar.open(org.refcodes.web.HttpServerContext aCtx) SeeConnectionOpenable.open(Object)static HttpRestServerHttpRestServerSugar.open(int aPort) Seeopen(int)static HttpRestServerHttpRestServerSugar.open(int aPort, int aMaxConnections) Seeopen(int, int)static HttpRestServerHttpRestServerSugar.open(String aSecureSocketProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort) static HttpRestServerHttpRestServerSugar.open(String aSecureSocketProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static HttpRestServerstatic HttpRestServerHttpRestServerSugar.open(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static HttpRestServerHttpRestServerSugar.open(org.refcodes.web.HttpServerContext aCtx) SeeConnectionOpenable.open(Object)default HttpRestServerHttpRestServer.withBaseLocator(String aBaseLocator) static HttpRestServerHttpRestServerSugar.withBaseLocator(String aBaseLocator) default HttpRestServerHttpRestServer.withClose()default HttpRestServerHttpRestServer.withCloseIn(int aCloseInMillis) default HttpRestServerHttpRestServer.withCloseQuietly()default HttpRestServerHttpRestServer.withDisableRequestCorrelation()default HttpRestServerHttpRestServer.withDisableSessionCorrelation()default HttpRestServerHttpRestServer.withEnableRequestCorrelation()default HttpRestServerHttpRestServer.withEnableSessionCorrelation()default HttpRestServerHttpRestServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default HttpRestServerHttpRestServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default HttpRestServerHttpRestServer.withKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) default HttpRestServerHttpRestServer.withMaxConnections(int aMaxConnections) default HttpRestServerHttpRestServer.withOpen(int aPort) Builder method for opening theHttpRestServer.default HttpRestServerHttpRestServer.withOpen(org.refcodes.web.HttpServerContext aConnection) default HttpRestServerHttpRestServer.withPort(int aPort) default HttpRestServerHttpRestServer.withProtocol(String aProtocol) default HttpRestServerstatic HttpRestServerdefault HttpRestServerHttpRestServer.withRequestCorrelation(boolean hasRequestCorrelation) default HttpRestServerHttpRestServer.withScheme(org.refcodes.data.Scheme aScheme) default HttpRestServerHttpRestServer.withSessionCorrelation(boolean hasSessionCorrelation) Constructors in org.refcodes.rest with parameters of type HttpRestServerModifierConstructorDescriptionDecorates the givenHttpRestServerwith discovery functionality.Decorates the givenHttpRestServerwith additional functionality.