Uses of Interface
org.refcodes.rest.RestClient
-
-
Uses of RestClient in org.refcodes.rest
Subinterfaces of RestClient in org.refcodes.rest Modifier and Type Interface Description interfaceHttpDiscoveryRestClient<B extends HttpDiscoveryRestClient<B>>TheHttpDiscoveryRestClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceHttpRestClientExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceLoopbackRestClientExtends aRestClientto be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.Classes in org.refcodes.rest that implement RestClient Modifier and Type Class Description classAbstractHttpDiscoveryRestClientDecorator<B extends HttpDiscoveryRestClient<B>>Abstract class for easily decorating aHttpDiscoveryRestClient.classAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstractRestClientAbstract base implementation of theRestClientinterface being the foundation for variousRestClientimplementations such asHttpRestClientImplorLoopbackRestClientImpl.classHttpRestClientImplTheHttpRestClientImplimplements theHttpRestClientinterface.classHttpRestClientSingletonThe singleton of theHttpRestClientImplfor easyHttpRestClientaccess.classLoopbackRestClientImplImplementation if theLoopbackRestClientfor easy testing of your requests being issued with aRestClient(LoopbackRestClientImpl) and the according responselambdaexpressions.classLoopbackRestClientSingletonThe singleton of theLoopbackRestClientImplfor easyLoopbackRestClientImplaccess.Methods in org.refcodes.rest with parameters of type RestClient Modifier and Type Method Description RestRequestRestRequest. build(RestClient aRestClient)This is a convenience method for easily instantiating the according builder.RestRequestBuilderRestRequestBuilder. build(RestClient aRestClient)This is a convenience method for easily instantiating the according builder.static RestResponseHandlerRestResponseHandler. build(RestClient aRestClient)This is a convenience method for easily instantiating the according builder.RestResponseResultRestResponseResult. build(RestClient aRestClient)This is a convenience method for easily instantiating the according builder.Constructors in org.refcodes.rest with parameters of type RestClient Constructor Description RestRequest(RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, Object aRequest, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, Object aRequest, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.web.RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequest(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.web.RequestHeaderFields aHeaderFields, Object aRequest, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, Object aRequest, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, Object aRequest, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.web.RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, RestClient aRestClient)Instantiates a new rest request builder impl.RestRequestBuilder(org.refcodes.web.HttpMethod aHttpMethod, org.refcodes.web.Url aUrl, org.refcodes.web.RequestHeaderFields aHeaderFields, Object aRequest, RestClient aRestClient)Instantiates a new rest request builder impl.RestResponseEvent(RestResponse aRestResponse, RestClient aRestClient)Constructs aRestResponseEventwith all required attributes.RestResponseEvent(org.refcodes.web.Url aUrl, InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, org.refcodes.web.HttpStatusCode aHttpStatusCode, org.refcodes.web.ResponseHeaderFields aHeaderFields, InputStream aHttpInputStream, RestClient aRestClient)Constructs aRestResponseEventwith all required attributes.
-