Uses of Interface
org.refcodes.rest.RestRequestClient
-
Uses of RestRequestClient in org.refcodes.rest
Subinterfaces of RestRequestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHelper interface to keep the huge amount of convenience methods under control.interfaceA client to send requests for communicating with a RESTful server such as theRestfulHttpServer.interfaceExtends aRestfulClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(RestfulHttpClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(RestfulHttpClient.withBaseUrl(String)).interfaceRestfulHttpDiscoveryClient<B extends RestfulHttpDiscoveryClient<B>>TheRestfulHttpDiscoveryClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.Classes in org.refcodes.rest that implement RestRequestClientModifier and TypeClassDescriptionclassAbstract base implementation of theRestfulClientinterface being the foundation for variousRestfulClientimplementations such asHttpRestClientorLoopbackRestClient.classAbstract class for easily decorating aRestfulHttpClient.classAbstract class for easily decorating aRestfulHttpDiscoveryClient.classTheHttpRestClientimplements theRestfulHttpClientinterface.classThe singleton of theHttpRestClientfor easyRestfulHttpClientaccess.classImplements theRestfulClientinterface to be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.classThe singleton of theLoopbackRestClientfor easyLoopbackRestClientaccess.