Uses of Interface
org.refcodes.rest.RestRequestClient
-
Uses of RestRequestClient in org.refcodes.rest
Subinterfaces of RestRequestClient in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceHttpDiscoveryRestClient<B extends HttpDiscoveryRestClient<B>>TheHttpDiscoveryRestClientprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.interfaceExtends aRestClientto be capable of providing a User-Agent withUserAgentAccessor.UserAgentMutator.setUserAgent(String)(HttpRestClient.withUserAgent(String)) and to be capable of using base URLs to be set withBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String)(HttpRestClient.withBaseUrl(String)).interfaceExtends aRestClientto be used as loopback device e.g. for testing purposes such as testing yourRestResponseConsumerimplementations.interfaceA client to send requests for communicating with a RESTful server such as theHttpRestServer.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.interfaceHelper interface to keep the huge amount of convenience methods under control.Classes in org.refcodes.rest that implement RestRequestClientModifier and TypeClassDescriptionclassAbstract class for easily decorating aHttpDiscoveryRestClient.classAbstractHttpRestClientDecorator<B extends HttpRestClient>Abstract class for easily decorating aHttpRestClient.classAbstract base implementation of theRestClientinterface being the foundation for variousRestClientimplementations such asHttpRestClientImplorLoopbackRestClientImpl.classTheHttpRestClientImplimplements theHttpRestClientinterface.classThe singleton of theHttpRestClientImplfor easyHttpRestClientaccess.classImplementation if theLoopbackRestClientfor easy testing of your requests being issued with aRestClient(LoopbackRestClientImpl) and the according responselambdaexpressions.classThe singleton of theLoopbackRestClientImplfor easyLoopbackRestClientImplaccess.