Uses of Interface
org.refcodes.rest.RestfulHttpServer
-
Uses of RestfulHttpServer in org.refcodes.rest
Classes in org.refcodes.rest with type parameters of type RestfulHttpServerSubinterfaces of RestfulHttpServer in org.refcodes.restModifier and TypeInterfaceDescriptioninterfaceRestfulHttpRegistryServer<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> TheRestfulHttpRegistryServerprovides additional functionality for registering at and signing off from a service discovery service in order to resolve URLs to or from other services.Classes in org.refcodes.rest that implement RestfulHttpServerModifier and TypeClassDescriptionclassAbstractRestfulHttpRegistryServerDecorator<DESC extends HttpServerDescriptor,B extends RestfulHttpRegistryServer<DESC, B>> Abstract class for easily decorating aRestfulHttpRegistryServer.classAbstract class for easily decorating aRestfulHttpServer.classImplementation of theRestfulHttpServerinterface using theRestfulHttpServerdefined in thecom.sun.net.httpserverpackage.classThe singleton of theHttpRestServerfor easyRestfulHttpServeraccess.Fields in org.refcodes.rest declared as RestfulHttpServerModifier and TypeFieldDescriptionprotected RestfulHttpServerAbstractRestfulHttpServerDecorator._serverMethods in org.refcodes.rest that return RestfulHttpServerModifier and TypeMethodDescriptionstatic RestfulHttpServerHttpRestServerSugar.close()SeeClosable.close().static RestfulHttpServerHttpRestServerSugar.closeIn(int aCloseMillis) SeeClosable.closeIn(int).static RestfulHttpServerHttpRestServerSugar.closeQuietly()SeeClosable.closeQuietly().static RestfulHttpServerHttpRestServerSugar.getHttpRestServer()SeeRestfulHttpServer.static RestfulHttpServerHttpRestServerSingleton.getInstance()Returns the singleton's instance as fabricated by thisHttpRestServerSingleton.HttpRestServer.onBasicAuthRequest(org.refcodes.web.BasicAuthObserver aBasicAuthObserver) static RestfulHttpServerHttpRestServerSugar.onBasicAuthRequest(org.refcodes.web.BasicAuthObserver aObserver) SeeBasicAuthObservable.onBasicAuthRequest(BasicAuthObserver).HttpRestServer.onConnectionRequest(org.refcodes.web.HttpsConnectionRequestObserver aObserver) static RestfulHttpServerHttpRestServerSugar.onHttpException(HttpExceptionHandler aHttpExceptionHandler) static RestfulHttpServerHttpRestClientSugar.open(org.refcodes.web.HttpServerContext aCtx) SeeConnectionOpenable.open(Object).static RestfulHttpServerHttpRestServerSugar.open(int aPort) Seeopen(int).static RestfulHttpServerHttpRestServerSugar.open(int aPort, int aMaxConnections) Seeopen(int, int).static RestfulHttpServerHttpRestServerSugar.open(String aSecureSocketProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort) static RestfulHttpServerHttpRestServerSugar.open(String aSecureSocketProtocol, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static RestfulHttpServerstatic RestfulHttpServerHttpRestServerSugar.open(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, Integer aPort, int aMaxConnections) static RestfulHttpServerHttpRestServerSugar.open(org.refcodes.web.HttpServerContext aCtx) SeeConnectionOpenable.open(Object).static RestfulHttpServerHttpRestServerSugar.withBaseLocator(String aBaseLocator) default RestfulHttpServerRestfulHttpServer.withBaseLocator(String aBaseLocator) default RestfulHttpServerRestfulHttpServer.withClose()default RestfulHttpServerRestfulHttpServer.withCloseIn(int aCloseMillis) default RestfulHttpServerRestfulHttpServer.withCloseQuietly()default RestfulHttpServerRestfulHttpServer.withHttpExceptionHandler(HttpExceptionHandler aHttpErrorHandler) Sets theHttpExceptionHandlerfor theHttpExceptionHandlerproperty.default RestfulHttpServerRestfulHttpServer.withHttpExceptionHandling(HttpExceptionHandling aHttpErrorHandling) Sets theHttpExceptionHandlingfor theHttpExceptionHandlingproperty.default RestfulHttpServerRestfulHttpServer.withKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) default RestfulHttpServerRestfulHttpServer.withMaxConnections(int aMaxConnections) default RestfulHttpServerRestfulHttpServer.withOpen(int aPort) Builder method for opening theRestfulHttpServer.default RestfulHttpServerRestfulHttpServer.withOpen(org.refcodes.web.HttpServerContext aConnection) default RestfulHttpServerRestfulHttpServer.withPort(int aPort) default RestfulHttpServerRestfulHttpServer.withProtocol(String aProtocol) static RestfulHttpServerSeewithRealm(String).default RestfulHttpServerdefault RestfulHttpServerRestfulHttpServer.withScheme(org.refcodes.data.Scheme aScheme) Constructors in org.refcodes.rest with parameters of type RestfulHttpServerModifierConstructorDescriptionDecorates the givenRestfulHttpServerwith discovery functionality.Decorates the givenRestfulHttpServerwith additional functionality.